# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

package Hamlib;
use base qw(Exporter);
use base qw(DynaLoader);
package Hamlibc;
bootstrap Hamlib;
package Hamlib;
@EXPORT = qw();

# ---------- BASE METHODS -------------

package Hamlib;

sub TIEHASH {
    my ($classname,$obj) = @_;
    return bless $obj, $classname;
}

sub CLEAR { }

sub FIRSTKEY { }

sub NEXTKEY { }

sub FETCH {
    my ($self,$field) = @_;
    my $member_func = "swig_${field}_get";
    $self->$member_func();
}

sub STORE {
    my ($self,$field,$newval) = @_;
    my $member_func = "swig_${field}_set";
    $self->$member_func($newval);
}

sub this {
    my $ptr = shift;
    return tied(%$ptr);
}


# ------- FUNCTION WRAPPERS --------

package Hamlib;

*rig_get_function_ptr = *Hamlibc::rig_get_function_ptr;
*rig_get_caps_int = *Hamlibc::rig_get_caps_int;
*rig_get_caps_cptr = *Hamlibc::rig_get_caps_cptr;
*rig_init = *Hamlibc::rig_init;
*rig_flush = *Hamlibc::rig_flush;
*rig_get_vfo_list = *Hamlibc::rig_get_vfo_list;
*netrigctl_get_vfo_mode = *Hamlibc::netrigctl_get_vfo_mode;
*rig_set_split_freq_mode = *Hamlibc::rig_set_split_freq_mode;
*rig_get_split_freq_mode = *Hamlibc::rig_get_split_freq_mode;
*rig_set_split_vfo = *Hamlibc::rig_set_split_vfo;
*rig_get_split_vfo = *Hamlibc::rig_get_split_vfo;
*rig_set_ext_func = *Hamlibc::rig_set_ext_func;
*rig_get_ext_func = *Hamlibc::rig_get_ext_func;
*rig_ext_func_foreach = *Hamlibc::rig_ext_func_foreach;
*rig_ext_lookup = *Hamlibc::rig_ext_lookup;
*rig_ext_lookup_tok = *Hamlibc::rig_ext_lookup_tok;
*rig_ext_token_lookup = *Hamlibc::rig_ext_token_lookup;
*rig_token_foreach = *Hamlibc::rig_token_foreach;
*rig_confparam_lookup = *Hamlibc::rig_confparam_lookup;
*rig_stop_morse = *Hamlibc::rig_stop_morse;
*rig_wait_morse = *Hamlibc::rig_wait_morse;
*rig_send_voice_mem = *Hamlibc::rig_send_voice_mem;
*rig_set_chan_all = *Hamlibc::rig_set_chan_all;
*rig_get_chan_all = *Hamlibc::rig_get_chan_all;
*rig_set_chan_all_cb = *Hamlibc::rig_set_chan_all_cb;
*rig_get_chan_all_cb = *Hamlibc::rig_get_chan_all_cb;
*rig_set_mem_all_cb = *Hamlibc::rig_set_mem_all_cb;
*rig_get_mem_all_cb = *Hamlibc::rig_get_mem_all_cb;
*rig_set_mem_all = *Hamlibc::rig_set_mem_all;
*rig_get_mem_all = *Hamlibc::rig_get_mem_all;
*rig_lookup_mem_caps = *Hamlibc::rig_lookup_mem_caps;
*rig_mem_count = *Hamlibc::rig_mem_count;
*rig_set_spectrum_callback = *Hamlibc::rig_set_spectrum_callback;
*rig_set_twiddle = *Hamlibc::rig_set_twiddle;
*rig_get_twiddle = *Hamlibc::rig_get_twiddle;
*rig_set_uplink = *Hamlibc::rig_set_uplink;
*rig_get_caps = *Hamlibc::rig_get_caps;
*rig_get_range = *Hamlibc::rig_get_range;
*rigerror = *Hamlibc::rigerror;
*rig_setting2idx = *Hamlibc::rig_setting2idx;
*rig_idx2setting = *Hamlibc::rig_idx2setting;
*rig_set_debug = *Hamlibc::rig_set_debug;
*rig_set_debug_time_stamp = *Hamlibc::rig_set_debug_time_stamp;
*rig_need_debug = *Hamlibc::rig_need_debug;
*rig_debug = *Hamlibc::rig_debug;
*rig_set_debug_callback = *Hamlibc::rig_set_debug_callback;
*rig_set_debug_file = *Hamlibc::rig_set_debug_file;
*rig_register = *Hamlibc::rig_register;
*rig_unregister = *Hamlibc::rig_unregister;
*rig_list_foreach = *Hamlibc::rig_list_foreach;
*rig_list_foreach_model = *Hamlibc::rig_list_foreach_model;
*rig_load_backend = *Hamlibc::rig_load_backend;
*rig_check_backend = *Hamlibc::rig_check_backend;
*rig_load_all_backends = *Hamlibc::rig_load_all_backends;
*rig_probe_all = *Hamlibc::rig_probe_all;
*rig_strrmode = *Hamlibc::rig_strrmode;
*rig_strrmodes = *Hamlibc::rig_strrmodes;
*rig_strvfo = *Hamlibc::rig_strvfo;
*rig_strfunc = *Hamlibc::rig_strfunc;
*rig_strlevel = *Hamlibc::rig_strlevel;
*rig_strparm = *Hamlibc::rig_strparm;
*rig_stragclevel = *Hamlibc::rig_stragclevel;
*rig_strptrshift = *Hamlibc::rig_strptrshift;
*rig_strvfop = *Hamlibc::rig_strvfop;
*rig_strscan = *Hamlibc::rig_strscan;
*rig_strstatus = *Hamlibc::rig_strstatus;
*rig_strmtype = *Hamlibc::rig_strmtype;
*rig_strspectrummode = *Hamlibc::rig_strspectrummode;
*rig_parse_mode = *Hamlibc::rig_parse_mode;
*rig_parse_vfo = *Hamlibc::rig_parse_vfo;
*rig_parse_func = *Hamlibc::rig_parse_func;
*rig_parse_level = *Hamlibc::rig_parse_level;
*rig_parse_parm = *Hamlibc::rig_parse_parm;
*rig_parse_vfo_op = *Hamlibc::rig_parse_vfo_op;
*rig_parse_scan = *Hamlibc::rig_parse_scan;
*rig_parse_rptr_shift = *Hamlibc::rig_parse_rptr_shift;
*rig_parse_mtype = *Hamlibc::rig_parse_mtype;
*rig_license = *Hamlibc::rig_license;
*rig_version = *Hamlibc::rig_version;
*rig_copyright = *Hamlibc::rig_copyright;
*rig_no_restore_ai = *Hamlibc::rig_no_restore_ai;
*rig_get_cache_timeout_ms = *Hamlibc::rig_get_cache_timeout_ms;
*rig_set_cache_timeout_ms = *Hamlibc::rig_set_cache_timeout_ms;
*rig_set_vfo_opt = *Hamlibc::rig_set_vfo_opt;
*rig_get_rig_info = *Hamlibc::rig_get_rig_info;
*rig_get_cache = *Hamlibc::rig_get_cache;
*rig_set_clock = *Hamlibc::rig_set_clock;
*rig_get_clock = *Hamlibc::rig_get_clock;
*hl_usleep = *Hamlibc::hl_usleep;
*rig_cookie = *Hamlibc::rig_cookie;
*rot_init = *Hamlibc::rot_init;
*rot_has_get_level = *Hamlibc::rot_has_get_level;
*rot_has_set_level = *Hamlibc::rot_has_set_level;
*rot_has_get_parm = *Hamlibc::rot_has_get_parm;
*rot_has_set_parm = *Hamlibc::rot_has_set_parm;
*rot_has_get_func = *Hamlibc::rot_has_get_func;
*rot_has_set_func = *Hamlibc::rot_has_set_func;
*rot_set_func = *Hamlibc::rot_set_func;
*rot_get_func = *Hamlibc::rot_get_func;
*rot_set_level = *Hamlibc::rot_set_level;
*rot_get_level = *Hamlibc::rot_get_level;
*rot_set_parm = *Hamlibc::rot_set_parm;
*rot_get_parm = *Hamlibc::rot_get_parm;
*rot_set_ext_level = *Hamlibc::rot_set_ext_level;
*rot_get_ext_level = *Hamlibc::rot_get_ext_level;
*rot_set_ext_func = *Hamlibc::rot_set_ext_func;
*rot_get_ext_func = *Hamlibc::rot_get_ext_func;
*rot_set_ext_parm = *Hamlibc::rot_set_ext_parm;
*rot_get_ext_parm = *Hamlibc::rot_get_ext_parm;
*rot_get_status = *Hamlibc::rot_get_status;
*rot_register = *Hamlibc::rot_register;
*rot_unregister = *Hamlibc::rot_unregister;
*rot_list_foreach = *Hamlibc::rot_list_foreach;
*rot_load_backend = *Hamlibc::rot_load_backend;
*rot_check_backend = *Hamlibc::rot_check_backend;
*rot_load_all_backends = *Hamlibc::rot_load_all_backends;
*rot_probe_all = *Hamlibc::rot_probe_all;
*rot_token_foreach = *Hamlibc::rot_token_foreach;
*rot_confparam_lookup = *Hamlibc::rot_confparam_lookup;
*rot_token_lookup = *Hamlibc::rot_token_lookup;
*rot_ext_func_foreach = *Hamlibc::rot_ext_func_foreach;
*rot_ext_level_foreach = *Hamlibc::rot_ext_level_foreach;
*rot_ext_parm_foreach = *Hamlibc::rot_ext_parm_foreach;
*rot_ext_lookup = *Hamlibc::rot_ext_lookup;
*rot_ext_lookup_tok = *Hamlibc::rot_ext_lookup_tok;
*rot_ext_token_lookup = *Hamlibc::rot_ext_token_lookup;
*rot_get_caps = *Hamlibc::rot_get_caps;
*qrb = *Hamlibc::qrb;
*distance_long_path = *Hamlibc::distance_long_path;
*azimuth_long_path = *Hamlibc::azimuth_long_path;
*longlat2locator = *Hamlibc::longlat2locator;
*locator2longlat = *Hamlibc::locator2longlat;
*dms2dec = *Hamlibc::dms2dec;
*dec2dms = *Hamlibc::dec2dms;
*dec2dmmm = *Hamlibc::dec2dmmm;
*dmmm2dec = *Hamlibc::dmmm2dec;
*rot_parse_func = *Hamlibc::rot_parse_func;
*rot_parse_level = *Hamlibc::rot_parse_level;
*rot_parse_parm = *Hamlibc::rot_parse_parm;
*rot_strfunc = *Hamlibc::rot_strfunc;
*rot_strlevel = *Hamlibc::rot_strlevel;
*rot_strparm = *Hamlibc::rot_strparm;
*rot_strstatus = *Hamlibc::rot_strstatus;

############# Class : Hamlib::confparams ##############

package Hamlib::confparams;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_token_get = *Hamlibc::confparams_token_get;
*swig_token_set = *Hamlibc::confparams_token_set;
*swig_name_get = *Hamlibc::confparams_name_get;
*swig_name_set = *Hamlibc::confparams_name_set;
*swig_label_get = *Hamlibc::confparams_label_get;
*swig_label_set = *Hamlibc::confparams_label_set;
*swig_tooltip_get = *Hamlibc::confparams_tooltip_get;
*swig_tooltip_set = *Hamlibc::confparams_tooltip_set;
*swig_dflt_get = *Hamlibc::confparams_dflt_get;
*swig_dflt_set = *Hamlibc::confparams_dflt_set;
*swig_type_get = *Hamlibc::confparams_type_get;
*swig_type_set = *Hamlibc::confparams_type_set;
*swig_u_get = *Hamlibc::confparams_u_get;
*swig_u_set = *Hamlibc::confparams_u_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_confparams(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_confparams($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::confparams_u ##############

package Hamlib::confparams_u;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_n_get = *Hamlibc::confparams_u_n_get;
*swig_n_set = *Hamlibc::confparams_u_n_set;
*swig_c_get = *Hamlibc::confparams_u_c_get;
*swig_c_set = *Hamlibc::confparams_u_c_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_confparams_u(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_confparams_u($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::confparams_u_c ##############

package Hamlib::confparams_u_c;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_combostr_get = *Hamlibc::confparams_u_c_combostr_get;
*swig_combostr_set = *Hamlibc::confparams_u_c_combostr_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_confparams_u_c(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_confparams_u_c($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::confparams_u_n ##############

package Hamlib::confparams_u_n;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_min_get = *Hamlibc::confparams_u_n_min_get;
*swig_min_set = *Hamlibc::confparams_u_n_min_set;
*swig_max_get = *Hamlibc::confparams_u_n_max_get;
*swig_max_set = *Hamlibc::confparams_u_n_max_set;
*swig_step_get = *Hamlibc::confparams_u_n_step_get;
*swig_step_set = *Hamlibc::confparams_u_n_step_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_confparams_u_n(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_confparams_u_n($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::value_t ##############

package Hamlib::value_t;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_i_get = *Hamlibc::value_t_i_get;
*swig_i_set = *Hamlibc::value_t_i_set;
*swig_f_get = *Hamlibc::value_t_f_get;
*swig_f_set = *Hamlibc::value_t_f_set;
*swig_s_get = *Hamlibc::value_t_s_get;
*swig_s_set = *Hamlibc::value_t_s_set;
*swig_cs_get = *Hamlibc::value_t_cs_get;
*swig_cs_set = *Hamlibc::value_t_cs_set;
*swig_b_get = *Hamlibc::value_t_b_get;
*swig_b_set = *Hamlibc::value_t_b_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_value_t(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_value_t($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::value_t_b ##############

package Hamlib::value_t_b;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_l_get = *Hamlibc::value_t_b_l_get;
*swig_l_set = *Hamlibc::value_t_b_l_set;
*swig_d_get = *Hamlibc::value_t_b_d_get;
*swig_d_set = *Hamlibc::value_t_b_d_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_value_t_b(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_value_t_b($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::freq_range_t ##############

package Hamlib::freq_range_t;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_startf_get = *Hamlibc::freq_range_t_startf_get;
*swig_startf_set = *Hamlibc::freq_range_t_startf_set;
*swig_endf_get = *Hamlibc::freq_range_t_endf_get;
*swig_endf_set = *Hamlibc::freq_range_t_endf_set;
*swig_modes_get = *Hamlibc::freq_range_t_modes_get;
*swig_modes_set = *Hamlibc::freq_range_t_modes_set;
*swig_low_power_get = *Hamlibc::freq_range_t_low_power_get;
*swig_low_power_set = *Hamlibc::freq_range_t_low_power_set;
*swig_high_power_get = *Hamlibc::freq_range_t_high_power_get;
*swig_high_power_set = *Hamlibc::freq_range_t_high_power_set;
*swig_vfo_get = *Hamlibc::freq_range_t_vfo_get;
*swig_vfo_set = *Hamlibc::freq_range_t_vfo_set;
*swig_ant_get = *Hamlibc::freq_range_t_ant_get;
*swig_ant_set = *Hamlibc::freq_range_t_ant_set;
*swig_label_get = *Hamlibc::freq_range_t_label_get;
*swig_label_set = *Hamlibc::freq_range_t_label_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_freq_range_t(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_freq_range_t($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::tuning_step_list ##############

package Hamlib::tuning_step_list;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_modes_get = *Hamlibc::tuning_step_list_modes_get;
*swig_modes_set = *Hamlibc::tuning_step_list_modes_set;
*swig_ts_get = *Hamlibc::tuning_step_list_ts_get;
*swig_ts_set = *Hamlibc::tuning_step_list_ts_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_tuning_step_list(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_tuning_step_list($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::filter_list ##############

package Hamlib::filter_list;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_modes_get = *Hamlibc::filter_list_modes_get;
*swig_modes_set = *Hamlibc::filter_list_modes_set;
*swig_width_get = *Hamlibc::filter_list_width_get;
*swig_width_set = *Hamlibc::filter_list_width_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_filter_list(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_filter_list($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::ext_list ##############

package Hamlib::ext_list;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_token_get = *Hamlibc::ext_list_token_get;
*swig_token_set = *Hamlibc::ext_list_token_set;
*swig_val_get = *Hamlibc::ext_list_val_get;
*swig_val_set = *Hamlibc::ext_list_val_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_ext_list(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_ext_list($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::channel ##############

package Hamlib::channel;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_channel_num_get = *Hamlibc::channel_channel_num_get;
*swig_channel_num_set = *Hamlibc::channel_channel_num_set;
*swig_bank_num_get = *Hamlibc::channel_bank_num_get;
*swig_bank_num_set = *Hamlibc::channel_bank_num_set;
*swig_vfo_get = *Hamlibc::channel_vfo_get;
*swig_vfo_set = *Hamlibc::channel_vfo_set;
*swig_ant_get = *Hamlibc::channel_ant_get;
*swig_ant_set = *Hamlibc::channel_ant_set;
*swig_freq_get = *Hamlibc::channel_freq_get;
*swig_freq_set = *Hamlibc::channel_freq_set;
*swig_mode_get = *Hamlibc::channel_mode_get;
*swig_mode_set = *Hamlibc::channel_mode_set;
*swig_width_get = *Hamlibc::channel_width_get;
*swig_width_set = *Hamlibc::channel_width_set;
*swig_tx_freq_get = *Hamlibc::channel_tx_freq_get;
*swig_tx_freq_set = *Hamlibc::channel_tx_freq_set;
*swig_tx_mode_get = *Hamlibc::channel_tx_mode_get;
*swig_tx_mode_set = *Hamlibc::channel_tx_mode_set;
*swig_tx_width_get = *Hamlibc::channel_tx_width_get;
*swig_tx_width_set = *Hamlibc::channel_tx_width_set;
*swig_split_get = *Hamlibc::channel_split_get;
*swig_split_set = *Hamlibc::channel_split_set;
*swig_tx_vfo_get = *Hamlibc::channel_tx_vfo_get;
*swig_tx_vfo_set = *Hamlibc::channel_tx_vfo_set;
*swig_rptr_shift_get = *Hamlibc::channel_rptr_shift_get;
*swig_rptr_shift_set = *Hamlibc::channel_rptr_shift_set;
*swig_rptr_offs_get = *Hamlibc::channel_rptr_offs_get;
*swig_rptr_offs_set = *Hamlibc::channel_rptr_offs_set;
*swig_tuning_step_get = *Hamlibc::channel_tuning_step_get;
*swig_tuning_step_set = *Hamlibc::channel_tuning_step_set;
*swig_rit_get = *Hamlibc::channel_rit_get;
*swig_rit_set = *Hamlibc::channel_rit_set;
*swig_xit_get = *Hamlibc::channel_xit_get;
*swig_xit_set = *Hamlibc::channel_xit_set;
*swig_funcs_get = *Hamlibc::channel_funcs_get;
*swig_funcs_set = *Hamlibc::channel_funcs_set;
*swig_levels_get = *Hamlibc::channel_levels_get;
*swig_levels_set = *Hamlibc::channel_levels_set;
*swig_ctcss_tone_get = *Hamlibc::channel_ctcss_tone_get;
*swig_ctcss_tone_set = *Hamlibc::channel_ctcss_tone_set;
*swig_ctcss_sql_get = *Hamlibc::channel_ctcss_sql_get;
*swig_ctcss_sql_set = *Hamlibc::channel_ctcss_sql_set;
*swig_dcs_code_get = *Hamlibc::channel_dcs_code_get;
*swig_dcs_code_set = *Hamlibc::channel_dcs_code_set;
*swig_dcs_sql_get = *Hamlibc::channel_dcs_sql_get;
*swig_dcs_sql_set = *Hamlibc::channel_dcs_sql_set;
*swig_scan_group_get = *Hamlibc::channel_scan_group_get;
*swig_scan_group_set = *Hamlibc::channel_scan_group_set;
*swig_flags_get = *Hamlibc::channel_flags_get;
*swig_flags_set = *Hamlibc::channel_flags_set;
*swig_channel_desc_get = *Hamlibc::channel_channel_desc_get;
*swig_channel_desc_set = *Hamlibc::channel_channel_desc_set;
*swig_ext_levels_get = *Hamlibc::channel_ext_levels_get;
*swig_ext_levels_set = *Hamlibc::channel_ext_levels_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_channel(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_channel($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::channel_cap ##############

package Hamlib::channel_cap;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_bank_num_get = *Hamlibc::channel_cap_bank_num_get;
*swig_bank_num_set = *Hamlibc::channel_cap_bank_num_set;
*swig_vfo_get = *Hamlibc::channel_cap_vfo_get;
*swig_vfo_set = *Hamlibc::channel_cap_vfo_set;
*swig_ant_get = *Hamlibc::channel_cap_ant_get;
*swig_ant_set = *Hamlibc::channel_cap_ant_set;
*swig_freq_get = *Hamlibc::channel_cap_freq_get;
*swig_freq_set = *Hamlibc::channel_cap_freq_set;
*swig_mode_get = *Hamlibc::channel_cap_mode_get;
*swig_mode_set = *Hamlibc::channel_cap_mode_set;
*swig_width_get = *Hamlibc::channel_cap_width_get;
*swig_width_set = *Hamlibc::channel_cap_width_set;
*swig_tx_freq_get = *Hamlibc::channel_cap_tx_freq_get;
*swig_tx_freq_set = *Hamlibc::channel_cap_tx_freq_set;
*swig_tx_mode_get = *Hamlibc::channel_cap_tx_mode_get;
*swig_tx_mode_set = *Hamlibc::channel_cap_tx_mode_set;
*swig_tx_width_get = *Hamlibc::channel_cap_tx_width_get;
*swig_tx_width_set = *Hamlibc::channel_cap_tx_width_set;
*swig_split_get = *Hamlibc::channel_cap_split_get;
*swig_split_set = *Hamlibc::channel_cap_split_set;
*swig_tx_vfo_get = *Hamlibc::channel_cap_tx_vfo_get;
*swig_tx_vfo_set = *Hamlibc::channel_cap_tx_vfo_set;
*swig_rptr_shift_get = *Hamlibc::channel_cap_rptr_shift_get;
*swig_rptr_shift_set = *Hamlibc::channel_cap_rptr_shift_set;
*swig_rptr_offs_get = *Hamlibc::channel_cap_rptr_offs_get;
*swig_rptr_offs_set = *Hamlibc::channel_cap_rptr_offs_set;
*swig_tuning_step_get = *Hamlibc::channel_cap_tuning_step_get;
*swig_tuning_step_set = *Hamlibc::channel_cap_tuning_step_set;
*swig_rit_get = *Hamlibc::channel_cap_rit_get;
*swig_rit_set = *Hamlibc::channel_cap_rit_set;
*swig_xit_get = *Hamlibc::channel_cap_xit_get;
*swig_xit_set = *Hamlibc::channel_cap_xit_set;
*swig_funcs_get = *Hamlibc::channel_cap_funcs_get;
*swig_funcs_set = *Hamlibc::channel_cap_funcs_set;
*swig_levels_get = *Hamlibc::channel_cap_levels_get;
*swig_levels_set = *Hamlibc::channel_cap_levels_set;
*swig_ctcss_tone_get = *Hamlibc::channel_cap_ctcss_tone_get;
*swig_ctcss_tone_set = *Hamlibc::channel_cap_ctcss_tone_set;
*swig_ctcss_sql_get = *Hamlibc::channel_cap_ctcss_sql_get;
*swig_ctcss_sql_set = *Hamlibc::channel_cap_ctcss_sql_set;
*swig_dcs_code_get = *Hamlibc::channel_cap_dcs_code_get;
*swig_dcs_code_set = *Hamlibc::channel_cap_dcs_code_set;
*swig_dcs_sql_get = *Hamlibc::channel_cap_dcs_sql_get;
*swig_dcs_sql_set = *Hamlibc::channel_cap_dcs_sql_set;
*swig_scan_group_get = *Hamlibc::channel_cap_scan_group_get;
*swig_scan_group_set = *Hamlibc::channel_cap_scan_group_set;
*swig_flags_get = *Hamlibc::channel_cap_flags_get;
*swig_flags_set = *Hamlibc::channel_cap_flags_set;
*swig_channel_desc_get = *Hamlibc::channel_cap_channel_desc_get;
*swig_channel_desc_set = *Hamlibc::channel_cap_channel_desc_set;
*swig_ext_levels_get = *Hamlibc::channel_cap_ext_levels_get;
*swig_ext_levels_set = *Hamlibc::channel_cap_ext_levels_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_channel_cap(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_channel_cap($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::chan_list ##############

package Hamlib::chan_list;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_startc_get = *Hamlibc::chan_list_startc_get;
*swig_startc_set = *Hamlibc::chan_list_startc_set;
*swig_endc_get = *Hamlibc::chan_list_endc_get;
*swig_endc_set = *Hamlibc::chan_list_endc_set;
*swig_type_get = *Hamlibc::chan_list_type_get;
*swig_type_set = *Hamlibc::chan_list_type_set;
*swig_mem_caps_get = *Hamlibc::chan_list_mem_caps_get;
*swig_mem_caps_set = *Hamlibc::chan_list_mem_caps_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_chan_list(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_chan_list($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::gran ##############

package Hamlib::gran;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_min_get = *Hamlibc::gran_min_get;
*swig_min_set = *Hamlibc::gran_min_set;
*swig_max_get = *Hamlibc::gran_max_get;
*swig_max_set = *Hamlibc::gran_max_set;
*swig_step_get = *Hamlibc::gran_step_get;
*swig_step_set = *Hamlibc::gran_step_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_gran(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_gran($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::cal_table ##############

package Hamlib::cal_table;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_size_get = *Hamlibc::cal_table_size_get;
*swig_size_set = *Hamlibc::cal_table_size_set;
*swig_table_get = *Hamlibc::cal_table_table_get;
*swig_table_set = *Hamlibc::cal_table_table_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_cal_table(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_cal_table($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::cal_table_table ##############

package Hamlib::cal_table_table;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_raw_get = *Hamlibc::cal_table_table_raw_get;
*swig_raw_set = *Hamlibc::cal_table_table_raw_set;
*swig_val_get = *Hamlibc::cal_table_table_val_get;
*swig_val_set = *Hamlibc::cal_table_table_val_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_cal_table_table(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_cal_table_table($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::cal_table_float ##############

package Hamlib::cal_table_float;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_size_get = *Hamlibc::cal_table_float_size_get;
*swig_size_set = *Hamlibc::cal_table_float_size_set;
*swig_table_get = *Hamlibc::cal_table_float_table_get;
*swig_table_set = *Hamlibc::cal_table_float_table_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_cal_table_float(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_cal_table_float($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::cal_table_float_table ##############

package Hamlib::cal_table_float_table;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_raw_get = *Hamlibc::cal_table_float_table_raw_get;
*swig_raw_set = *Hamlibc::cal_table_float_table_raw_set;
*swig_val_get = *Hamlibc::cal_table_float_table_val_get;
*swig_val_set = *Hamlibc::cal_table_float_table_val_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_cal_table_float_table(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_cal_table_float_table($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::rig_spectrum_scope ##############

package Hamlib::rig_spectrum_scope;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_id_get = *Hamlibc::rig_spectrum_scope_id_get;
*swig_id_set = *Hamlibc::rig_spectrum_scope_id_set;
*swig_name_get = *Hamlibc::rig_spectrum_scope_name_get;
*swig_name_set = *Hamlibc::rig_spectrum_scope_name_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_rig_spectrum_scope(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_rig_spectrum_scope($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::rig_spectrum_avg_mode ##############

package Hamlib::rig_spectrum_avg_mode;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_id_get = *Hamlibc::rig_spectrum_avg_mode_id_get;
*swig_id_set = *Hamlibc::rig_spectrum_avg_mode_id_set;
*swig_name_get = *Hamlibc::rig_spectrum_avg_mode_name_get;
*swig_name_set = *Hamlibc::rig_spectrum_avg_mode_name_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_rig_spectrum_avg_mode(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_rig_spectrum_avg_mode($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::rig_spectrum_line ##############

package Hamlib::rig_spectrum_line;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_id_get = *Hamlibc::rig_spectrum_line_id_get;
*swig_id_set = *Hamlibc::rig_spectrum_line_id_set;
*swig_data_level_min_get = *Hamlibc::rig_spectrum_line_data_level_min_get;
*swig_data_level_min_set = *Hamlibc::rig_spectrum_line_data_level_min_set;
*swig_data_level_max_get = *Hamlibc::rig_spectrum_line_data_level_max_get;
*swig_data_level_max_set = *Hamlibc::rig_spectrum_line_data_level_max_set;
*swig_signal_strength_min_get = *Hamlibc::rig_spectrum_line_signal_strength_min_get;
*swig_signal_strength_min_set = *Hamlibc::rig_spectrum_line_signal_strength_min_set;
*swig_signal_strength_max_get = *Hamlibc::rig_spectrum_line_signal_strength_max_get;
*swig_signal_strength_max_set = *Hamlibc::rig_spectrum_line_signal_strength_max_set;
*swig_spectrum_mode_get = *Hamlibc::rig_spectrum_line_spectrum_mode_get;
*swig_spectrum_mode_set = *Hamlibc::rig_spectrum_line_spectrum_mode_set;
*swig_center_freq_get = *Hamlibc::rig_spectrum_line_center_freq_get;
*swig_center_freq_set = *Hamlibc::rig_spectrum_line_center_freq_set;
*swig_span_freq_get = *Hamlibc::rig_spectrum_line_span_freq_get;
*swig_span_freq_set = *Hamlibc::rig_spectrum_line_span_freq_set;
*swig_low_edge_freq_get = *Hamlibc::rig_spectrum_line_low_edge_freq_get;
*swig_low_edge_freq_set = *Hamlibc::rig_spectrum_line_low_edge_freq_set;
*swig_high_edge_freq_get = *Hamlibc::rig_spectrum_line_high_edge_freq_get;
*swig_high_edge_freq_set = *Hamlibc::rig_spectrum_line_high_edge_freq_set;
*swig_spectrum_data_length_get = *Hamlibc::rig_spectrum_line_spectrum_data_length_get;
*swig_spectrum_data_length_set = *Hamlibc::rig_spectrum_line_spectrum_data_length_set;
*swig_spectrum_data_get = *Hamlibc::rig_spectrum_line_spectrum_data_get;
*swig_spectrum_data_set = *Hamlibc::rig_spectrum_line_spectrum_data_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_rig_spectrum_line(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_rig_spectrum_line($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::rig_caps ##############

package Hamlib::rig_caps;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_rig_model_get = *Hamlibc::rig_caps_rig_model_get;
*swig_rig_model_set = *Hamlibc::rig_caps_rig_model_set;
*swig_model_name_get = *Hamlibc::rig_caps_model_name_get;
*swig_model_name_set = *Hamlibc::rig_caps_model_name_set;
*swig_mfg_name_get = *Hamlibc::rig_caps_mfg_name_get;
*swig_mfg_name_set = *Hamlibc::rig_caps_mfg_name_set;
*swig_version_get = *Hamlibc::rig_caps_version_get;
*swig_version_set = *Hamlibc::rig_caps_version_set;
*swig_copyright_get = *Hamlibc::rig_caps_copyright_get;
*swig_copyright_set = *Hamlibc::rig_caps_copyright_set;
*swig_status_get = *Hamlibc::rig_caps_status_get;
*swig_status_set = *Hamlibc::rig_caps_status_set;
*swig_rig_type_get = *Hamlibc::rig_caps_rig_type_get;
*swig_rig_type_set = *Hamlibc::rig_caps_rig_type_set;
*swig_ptt_type_get = *Hamlibc::rig_caps_ptt_type_get;
*swig_ptt_type_set = *Hamlibc::rig_caps_ptt_type_set;
*swig_dcd_type_get = *Hamlibc::rig_caps_dcd_type_get;
*swig_dcd_type_set = *Hamlibc::rig_caps_dcd_type_set;
*swig_port_type_get = *Hamlibc::rig_caps_port_type_get;
*swig_port_type_set = *Hamlibc::rig_caps_port_type_set;
*swig_serial_rate_min_get = *Hamlibc::rig_caps_serial_rate_min_get;
*swig_serial_rate_min_set = *Hamlibc::rig_caps_serial_rate_min_set;
*swig_serial_rate_max_get = *Hamlibc::rig_caps_serial_rate_max_get;
*swig_serial_rate_max_set = *Hamlibc::rig_caps_serial_rate_max_set;
*swig_serial_data_bits_get = *Hamlibc::rig_caps_serial_data_bits_get;
*swig_serial_data_bits_set = *Hamlibc::rig_caps_serial_data_bits_set;
*swig_serial_stop_bits_get = *Hamlibc::rig_caps_serial_stop_bits_get;
*swig_serial_stop_bits_set = *Hamlibc::rig_caps_serial_stop_bits_set;
*swig_serial_parity_get = *Hamlibc::rig_caps_serial_parity_get;
*swig_serial_parity_set = *Hamlibc::rig_caps_serial_parity_set;
*swig_serial_handshake_get = *Hamlibc::rig_caps_serial_handshake_get;
*swig_serial_handshake_set = *Hamlibc::rig_caps_serial_handshake_set;
*swig_write_delay_get = *Hamlibc::rig_caps_write_delay_get;
*swig_write_delay_set = *Hamlibc::rig_caps_write_delay_set;
*swig_post_write_delay_get = *Hamlibc::rig_caps_post_write_delay_get;
*swig_post_write_delay_set = *Hamlibc::rig_caps_post_write_delay_set;
*swig_timeout_get = *Hamlibc::rig_caps_timeout_get;
*swig_timeout_set = *Hamlibc::rig_caps_timeout_set;
*swig_retry_get = *Hamlibc::rig_caps_retry_get;
*swig_retry_set = *Hamlibc::rig_caps_retry_set;
*swig_has_get_func_get = *Hamlibc::rig_caps_has_get_func_get;
*swig_has_get_func_set = *Hamlibc::rig_caps_has_get_func_set;
*swig_has_set_func_get = *Hamlibc::rig_caps_has_set_func_get;
*swig_has_set_func_set = *Hamlibc::rig_caps_has_set_func_set;
*swig_has_get_level_get = *Hamlibc::rig_caps_has_get_level_get;
*swig_has_get_level_set = *Hamlibc::rig_caps_has_get_level_set;
*swig_has_set_level_get = *Hamlibc::rig_caps_has_set_level_get;
*swig_has_set_level_set = *Hamlibc::rig_caps_has_set_level_set;
*swig_has_get_parm_get = *Hamlibc::rig_caps_has_get_parm_get;
*swig_has_get_parm_set = *Hamlibc::rig_caps_has_get_parm_set;
*swig_has_set_parm_get = *Hamlibc::rig_caps_has_set_parm_get;
*swig_has_set_parm_set = *Hamlibc::rig_caps_has_set_parm_set;
*swig_level_gran_get = *Hamlibc::rig_caps_level_gran_get;
*swig_level_gran_set = *Hamlibc::rig_caps_level_gran_set;
*swig_parm_gran_get = *Hamlibc::rig_caps_parm_gran_get;
*swig_parm_gran_set = *Hamlibc::rig_caps_parm_gran_set;
*swig_extparms_get = *Hamlibc::rig_caps_extparms_get;
*swig_extparms_set = *Hamlibc::rig_caps_extparms_set;
*swig_extlevels_get = *Hamlibc::rig_caps_extlevels_get;
*swig_extlevels_set = *Hamlibc::rig_caps_extlevels_set;
*swig_extfuncs_get = *Hamlibc::rig_caps_extfuncs_get;
*swig_extfuncs_set = *Hamlibc::rig_caps_extfuncs_set;
*swig_ext_tokens_get = *Hamlibc::rig_caps_ext_tokens_get;
*swig_ext_tokens_set = *Hamlibc::rig_caps_ext_tokens_set;
*swig_ctcss_list_get = *Hamlibc::rig_caps_ctcss_list_get;
*swig_ctcss_list_set = *Hamlibc::rig_caps_ctcss_list_set;
*swig_dcs_list_get = *Hamlibc::rig_caps_dcs_list_get;
*swig_dcs_list_set = *Hamlibc::rig_caps_dcs_list_set;
*swig_preamp_get = *Hamlibc::rig_caps_preamp_get;
*swig_preamp_set = *Hamlibc::rig_caps_preamp_set;
*swig_attenuator_get = *Hamlibc::rig_caps_attenuator_get;
*swig_attenuator_set = *Hamlibc::rig_caps_attenuator_set;
*swig_max_rit_get = *Hamlibc::rig_caps_max_rit_get;
*swig_max_rit_set = *Hamlibc::rig_caps_max_rit_set;
*swig_max_xit_get = *Hamlibc::rig_caps_max_xit_get;
*swig_max_xit_set = *Hamlibc::rig_caps_max_xit_set;
*swig_max_ifshift_get = *Hamlibc::rig_caps_max_ifshift_get;
*swig_max_ifshift_set = *Hamlibc::rig_caps_max_ifshift_set;
*swig_agc_level_count_get = *Hamlibc::rig_caps_agc_level_count_get;
*swig_agc_level_count_set = *Hamlibc::rig_caps_agc_level_count_set;
*swig_agc_levels_get = *Hamlibc::rig_caps_agc_levels_get;
*swig_agc_levels_set = *Hamlibc::rig_caps_agc_levels_set;
*swig_announces_get = *Hamlibc::rig_caps_announces_get;
*swig_announces_set = *Hamlibc::rig_caps_announces_set;
*swig_vfo_ops_get = *Hamlibc::rig_caps_vfo_ops_get;
*swig_vfo_ops_set = *Hamlibc::rig_caps_vfo_ops_set;
*swig_scan_ops_get = *Hamlibc::rig_caps_scan_ops_get;
*swig_scan_ops_set = *Hamlibc::rig_caps_scan_ops_set;
*swig_targetable_vfo_get = *Hamlibc::rig_caps_targetable_vfo_get;
*swig_targetable_vfo_set = *Hamlibc::rig_caps_targetable_vfo_set;
*swig_transceive_get = *Hamlibc::rig_caps_transceive_get;
*swig_transceive_set = *Hamlibc::rig_caps_transceive_set;
*swig_bank_qty_get = *Hamlibc::rig_caps_bank_qty_get;
*swig_bank_qty_set = *Hamlibc::rig_caps_bank_qty_set;
*swig_chan_desc_sz_get = *Hamlibc::rig_caps_chan_desc_sz_get;
*swig_chan_desc_sz_set = *Hamlibc::rig_caps_chan_desc_sz_set;
*swig_chan_list_get = *Hamlibc::rig_caps_chan_list_get;
*swig_chan_list_set = *Hamlibc::rig_caps_chan_list_set;
*swig_rx_range_list1_get = *Hamlibc::rig_caps_rx_range_list1_get;
*swig_rx_range_list1_set = *Hamlibc::rig_caps_rx_range_list1_set;
*swig_tx_range_list1_get = *Hamlibc::rig_caps_tx_range_list1_get;
*swig_tx_range_list1_set = *Hamlibc::rig_caps_tx_range_list1_set;
*swig_rx_range_list2_get = *Hamlibc::rig_caps_rx_range_list2_get;
*swig_rx_range_list2_set = *Hamlibc::rig_caps_rx_range_list2_set;
*swig_tx_range_list2_get = *Hamlibc::rig_caps_tx_range_list2_get;
*swig_tx_range_list2_set = *Hamlibc::rig_caps_tx_range_list2_set;
*swig_rx_range_list3_get = *Hamlibc::rig_caps_rx_range_list3_get;
*swig_rx_range_list3_set = *Hamlibc::rig_caps_rx_range_list3_set;
*swig_tx_range_list3_get = *Hamlibc::rig_caps_tx_range_list3_get;
*swig_tx_range_list3_set = *Hamlibc::rig_caps_tx_range_list3_set;
*swig_rx_range_list4_get = *Hamlibc::rig_caps_rx_range_list4_get;
*swig_rx_range_list4_set = *Hamlibc::rig_caps_rx_range_list4_set;
*swig_tx_range_list4_get = *Hamlibc::rig_caps_tx_range_list4_get;
*swig_tx_range_list4_set = *Hamlibc::rig_caps_tx_range_list4_set;
*swig_rx_range_list5_get = *Hamlibc::rig_caps_rx_range_list5_get;
*swig_rx_range_list5_set = *Hamlibc::rig_caps_rx_range_list5_set;
*swig_tx_range_list5_get = *Hamlibc::rig_caps_tx_range_list5_get;
*swig_tx_range_list5_set = *Hamlibc::rig_caps_tx_range_list5_set;
*swig_tuning_steps_get = *Hamlibc::rig_caps_tuning_steps_get;
*swig_tuning_steps_set = *Hamlibc::rig_caps_tuning_steps_set;
*swig_filters_get = *Hamlibc::rig_caps_filters_get;
*swig_filters_set = *Hamlibc::rig_caps_filters_set;
*swig_str_cal_get = *Hamlibc::rig_caps_str_cal_get;
*swig_str_cal_set = *Hamlibc::rig_caps_str_cal_set;
*swig_swr_cal_get = *Hamlibc::rig_caps_swr_cal_get;
*swig_swr_cal_set = *Hamlibc::rig_caps_swr_cal_set;
*swig_alc_cal_get = *Hamlibc::rig_caps_alc_cal_get;
*swig_alc_cal_set = *Hamlibc::rig_caps_alc_cal_set;
*swig_rfpower_meter_cal_get = *Hamlibc::rig_caps_rfpower_meter_cal_get;
*swig_rfpower_meter_cal_set = *Hamlibc::rig_caps_rfpower_meter_cal_set;
*swig_comp_meter_cal_get = *Hamlibc::rig_caps_comp_meter_cal_get;
*swig_comp_meter_cal_set = *Hamlibc::rig_caps_comp_meter_cal_set;
*swig_vd_meter_cal_get = *Hamlibc::rig_caps_vd_meter_cal_get;
*swig_vd_meter_cal_set = *Hamlibc::rig_caps_vd_meter_cal_set;
*swig_id_meter_cal_get = *Hamlibc::rig_caps_id_meter_cal_get;
*swig_id_meter_cal_set = *Hamlibc::rig_caps_id_meter_cal_set;
*swig_spectrum_scopes_get = *Hamlibc::rig_caps_spectrum_scopes_get;
*swig_spectrum_scopes_set = *Hamlibc::rig_caps_spectrum_scopes_set;
*swig_spectrum_modes_get = *Hamlibc::rig_caps_spectrum_modes_get;
*swig_spectrum_modes_set = *Hamlibc::rig_caps_spectrum_modes_set;
*swig_spectrum_spans_get = *Hamlibc::rig_caps_spectrum_spans_get;
*swig_spectrum_spans_set = *Hamlibc::rig_caps_spectrum_spans_set;
*swig_spectrum_avg_modes_get = *Hamlibc::rig_caps_spectrum_avg_modes_get;
*swig_spectrum_avg_modes_set = *Hamlibc::rig_caps_spectrum_avg_modes_set;
*swig_spectrum_attenuator_get = *Hamlibc::rig_caps_spectrum_attenuator_get;
*swig_spectrum_attenuator_set = *Hamlibc::rig_caps_spectrum_attenuator_set;
*swig_cfgparams_get = *Hamlibc::rig_caps_cfgparams_get;
*swig_cfgparams_set = *Hamlibc::rig_caps_cfgparams_set;
*swig_priv_get = *Hamlibc::rig_caps_priv_get;
*swig_priv_set = *Hamlibc::rig_caps_priv_set;
*swig_rig_init_get = *Hamlibc::rig_caps_rig_init_get;
*swig_rig_init_set = *Hamlibc::rig_caps_rig_init_set;
*swig_set_freq_get = *Hamlibc::rig_caps_set_freq_get;
*swig_set_freq_set = *Hamlibc::rig_caps_set_freq_set;
*swig_get_freq_get = *Hamlibc::rig_caps_get_freq_get;
*swig_get_freq_set = *Hamlibc::rig_caps_get_freq_set;
*swig_set_mode_get = *Hamlibc::rig_caps_set_mode_get;
*swig_set_mode_set = *Hamlibc::rig_caps_set_mode_set;
*swig_get_mode_get = *Hamlibc::rig_caps_get_mode_get;
*swig_get_mode_set = *Hamlibc::rig_caps_get_mode_set;
*swig_set_vfo_get = *Hamlibc::rig_caps_set_vfo_get;
*swig_set_vfo_set = *Hamlibc::rig_caps_set_vfo_set;
*swig_get_vfo_get = *Hamlibc::rig_caps_get_vfo_get;
*swig_get_vfo_set = *Hamlibc::rig_caps_get_vfo_set;
*swig_set_ptt_get = *Hamlibc::rig_caps_set_ptt_get;
*swig_set_ptt_set = *Hamlibc::rig_caps_set_ptt_set;
*swig_get_ptt_get = *Hamlibc::rig_caps_get_ptt_get;
*swig_get_ptt_set = *Hamlibc::rig_caps_get_ptt_set;
*swig_get_dcd_get = *Hamlibc::rig_caps_get_dcd_get;
*swig_get_dcd_set = *Hamlibc::rig_caps_get_dcd_set;
*swig_set_rptr_shift_get = *Hamlibc::rig_caps_set_rptr_shift_get;
*swig_set_rptr_shift_set = *Hamlibc::rig_caps_set_rptr_shift_set;
*swig_get_rptr_shift_get = *Hamlibc::rig_caps_get_rptr_shift_get;
*swig_get_rptr_shift_set = *Hamlibc::rig_caps_get_rptr_shift_set;
*swig_set_rptr_offs_get = *Hamlibc::rig_caps_set_rptr_offs_get;
*swig_set_rptr_offs_set = *Hamlibc::rig_caps_set_rptr_offs_set;
*swig_get_rptr_offs_get = *Hamlibc::rig_caps_get_rptr_offs_get;
*swig_get_rptr_offs_set = *Hamlibc::rig_caps_get_rptr_offs_set;
*swig_set_split_freq_get = *Hamlibc::rig_caps_set_split_freq_get;
*swig_set_split_freq_set = *Hamlibc::rig_caps_set_split_freq_set;
*swig_get_split_freq_get = *Hamlibc::rig_caps_get_split_freq_get;
*swig_get_split_freq_set = *Hamlibc::rig_caps_get_split_freq_set;
*swig_set_split_mode_get = *Hamlibc::rig_caps_set_split_mode_get;
*swig_set_split_mode_set = *Hamlibc::rig_caps_set_split_mode_set;
*swig_get_split_mode_get = *Hamlibc::rig_caps_get_split_mode_get;
*swig_get_split_mode_set = *Hamlibc::rig_caps_get_split_mode_set;
*swig_set_split_freq_mode_get = *Hamlibc::rig_caps_set_split_freq_mode_get;
*swig_set_split_freq_mode_set = *Hamlibc::rig_caps_set_split_freq_mode_set;
*swig_get_split_freq_mode_get = *Hamlibc::rig_caps_get_split_freq_mode_get;
*swig_get_split_freq_mode_set = *Hamlibc::rig_caps_get_split_freq_mode_set;
*swig_set_split_vfo_get = *Hamlibc::rig_caps_set_split_vfo_get;
*swig_set_split_vfo_set = *Hamlibc::rig_caps_set_split_vfo_set;
*swig_get_split_vfo_get = *Hamlibc::rig_caps_get_split_vfo_get;
*swig_get_split_vfo_set = *Hamlibc::rig_caps_get_split_vfo_set;
*swig_set_rit_get = *Hamlibc::rig_caps_set_rit_get;
*swig_set_rit_set = *Hamlibc::rig_caps_set_rit_set;
*swig_get_rit_get = *Hamlibc::rig_caps_get_rit_get;
*swig_get_rit_set = *Hamlibc::rig_caps_get_rit_set;
*swig_set_xit_get = *Hamlibc::rig_caps_set_xit_get;
*swig_set_xit_set = *Hamlibc::rig_caps_set_xit_set;
*swig_get_xit_get = *Hamlibc::rig_caps_get_xit_get;
*swig_get_xit_set = *Hamlibc::rig_caps_get_xit_set;
*swig_set_ts_get = *Hamlibc::rig_caps_set_ts_get;
*swig_set_ts_set = *Hamlibc::rig_caps_set_ts_set;
*swig_get_ts_get = *Hamlibc::rig_caps_get_ts_get;
*swig_get_ts_set = *Hamlibc::rig_caps_get_ts_set;
*swig_set_dcs_code_get = *Hamlibc::rig_caps_set_dcs_code_get;
*swig_set_dcs_code_set = *Hamlibc::rig_caps_set_dcs_code_set;
*swig_get_dcs_code_get = *Hamlibc::rig_caps_get_dcs_code_get;
*swig_get_dcs_code_set = *Hamlibc::rig_caps_get_dcs_code_set;
*swig_set_tone_get = *Hamlibc::rig_caps_set_tone_get;
*swig_set_tone_set = *Hamlibc::rig_caps_set_tone_set;
*swig_get_tone_get = *Hamlibc::rig_caps_get_tone_get;
*swig_get_tone_set = *Hamlibc::rig_caps_get_tone_set;
*swig_set_ctcss_tone_get = *Hamlibc::rig_caps_set_ctcss_tone_get;
*swig_set_ctcss_tone_set = *Hamlibc::rig_caps_set_ctcss_tone_set;
*swig_get_ctcss_tone_get = *Hamlibc::rig_caps_get_ctcss_tone_get;
*swig_get_ctcss_tone_set = *Hamlibc::rig_caps_get_ctcss_tone_set;
*swig_set_dcs_sql_get = *Hamlibc::rig_caps_set_dcs_sql_get;
*swig_set_dcs_sql_set = *Hamlibc::rig_caps_set_dcs_sql_set;
*swig_get_dcs_sql_get = *Hamlibc::rig_caps_get_dcs_sql_get;
*swig_get_dcs_sql_set = *Hamlibc::rig_caps_get_dcs_sql_set;
*swig_set_tone_sql_get = *Hamlibc::rig_caps_set_tone_sql_get;
*swig_set_tone_sql_set = *Hamlibc::rig_caps_set_tone_sql_set;
*swig_get_tone_sql_get = *Hamlibc::rig_caps_get_tone_sql_get;
*swig_get_tone_sql_set = *Hamlibc::rig_caps_get_tone_sql_set;
*swig_set_ctcss_sql_get = *Hamlibc::rig_caps_set_ctcss_sql_get;
*swig_set_ctcss_sql_set = *Hamlibc::rig_caps_set_ctcss_sql_set;
*swig_get_ctcss_sql_get = *Hamlibc::rig_caps_get_ctcss_sql_get;
*swig_get_ctcss_sql_set = *Hamlibc::rig_caps_get_ctcss_sql_set;
*swig_power2mW_get = *Hamlibc::rig_caps_power2mW_get;
*swig_power2mW_set = *Hamlibc::rig_caps_power2mW_set;
*swig_mW2power_get = *Hamlibc::rig_caps_mW2power_get;
*swig_mW2power_set = *Hamlibc::rig_caps_mW2power_set;
*swig_set_powerstat_get = *Hamlibc::rig_caps_set_powerstat_get;
*swig_set_powerstat_set = *Hamlibc::rig_caps_set_powerstat_set;
*swig_get_powerstat_get = *Hamlibc::rig_caps_get_powerstat_get;
*swig_get_powerstat_set = *Hamlibc::rig_caps_get_powerstat_set;
*swig_reset_get = *Hamlibc::rig_caps_reset_get;
*swig_reset_set = *Hamlibc::rig_caps_reset_set;
*swig_set_ant_get = *Hamlibc::rig_caps_set_ant_get;
*swig_set_ant_set = *Hamlibc::rig_caps_set_ant_set;
*swig_get_ant_get = *Hamlibc::rig_caps_get_ant_get;
*swig_get_ant_set = *Hamlibc::rig_caps_get_ant_set;
*swig_set_level_get = *Hamlibc::rig_caps_set_level_get;
*swig_set_level_set = *Hamlibc::rig_caps_set_level_set;
*swig_get_level_get = *Hamlibc::rig_caps_get_level_get;
*swig_get_level_set = *Hamlibc::rig_caps_get_level_set;
*swig_set_func_get = *Hamlibc::rig_caps_set_func_get;
*swig_set_func_set = *Hamlibc::rig_caps_set_func_set;
*swig_get_func_get = *Hamlibc::rig_caps_get_func_get;
*swig_get_func_set = *Hamlibc::rig_caps_get_func_set;
*swig_set_parm_get = *Hamlibc::rig_caps_set_parm_get;
*swig_set_parm_set = *Hamlibc::rig_caps_set_parm_set;
*swig_get_parm_get = *Hamlibc::rig_caps_get_parm_get;
*swig_get_parm_set = *Hamlibc::rig_caps_get_parm_set;
*swig_set_ext_level_get = *Hamlibc::rig_caps_set_ext_level_get;
*swig_set_ext_level_set = *Hamlibc::rig_caps_set_ext_level_set;
*swig_get_ext_level_get = *Hamlibc::rig_caps_get_ext_level_get;
*swig_get_ext_level_set = *Hamlibc::rig_caps_get_ext_level_set;
*swig_set_ext_func_get = *Hamlibc::rig_caps_set_ext_func_get;
*swig_set_ext_func_set = *Hamlibc::rig_caps_set_ext_func_set;
*swig_get_ext_func_get = *Hamlibc::rig_caps_get_ext_func_get;
*swig_get_ext_func_set = *Hamlibc::rig_caps_get_ext_func_set;
*swig_set_ext_parm_get = *Hamlibc::rig_caps_set_ext_parm_get;
*swig_set_ext_parm_set = *Hamlibc::rig_caps_set_ext_parm_set;
*swig_get_ext_parm_get = *Hamlibc::rig_caps_get_ext_parm_get;
*swig_get_ext_parm_set = *Hamlibc::rig_caps_get_ext_parm_set;
*swig_set_conf_get = *Hamlibc::rig_caps_set_conf_get;
*swig_set_conf_set = *Hamlibc::rig_caps_set_conf_set;
*swig_get_conf_get = *Hamlibc::rig_caps_get_conf_get;
*swig_get_conf_set = *Hamlibc::rig_caps_get_conf_set;
*swig_send_dtmf_get = *Hamlibc::rig_caps_send_dtmf_get;
*swig_send_dtmf_set = *Hamlibc::rig_caps_send_dtmf_set;
*swig_recv_dtmf_get = *Hamlibc::rig_caps_recv_dtmf_get;
*swig_recv_dtmf_set = *Hamlibc::rig_caps_recv_dtmf_set;
*swig_send_morse_get = *Hamlibc::rig_caps_send_morse_get;
*swig_send_morse_set = *Hamlibc::rig_caps_send_morse_set;
*swig_stop_morse_get = *Hamlibc::rig_caps_stop_morse_get;
*swig_stop_morse_set = *Hamlibc::rig_caps_stop_morse_set;
*swig_wait_morse_get = *Hamlibc::rig_caps_wait_morse_get;
*swig_wait_morse_set = *Hamlibc::rig_caps_wait_morse_set;
*swig_send_voice_mem_get = *Hamlibc::rig_caps_send_voice_mem_get;
*swig_send_voice_mem_set = *Hamlibc::rig_caps_send_voice_mem_set;
*swig_set_bank_get = *Hamlibc::rig_caps_set_bank_get;
*swig_set_bank_set = *Hamlibc::rig_caps_set_bank_set;
*swig_set_mem_get = *Hamlibc::rig_caps_set_mem_get;
*swig_set_mem_set = *Hamlibc::rig_caps_set_mem_set;
*swig_get_mem_get = *Hamlibc::rig_caps_get_mem_get;
*swig_get_mem_set = *Hamlibc::rig_caps_get_mem_set;
*swig_vfo_op_get = *Hamlibc::rig_caps_vfo_op_get;
*swig_vfo_op_set = *Hamlibc::rig_caps_vfo_op_set;
*swig_scan_get = *Hamlibc::rig_caps_scan_get;
*swig_scan_set = *Hamlibc::rig_caps_scan_set;
*swig_set_trn_get = *Hamlibc::rig_caps_set_trn_get;
*swig_set_trn_set = *Hamlibc::rig_caps_set_trn_set;
*swig_get_trn_get = *Hamlibc::rig_caps_get_trn_get;
*swig_get_trn_set = *Hamlibc::rig_caps_get_trn_set;
*swig_decode_event_get = *Hamlibc::rig_caps_decode_event_get;
*swig_decode_event_set = *Hamlibc::rig_caps_decode_event_set;
*swig_set_channel_get = *Hamlibc::rig_caps_set_channel_get;
*swig_set_channel_set = *Hamlibc::rig_caps_set_channel_set;
*swig_get_channel_get = *Hamlibc::rig_caps_get_channel_get;
*swig_get_channel_set = *Hamlibc::rig_caps_get_channel_set;
*swig_get_info_get = *Hamlibc::rig_caps_get_info_get;
*swig_get_info_set = *Hamlibc::rig_caps_get_info_set;
*swig_set_chan_all_cb_get = *Hamlibc::rig_caps_set_chan_all_cb_get;
*swig_set_chan_all_cb_set = *Hamlibc::rig_caps_set_chan_all_cb_set;
*swig_get_chan_all_cb_get = *Hamlibc::rig_caps_get_chan_all_cb_get;
*swig_get_chan_all_cb_set = *Hamlibc::rig_caps_get_chan_all_cb_set;
*swig_set_mem_all_cb_get = *Hamlibc::rig_caps_set_mem_all_cb_get;
*swig_set_mem_all_cb_set = *Hamlibc::rig_caps_set_mem_all_cb_set;
*swig_get_mem_all_cb_get = *Hamlibc::rig_caps_get_mem_all_cb_get;
*swig_get_mem_all_cb_set = *Hamlibc::rig_caps_get_mem_all_cb_set;
*swig_set_vfo_opt_get = *Hamlibc::rig_caps_set_vfo_opt_get;
*swig_set_vfo_opt_set = *Hamlibc::rig_caps_set_vfo_opt_set;
*swig_set_clock_get = *Hamlibc::rig_caps_set_clock_get;
*swig_set_clock_set = *Hamlibc::rig_caps_set_clock_set;
*swig_get_clock_get = *Hamlibc::rig_caps_get_clock_get;
*swig_get_clock_set = *Hamlibc::rig_caps_get_clock_set;
*swig_clone_combo_set_get = *Hamlibc::rig_caps_clone_combo_set_get;
*swig_clone_combo_set_set = *Hamlibc::rig_caps_clone_combo_set_set;
*swig_clone_combo_get_get = *Hamlibc::rig_caps_clone_combo_get_get;
*swig_clone_combo_get_set = *Hamlibc::rig_caps_clone_combo_get_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_rig_caps(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_rig_caps($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::hamlib_port_t ##############

package Hamlib::hamlib_port_t;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_type_get = *Hamlibc::hamlib_port_t_type_get;
*swig_type_set = *Hamlibc::hamlib_port_t_type_set;
*swig_fd_get = *Hamlibc::hamlib_port_t_fd_get;
*swig_fd_set = *Hamlibc::hamlib_port_t_fd_set;
*swig_handle_get = *Hamlibc::hamlib_port_t_handle_get;
*swig_handle_set = *Hamlibc::hamlib_port_t_handle_set;
*swig_write_delay_get = *Hamlibc::hamlib_port_t_write_delay_get;
*swig_write_delay_set = *Hamlibc::hamlib_port_t_write_delay_set;
*swig_post_write_delay_get = *Hamlibc::hamlib_port_t_post_write_delay_get;
*swig_post_write_delay_set = *Hamlibc::hamlib_port_t_post_write_delay_set;
*swig_post_write_date_get = *Hamlibc::hamlib_port_t_post_write_date_get;
*swig_post_write_date_set = *Hamlibc::hamlib_port_t_post_write_date_set;
*swig_timeout_get = *Hamlibc::hamlib_port_t_timeout_get;
*swig_timeout_set = *Hamlibc::hamlib_port_t_timeout_set;
*swig_retry_get = *Hamlibc::hamlib_port_t_retry_get;
*swig_retry_set = *Hamlibc::hamlib_port_t_retry_set;
*swig_flushx_get = *Hamlibc::hamlib_port_t_flushx_get;
*swig_flushx_set = *Hamlibc::hamlib_port_t_flushx_set;
*swig_pathname_get = *Hamlibc::hamlib_port_t_pathname_get;
*swig_pathname_set = *Hamlibc::hamlib_port_t_pathname_set;
*swig_parm_get = *Hamlibc::hamlib_port_t_parm_get;
*swig_parm_set = *Hamlibc::hamlib_port_t_parm_set;
*swig_client_port_get = *Hamlibc::hamlib_port_t_client_port_get;
*swig_client_port_set = *Hamlibc::hamlib_port_t_client_port_set;
*swig_rig_get = *Hamlibc::hamlib_port_t_rig_get;
*swig_rig_set = *Hamlibc::hamlib_port_t_rig_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_hamlib_port_t(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_hamlib_port_t($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::hamlib_port_parm ##############

package Hamlib::hamlib_port_parm;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_serial_get = *Hamlibc::hamlib_port_parm_serial_get;
*swig_serial_set = *Hamlibc::hamlib_port_parm_serial_set;
*swig_parallel_get = *Hamlibc::hamlib_port_parm_parallel_get;
*swig_parallel_set = *Hamlibc::hamlib_port_parm_parallel_set;
*swig_cm108_get = *Hamlibc::hamlib_port_parm_cm108_get;
*swig_cm108_set = *Hamlibc::hamlib_port_parm_cm108_set;
*swig_usb_get = *Hamlibc::hamlib_port_parm_usb_get;
*swig_usb_set = *Hamlibc::hamlib_port_parm_usb_set;
*swig_gpio_get = *Hamlibc::hamlib_port_parm_gpio_get;
*swig_gpio_set = *Hamlibc::hamlib_port_parm_gpio_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_hamlib_port_parm(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_hamlib_port_parm($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::hamlib_port_parm_gpio ##############

package Hamlib::hamlib_port_parm_gpio;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_on_value_get = *Hamlibc::hamlib_port_parm_gpio_on_value_get;
*swig_on_value_set = *Hamlibc::hamlib_port_parm_gpio_on_value_set;
*swig_value_get = *Hamlibc::hamlib_port_parm_gpio_value_get;
*swig_value_set = *Hamlibc::hamlib_port_parm_gpio_value_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_hamlib_port_parm_gpio(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_hamlib_port_parm_gpio($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::hamlib_port_parm_usb ##############

package Hamlib::hamlib_port_parm_usb;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_vid_get = *Hamlibc::hamlib_port_parm_usb_vid_get;
*swig_vid_set = *Hamlibc::hamlib_port_parm_usb_vid_set;
*swig_pid_get = *Hamlibc::hamlib_port_parm_usb_pid_get;
*swig_pid_set = *Hamlibc::hamlib_port_parm_usb_pid_set;
*swig_conf_get = *Hamlibc::hamlib_port_parm_usb_conf_get;
*swig_conf_set = *Hamlibc::hamlib_port_parm_usb_conf_set;
*swig_iface_get = *Hamlibc::hamlib_port_parm_usb_iface_get;
*swig_iface_set = *Hamlibc::hamlib_port_parm_usb_iface_set;
*swig_alt_get = *Hamlibc::hamlib_port_parm_usb_alt_get;
*swig_alt_set = *Hamlibc::hamlib_port_parm_usb_alt_set;
*swig_vendor_name_get = *Hamlibc::hamlib_port_parm_usb_vendor_name_get;
*swig_vendor_name_set = *Hamlibc::hamlib_port_parm_usb_vendor_name_set;
*swig_product_get = *Hamlibc::hamlib_port_parm_usb_product_get;
*swig_product_set = *Hamlibc::hamlib_port_parm_usb_product_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_hamlib_port_parm_usb(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_hamlib_port_parm_usb($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::hamlib_port_parm_cm108 ##############

package Hamlib::hamlib_port_parm_cm108;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_ptt_bitnum_get = *Hamlibc::hamlib_port_parm_cm108_ptt_bitnum_get;
*swig_ptt_bitnum_set = *Hamlibc::hamlib_port_parm_cm108_ptt_bitnum_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_hamlib_port_parm_cm108(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_hamlib_port_parm_cm108($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::hamlib_port_parm_parallel ##############

package Hamlib::hamlib_port_parm_parallel;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_pin_get = *Hamlibc::hamlib_port_parm_parallel_pin_get;
*swig_pin_set = *Hamlibc::hamlib_port_parm_parallel_pin_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_hamlib_port_parm_parallel(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_hamlib_port_parm_parallel($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::hamlib_port_parm_serial ##############

package Hamlib::hamlib_port_parm_serial;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_rate_get = *Hamlibc::hamlib_port_parm_serial_rate_get;
*swig_rate_set = *Hamlibc::hamlib_port_parm_serial_rate_set;
*swig_data_bits_get = *Hamlibc::hamlib_port_parm_serial_data_bits_get;
*swig_data_bits_set = *Hamlibc::hamlib_port_parm_serial_data_bits_set;
*swig_stop_bits_get = *Hamlibc::hamlib_port_parm_serial_stop_bits_get;
*swig_stop_bits_set = *Hamlibc::hamlib_port_parm_serial_stop_bits_set;
*swig_parity_get = *Hamlibc::hamlib_port_parm_serial_parity_get;
*swig_parity_set = *Hamlibc::hamlib_port_parm_serial_parity_set;
*swig_handshake_get = *Hamlibc::hamlib_port_parm_serial_handshake_get;
*swig_handshake_set = *Hamlibc::hamlib_port_parm_serial_handshake_set;
*swig_rts_state_get = *Hamlibc::hamlib_port_parm_serial_rts_state_get;
*swig_rts_state_set = *Hamlibc::hamlib_port_parm_serial_rts_state_set;
*swig_dtr_state_get = *Hamlibc::hamlib_port_parm_serial_dtr_state_get;
*swig_dtr_state_set = *Hamlibc::hamlib_port_parm_serial_dtr_state_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_hamlib_port_parm_serial(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_hamlib_port_parm_serial($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::hamlib_port_post_write_date ##############

package Hamlib::hamlib_port_post_write_date;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_tv_sec_get = *Hamlibc::hamlib_port_post_write_date_tv_sec_get;
*swig_tv_sec_set = *Hamlibc::hamlib_port_post_write_date_tv_sec_set;
*swig_tv_usec_get = *Hamlibc::hamlib_port_post_write_date_tv_usec_get;
*swig_tv_usec_set = *Hamlibc::hamlib_port_post_write_date_tv_usec_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_hamlib_port_post_write_date(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_hamlib_port_post_write_date($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::hamlib_port_type ##############

package Hamlib::hamlib_port_type;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_rig_get = *Hamlibc::hamlib_port_type_rig_get;
*swig_rig_set = *Hamlibc::hamlib_port_type_rig_set;
*swig_ptt_get = *Hamlibc::hamlib_port_type_ptt_get;
*swig_ptt_set = *Hamlibc::hamlib_port_type_ptt_set;
*swig_dcd_get = *Hamlibc::hamlib_port_type_dcd_get;
*swig_dcd_set = *Hamlibc::hamlib_port_type_dcd_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_hamlib_port_type(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_hamlib_port_type($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::rig_cache ##############

package Hamlib::rig_cache;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_timeout_ms_get = *Hamlibc::rig_cache_timeout_ms_get;
*swig_timeout_ms_set = *Hamlibc::rig_cache_timeout_ms_set;
*swig_vfo_get = *Hamlibc::rig_cache_vfo_get;
*swig_vfo_set = *Hamlibc::rig_cache_vfo_set;
*swig_freqCurr_get = *Hamlibc::rig_cache_freqCurr_get;
*swig_freqCurr_set = *Hamlibc::rig_cache_freqCurr_set;
*swig_freqOther_get = *Hamlibc::rig_cache_freqOther_get;
*swig_freqOther_set = *Hamlibc::rig_cache_freqOther_set;
*swig_freqMainA_get = *Hamlibc::rig_cache_freqMainA_get;
*swig_freqMainA_set = *Hamlibc::rig_cache_freqMainA_set;
*swig_freqMainB_get = *Hamlibc::rig_cache_freqMainB_get;
*swig_freqMainB_set = *Hamlibc::rig_cache_freqMainB_set;
*swig_freqMainC_get = *Hamlibc::rig_cache_freqMainC_get;
*swig_freqMainC_set = *Hamlibc::rig_cache_freqMainC_set;
*swig_freqSubA_get = *Hamlibc::rig_cache_freqSubA_get;
*swig_freqSubA_set = *Hamlibc::rig_cache_freqSubA_set;
*swig_freqSubB_get = *Hamlibc::rig_cache_freqSubB_get;
*swig_freqSubB_set = *Hamlibc::rig_cache_freqSubB_set;
*swig_freqSubC_get = *Hamlibc::rig_cache_freqSubC_get;
*swig_freqSubC_set = *Hamlibc::rig_cache_freqSubC_set;
*swig_freqMem_get = *Hamlibc::rig_cache_freqMem_get;
*swig_freqMem_set = *Hamlibc::rig_cache_freqMem_set;
*swig_modeCurr_get = *Hamlibc::rig_cache_modeCurr_get;
*swig_modeCurr_set = *Hamlibc::rig_cache_modeCurr_set;
*swig_modeOther_get = *Hamlibc::rig_cache_modeOther_get;
*swig_modeOther_set = *Hamlibc::rig_cache_modeOther_set;
*swig_modeMainA_get = *Hamlibc::rig_cache_modeMainA_get;
*swig_modeMainA_set = *Hamlibc::rig_cache_modeMainA_set;
*swig_modeMainB_get = *Hamlibc::rig_cache_modeMainB_get;
*swig_modeMainB_set = *Hamlibc::rig_cache_modeMainB_set;
*swig_modeMainC_get = *Hamlibc::rig_cache_modeMainC_get;
*swig_modeMainC_set = *Hamlibc::rig_cache_modeMainC_set;
*swig_modeSubA_get = *Hamlibc::rig_cache_modeSubA_get;
*swig_modeSubA_set = *Hamlibc::rig_cache_modeSubA_set;
*swig_modeSubB_get = *Hamlibc::rig_cache_modeSubB_get;
*swig_modeSubB_set = *Hamlibc::rig_cache_modeSubB_set;
*swig_modeSubC_get = *Hamlibc::rig_cache_modeSubC_get;
*swig_modeSubC_set = *Hamlibc::rig_cache_modeSubC_set;
*swig_modeMem_get = *Hamlibc::rig_cache_modeMem_get;
*swig_modeMem_set = *Hamlibc::rig_cache_modeMem_set;
*swig_widthCurr_get = *Hamlibc::rig_cache_widthCurr_get;
*swig_widthCurr_set = *Hamlibc::rig_cache_widthCurr_set;
*swig_widthOther_get = *Hamlibc::rig_cache_widthOther_get;
*swig_widthOther_set = *Hamlibc::rig_cache_widthOther_set;
*swig_widthMainA_get = *Hamlibc::rig_cache_widthMainA_get;
*swig_widthMainA_set = *Hamlibc::rig_cache_widthMainA_set;
*swig_widthMainB_get = *Hamlibc::rig_cache_widthMainB_get;
*swig_widthMainB_set = *Hamlibc::rig_cache_widthMainB_set;
*swig_widthMainC_get = *Hamlibc::rig_cache_widthMainC_get;
*swig_widthMainC_set = *Hamlibc::rig_cache_widthMainC_set;
*swig_widthSubA_get = *Hamlibc::rig_cache_widthSubA_get;
*swig_widthSubA_set = *Hamlibc::rig_cache_widthSubA_set;
*swig_widthSubB_get = *Hamlibc::rig_cache_widthSubB_get;
*swig_widthSubB_set = *Hamlibc::rig_cache_widthSubB_set;
*swig_widthSubC_get = *Hamlibc::rig_cache_widthSubC_get;
*swig_widthSubC_set = *Hamlibc::rig_cache_widthSubC_set;
*swig_widthMem_get = *Hamlibc::rig_cache_widthMem_get;
*swig_widthMem_set = *Hamlibc::rig_cache_widthMem_set;
*swig_ptt_get = *Hamlibc::rig_cache_ptt_get;
*swig_ptt_set = *Hamlibc::rig_cache_ptt_set;
*swig_split_get = *Hamlibc::rig_cache_split_get;
*swig_split_set = *Hamlibc::rig_cache_split_set;
*swig_split_vfo_get = *Hamlibc::rig_cache_split_vfo_get;
*swig_split_vfo_set = *Hamlibc::rig_cache_split_vfo_set;
*swig_time_freqCurr_get = *Hamlibc::rig_cache_time_freqCurr_get;
*swig_time_freqCurr_set = *Hamlibc::rig_cache_time_freqCurr_set;
*swig_time_freqOther_get = *Hamlibc::rig_cache_time_freqOther_get;
*swig_time_freqOther_set = *Hamlibc::rig_cache_time_freqOther_set;
*swig_time_freqMainA_get = *Hamlibc::rig_cache_time_freqMainA_get;
*swig_time_freqMainA_set = *Hamlibc::rig_cache_time_freqMainA_set;
*swig_time_freqMainB_get = *Hamlibc::rig_cache_time_freqMainB_get;
*swig_time_freqMainB_set = *Hamlibc::rig_cache_time_freqMainB_set;
*swig_time_freqMainC_get = *Hamlibc::rig_cache_time_freqMainC_get;
*swig_time_freqMainC_set = *Hamlibc::rig_cache_time_freqMainC_set;
*swig_time_freqSubA_get = *Hamlibc::rig_cache_time_freqSubA_get;
*swig_time_freqSubA_set = *Hamlibc::rig_cache_time_freqSubA_set;
*swig_time_freqSubB_get = *Hamlibc::rig_cache_time_freqSubB_get;
*swig_time_freqSubB_set = *Hamlibc::rig_cache_time_freqSubB_set;
*swig_time_freqSubC_get = *Hamlibc::rig_cache_time_freqSubC_get;
*swig_time_freqSubC_set = *Hamlibc::rig_cache_time_freqSubC_set;
*swig_time_freqMem_get = *Hamlibc::rig_cache_time_freqMem_get;
*swig_time_freqMem_set = *Hamlibc::rig_cache_time_freqMem_set;
*swig_time_vfo_get = *Hamlibc::rig_cache_time_vfo_get;
*swig_time_vfo_set = *Hamlibc::rig_cache_time_vfo_set;
*swig_time_modeCurr_get = *Hamlibc::rig_cache_time_modeCurr_get;
*swig_time_modeCurr_set = *Hamlibc::rig_cache_time_modeCurr_set;
*swig_time_modeOther_get = *Hamlibc::rig_cache_time_modeOther_get;
*swig_time_modeOther_set = *Hamlibc::rig_cache_time_modeOther_set;
*swig_time_modeMainA_get = *Hamlibc::rig_cache_time_modeMainA_get;
*swig_time_modeMainA_set = *Hamlibc::rig_cache_time_modeMainA_set;
*swig_time_modeMainB_get = *Hamlibc::rig_cache_time_modeMainB_get;
*swig_time_modeMainB_set = *Hamlibc::rig_cache_time_modeMainB_set;
*swig_time_modeMainC_get = *Hamlibc::rig_cache_time_modeMainC_get;
*swig_time_modeMainC_set = *Hamlibc::rig_cache_time_modeMainC_set;
*swig_time_modeSubA_get = *Hamlibc::rig_cache_time_modeSubA_get;
*swig_time_modeSubA_set = *Hamlibc::rig_cache_time_modeSubA_set;
*swig_time_modeSubB_get = *Hamlibc::rig_cache_time_modeSubB_get;
*swig_time_modeSubB_set = *Hamlibc::rig_cache_time_modeSubB_set;
*swig_time_modeSubC_get = *Hamlibc::rig_cache_time_modeSubC_get;
*swig_time_modeSubC_set = *Hamlibc::rig_cache_time_modeSubC_set;
*swig_time_modeMem_get = *Hamlibc::rig_cache_time_modeMem_get;
*swig_time_modeMem_set = *Hamlibc::rig_cache_time_modeMem_set;
*swig_time_widthCurr_get = *Hamlibc::rig_cache_time_widthCurr_get;
*swig_time_widthCurr_set = *Hamlibc::rig_cache_time_widthCurr_set;
*swig_time_widthOther_get = *Hamlibc::rig_cache_time_widthOther_get;
*swig_time_widthOther_set = *Hamlibc::rig_cache_time_widthOther_set;
*swig_time_widthMainA_get = *Hamlibc::rig_cache_time_widthMainA_get;
*swig_time_widthMainA_set = *Hamlibc::rig_cache_time_widthMainA_set;
*swig_time_widthMainB_get = *Hamlibc::rig_cache_time_widthMainB_get;
*swig_time_widthMainB_set = *Hamlibc::rig_cache_time_widthMainB_set;
*swig_time_widthMainC_get = *Hamlibc::rig_cache_time_widthMainC_get;
*swig_time_widthMainC_set = *Hamlibc::rig_cache_time_widthMainC_set;
*swig_time_widthSubA_get = *Hamlibc::rig_cache_time_widthSubA_get;
*swig_time_widthSubA_set = *Hamlibc::rig_cache_time_widthSubA_set;
*swig_time_widthSubB_get = *Hamlibc::rig_cache_time_widthSubB_get;
*swig_time_widthSubB_set = *Hamlibc::rig_cache_time_widthSubB_set;
*swig_time_widthSubC_get = *Hamlibc::rig_cache_time_widthSubC_get;
*swig_time_widthSubC_set = *Hamlibc::rig_cache_time_widthSubC_set;
*swig_time_widthMem_get = *Hamlibc::rig_cache_time_widthMem_get;
*swig_time_widthMem_set = *Hamlibc::rig_cache_time_widthMem_set;
*swig_time_ptt_get = *Hamlibc::rig_cache_time_ptt_get;
*swig_time_ptt_set = *Hamlibc::rig_cache_time_ptt_set;
*swig_time_split_get = *Hamlibc::rig_cache_time_split_get;
*swig_time_split_set = *Hamlibc::rig_cache_time_split_set;
*swig_satmode_get = *Hamlibc::rig_cache_satmode_get;
*swig_satmode_set = *Hamlibc::rig_cache_satmode_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_rig_cache(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_rig_cache($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::rig_state ##############

package Hamlib::rig_state;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_rigport_get = *Hamlibc::rig_state_rigport_get;
*swig_rigport_set = *Hamlibc::rig_state_rigport_set;
*swig_pttport_get = *Hamlibc::rig_state_pttport_get;
*swig_pttport_set = *Hamlibc::rig_state_pttport_set;
*swig_dcdport_get = *Hamlibc::rig_state_dcdport_get;
*swig_dcdport_set = *Hamlibc::rig_state_dcdport_set;
*swig_vfo_comp_get = *Hamlibc::rig_state_vfo_comp_get;
*swig_vfo_comp_set = *Hamlibc::rig_state_vfo_comp_set;
*swig_deprecated_itu_region_get = *Hamlibc::rig_state_deprecated_itu_region_get;
*swig_deprecated_itu_region_set = *Hamlibc::rig_state_deprecated_itu_region_set;
*swig_rx_range_list_get = *Hamlibc::rig_state_rx_range_list_get;
*swig_rx_range_list_set = *Hamlibc::rig_state_rx_range_list_set;
*swig_tx_range_list_get = *Hamlibc::rig_state_tx_range_list_get;
*swig_tx_range_list_set = *Hamlibc::rig_state_tx_range_list_set;
*swig_tuning_steps_get = *Hamlibc::rig_state_tuning_steps_get;
*swig_tuning_steps_set = *Hamlibc::rig_state_tuning_steps_set;
*swig_filters_get = *Hamlibc::rig_state_filters_get;
*swig_filters_set = *Hamlibc::rig_state_filters_set;
*swig_str_cal_get = *Hamlibc::rig_state_str_cal_get;
*swig_str_cal_set = *Hamlibc::rig_state_str_cal_set;
*swig_chan_list_get = *Hamlibc::rig_state_chan_list_get;
*swig_chan_list_set = *Hamlibc::rig_state_chan_list_set;
*swig_max_rit_get = *Hamlibc::rig_state_max_rit_get;
*swig_max_rit_set = *Hamlibc::rig_state_max_rit_set;
*swig_max_xit_get = *Hamlibc::rig_state_max_xit_get;
*swig_max_xit_set = *Hamlibc::rig_state_max_xit_set;
*swig_max_ifshift_get = *Hamlibc::rig_state_max_ifshift_get;
*swig_max_ifshift_set = *Hamlibc::rig_state_max_ifshift_set;
*swig_announces_get = *Hamlibc::rig_state_announces_get;
*swig_announces_set = *Hamlibc::rig_state_announces_set;
*swig_preamp_get = *Hamlibc::rig_state_preamp_get;
*swig_preamp_set = *Hamlibc::rig_state_preamp_set;
*swig_attenuator_get = *Hamlibc::rig_state_attenuator_get;
*swig_attenuator_set = *Hamlibc::rig_state_attenuator_set;
*swig_has_get_func_get = *Hamlibc::rig_state_has_get_func_get;
*swig_has_get_func_set = *Hamlibc::rig_state_has_get_func_set;
*swig_has_set_func_get = *Hamlibc::rig_state_has_set_func_get;
*swig_has_set_func_set = *Hamlibc::rig_state_has_set_func_set;
*swig_has_get_level_get = *Hamlibc::rig_state_has_get_level_get;
*swig_has_get_level_set = *Hamlibc::rig_state_has_get_level_set;
*swig_has_set_level_get = *Hamlibc::rig_state_has_set_level_get;
*swig_has_set_level_set = *Hamlibc::rig_state_has_set_level_set;
*swig_has_get_parm_get = *Hamlibc::rig_state_has_get_parm_get;
*swig_has_get_parm_set = *Hamlibc::rig_state_has_get_parm_set;
*swig_has_set_parm_get = *Hamlibc::rig_state_has_set_parm_get;
*swig_has_set_parm_set = *Hamlibc::rig_state_has_set_parm_set;
*swig_level_gran_get = *Hamlibc::rig_state_level_gran_get;
*swig_level_gran_set = *Hamlibc::rig_state_level_gran_set;
*swig_parm_gran_get = *Hamlibc::rig_state_parm_gran_get;
*swig_parm_gran_set = *Hamlibc::rig_state_parm_gran_set;
*swig_hold_decode_get = *Hamlibc::rig_state_hold_decode_get;
*swig_hold_decode_set = *Hamlibc::rig_state_hold_decode_set;
*swig_current_vfo_get = *Hamlibc::rig_state_current_vfo_get;
*swig_current_vfo_set = *Hamlibc::rig_state_current_vfo_set;
*swig_vfo_list_get = *Hamlibc::rig_state_vfo_list_get;
*swig_vfo_list_set = *Hamlibc::rig_state_vfo_list_set;
*swig_comm_state_get = *Hamlibc::rig_state_comm_state_get;
*swig_comm_state_set = *Hamlibc::rig_state_comm_state_set;
*swig_priv_get = *Hamlibc::rig_state_priv_get;
*swig_priv_set = *Hamlibc::rig_state_priv_set;
*swig_obj_get = *Hamlibc::rig_state_obj_get;
*swig_obj_set = *Hamlibc::rig_state_obj_set;
*swig_transceive_get = *Hamlibc::rig_state_transceive_get;
*swig_transceive_set = *Hamlibc::rig_state_transceive_set;
*swig_poll_interval_get = *Hamlibc::rig_state_poll_interval_get;
*swig_poll_interval_set = *Hamlibc::rig_state_poll_interval_set;
*swig_current_freq_get = *Hamlibc::rig_state_current_freq_get;
*swig_current_freq_set = *Hamlibc::rig_state_current_freq_set;
*swig_current_mode_get = *Hamlibc::rig_state_current_mode_get;
*swig_current_mode_set = *Hamlibc::rig_state_current_mode_set;
*swig_current_width_get = *Hamlibc::rig_state_current_width_get;
*swig_current_width_set = *Hamlibc::rig_state_current_width_set;
*swig_tx_vfo_get = *Hamlibc::rig_state_tx_vfo_get;
*swig_tx_vfo_set = *Hamlibc::rig_state_tx_vfo_set;
*swig_mode_list_get = *Hamlibc::rig_state_mode_list_get;
*swig_mode_list_set = *Hamlibc::rig_state_mode_list_set;
*swig_transmit_get = *Hamlibc::rig_state_transmit_get;
*swig_transmit_set = *Hamlibc::rig_state_transmit_set;
*swig_lo_freq_get = *Hamlibc::rig_state_lo_freq_get;
*swig_lo_freq_set = *Hamlibc::rig_state_lo_freq_set;
*swig_twiddle_time_get = *Hamlibc::rig_state_twiddle_time_get;
*swig_twiddle_time_set = *Hamlibc::rig_state_twiddle_time_set;
*swig_twiddle_timeout_get = *Hamlibc::rig_state_twiddle_timeout_get;
*swig_twiddle_timeout_set = *Hamlibc::rig_state_twiddle_timeout_set;
*swig_uplink_get = *Hamlibc::rig_state_uplink_get;
*swig_uplink_set = *Hamlibc::rig_state_uplink_set;
*swig_cache_get = *Hamlibc::rig_state_cache_get;
*swig_cache_set = *Hamlibc::rig_state_cache_set;
*swig_vfo_opt_get = *Hamlibc::rig_state_vfo_opt_get;
*swig_vfo_opt_set = *Hamlibc::rig_state_vfo_opt_set;
*swig_auto_power_on_get = *Hamlibc::rig_state_auto_power_on_get;
*swig_auto_power_on_set = *Hamlibc::rig_state_auto_power_on_set;
*swig_auto_power_off_get = *Hamlibc::rig_state_auto_power_off_get;
*swig_auto_power_off_set = *Hamlibc::rig_state_auto_power_off_set;
*swig_auto_disable_screensaver_get = *Hamlibc::rig_state_auto_disable_screensaver_get;
*swig_auto_disable_screensaver_set = *Hamlibc::rig_state_auto_disable_screensaver_set;
*swig_ptt_share_get = *Hamlibc::rig_state_ptt_share_get;
*swig_ptt_share_set = *Hamlibc::rig_state_ptt_share_set;
*swig_power_now_get = *Hamlibc::rig_state_power_now_get;
*swig_power_now_set = *Hamlibc::rig_state_power_now_set;
*swig_power_min_get = *Hamlibc::rig_state_power_min_get;
*swig_power_min_set = *Hamlibc::rig_state_power_min_set;
*swig_power_max_get = *Hamlibc::rig_state_power_max_get;
*swig_power_max_set = *Hamlibc::rig_state_power_max_set;
*swig_disable_yaesu_bandselect_get = *Hamlibc::rig_state_disable_yaesu_bandselect_get;
*swig_disable_yaesu_bandselect_set = *Hamlibc::rig_state_disable_yaesu_bandselect_set;
*swig_twiddle_rit_get = *Hamlibc::rig_state_twiddle_rit_get;
*swig_twiddle_rit_set = *Hamlibc::rig_state_twiddle_rit_set;
*swig_twiddle_state_get = *Hamlibc::rig_state_twiddle_state_get;
*swig_twiddle_state_set = *Hamlibc::rig_state_twiddle_state_set;
*swig_rx_vfo_get = *Hamlibc::rig_state_rx_vfo_get;
*swig_rx_vfo_set = *Hamlibc::rig_state_rx_vfo_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_rig_state(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_rig_state($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::rig_callbacks ##############

package Hamlib::rig_callbacks;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_freq_event_get = *Hamlibc::rig_callbacks_freq_event_get;
*swig_freq_event_set = *Hamlibc::rig_callbacks_freq_event_set;
*swig_freq_arg_get = *Hamlibc::rig_callbacks_freq_arg_get;
*swig_freq_arg_set = *Hamlibc::rig_callbacks_freq_arg_set;
*swig_mode_event_get = *Hamlibc::rig_callbacks_mode_event_get;
*swig_mode_event_set = *Hamlibc::rig_callbacks_mode_event_set;
*swig_mode_arg_get = *Hamlibc::rig_callbacks_mode_arg_get;
*swig_mode_arg_set = *Hamlibc::rig_callbacks_mode_arg_set;
*swig_vfo_event_get = *Hamlibc::rig_callbacks_vfo_event_get;
*swig_vfo_event_set = *Hamlibc::rig_callbacks_vfo_event_set;
*swig_vfo_arg_get = *Hamlibc::rig_callbacks_vfo_arg_get;
*swig_vfo_arg_set = *Hamlibc::rig_callbacks_vfo_arg_set;
*swig_ptt_event_get = *Hamlibc::rig_callbacks_ptt_event_get;
*swig_ptt_event_set = *Hamlibc::rig_callbacks_ptt_event_set;
*swig_ptt_arg_get = *Hamlibc::rig_callbacks_ptt_arg_get;
*swig_ptt_arg_set = *Hamlibc::rig_callbacks_ptt_arg_set;
*swig_dcd_event_get = *Hamlibc::rig_callbacks_dcd_event_get;
*swig_dcd_event_set = *Hamlibc::rig_callbacks_dcd_event_set;
*swig_dcd_arg_get = *Hamlibc::rig_callbacks_dcd_arg_get;
*swig_dcd_arg_set = *Hamlibc::rig_callbacks_dcd_arg_set;
*swig_pltune_get = *Hamlibc::rig_callbacks_pltune_get;
*swig_pltune_set = *Hamlibc::rig_callbacks_pltune_set;
*swig_pltune_arg_get = *Hamlibc::rig_callbacks_pltune_arg_get;
*swig_pltune_arg_set = *Hamlibc::rig_callbacks_pltune_arg_set;
*swig_spectrum_event_get = *Hamlibc::rig_callbacks_spectrum_event_get;
*swig_spectrum_event_set = *Hamlibc::rig_callbacks_spectrum_event_set;
*swig_spectrum_arg_get = *Hamlibc::rig_callbacks_spectrum_arg_get;
*swig_spectrum_arg_set = *Hamlibc::rig_callbacks_spectrum_arg_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_rig_callbacks(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_rig_callbacks($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::s_rig ##############

package Hamlib::s_rig;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_caps_get = *Hamlibc::s_rig_caps_get;
*swig_caps_set = *Hamlibc::s_rig_caps_set;
*swig_state_get = *Hamlibc::s_rig_state_get;
*swig_state_set = *Hamlibc::s_rig_state_set;
*swig_callbacks_get = *Hamlibc::s_rig_callbacks_get;
*swig_callbacks_set = *Hamlibc::s_rig_callbacks_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_s_rig(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_s_rig($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::rot_caps ##############

package Hamlib::rot_caps;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_rot_model_get = *Hamlibc::rot_caps_rot_model_get;
*swig_rot_model_set = *Hamlibc::rot_caps_rot_model_set;
*swig_model_name_get = *Hamlibc::rot_caps_model_name_get;
*swig_model_name_set = *Hamlibc::rot_caps_model_name_set;
*swig_mfg_name_get = *Hamlibc::rot_caps_mfg_name_get;
*swig_mfg_name_set = *Hamlibc::rot_caps_mfg_name_set;
*swig_version_get = *Hamlibc::rot_caps_version_get;
*swig_version_set = *Hamlibc::rot_caps_version_set;
*swig_copyright_get = *Hamlibc::rot_caps_copyright_get;
*swig_copyright_set = *Hamlibc::rot_caps_copyright_set;
*swig_status_get = *Hamlibc::rot_caps_status_get;
*swig_status_set = *Hamlibc::rot_caps_status_set;
*swig_rot_type_get = *Hamlibc::rot_caps_rot_type_get;
*swig_rot_type_set = *Hamlibc::rot_caps_rot_type_set;
*swig_port_type_get = *Hamlibc::rot_caps_port_type_get;
*swig_port_type_set = *Hamlibc::rot_caps_port_type_set;
*swig_serial_rate_min_get = *Hamlibc::rot_caps_serial_rate_min_get;
*swig_serial_rate_min_set = *Hamlibc::rot_caps_serial_rate_min_set;
*swig_serial_rate_max_get = *Hamlibc::rot_caps_serial_rate_max_get;
*swig_serial_rate_max_set = *Hamlibc::rot_caps_serial_rate_max_set;
*swig_serial_data_bits_get = *Hamlibc::rot_caps_serial_data_bits_get;
*swig_serial_data_bits_set = *Hamlibc::rot_caps_serial_data_bits_set;
*swig_serial_stop_bits_get = *Hamlibc::rot_caps_serial_stop_bits_get;
*swig_serial_stop_bits_set = *Hamlibc::rot_caps_serial_stop_bits_set;
*swig_serial_parity_get = *Hamlibc::rot_caps_serial_parity_get;
*swig_serial_parity_set = *Hamlibc::rot_caps_serial_parity_set;
*swig_serial_handshake_get = *Hamlibc::rot_caps_serial_handshake_get;
*swig_serial_handshake_set = *Hamlibc::rot_caps_serial_handshake_set;
*swig_write_delay_get = *Hamlibc::rot_caps_write_delay_get;
*swig_write_delay_set = *Hamlibc::rot_caps_write_delay_set;
*swig_post_write_delay_get = *Hamlibc::rot_caps_post_write_delay_get;
*swig_post_write_delay_set = *Hamlibc::rot_caps_post_write_delay_set;
*swig_timeout_get = *Hamlibc::rot_caps_timeout_get;
*swig_timeout_set = *Hamlibc::rot_caps_timeout_set;
*swig_retry_get = *Hamlibc::rot_caps_retry_get;
*swig_retry_set = *Hamlibc::rot_caps_retry_set;
*swig_has_get_func_get = *Hamlibc::rot_caps_has_get_func_get;
*swig_has_get_func_set = *Hamlibc::rot_caps_has_get_func_set;
*swig_has_set_func_get = *Hamlibc::rot_caps_has_set_func_get;
*swig_has_set_func_set = *Hamlibc::rot_caps_has_set_func_set;
*swig_has_get_level_get = *Hamlibc::rot_caps_has_get_level_get;
*swig_has_get_level_set = *Hamlibc::rot_caps_has_get_level_set;
*swig_has_set_level_get = *Hamlibc::rot_caps_has_set_level_get;
*swig_has_set_level_set = *Hamlibc::rot_caps_has_set_level_set;
*swig_has_get_parm_get = *Hamlibc::rot_caps_has_get_parm_get;
*swig_has_get_parm_set = *Hamlibc::rot_caps_has_get_parm_set;
*swig_has_set_parm_get = *Hamlibc::rot_caps_has_set_parm_get;
*swig_has_set_parm_set = *Hamlibc::rot_caps_has_set_parm_set;
*swig_has_status_get = *Hamlibc::rot_caps_has_status_get;
*swig_has_status_set = *Hamlibc::rot_caps_has_status_set;
*swig_level_gran_get = *Hamlibc::rot_caps_level_gran_get;
*swig_level_gran_set = *Hamlibc::rot_caps_level_gran_set;
*swig_parm_gran_get = *Hamlibc::rot_caps_parm_gran_get;
*swig_parm_gran_set = *Hamlibc::rot_caps_parm_gran_set;
*swig_extparms_get = *Hamlibc::rot_caps_extparms_get;
*swig_extparms_set = *Hamlibc::rot_caps_extparms_set;
*swig_extlevels_get = *Hamlibc::rot_caps_extlevels_get;
*swig_extlevels_set = *Hamlibc::rot_caps_extlevels_set;
*swig_extfuncs_get = *Hamlibc::rot_caps_extfuncs_get;
*swig_extfuncs_set = *Hamlibc::rot_caps_extfuncs_set;
*swig_ext_tokens_get = *Hamlibc::rot_caps_ext_tokens_get;
*swig_ext_tokens_set = *Hamlibc::rot_caps_ext_tokens_set;
*swig_min_az_get = *Hamlibc::rot_caps_min_az_get;
*swig_min_az_set = *Hamlibc::rot_caps_min_az_set;
*swig_max_az_get = *Hamlibc::rot_caps_max_az_get;
*swig_max_az_set = *Hamlibc::rot_caps_max_az_set;
*swig_min_el_get = *Hamlibc::rot_caps_min_el_get;
*swig_min_el_set = *Hamlibc::rot_caps_min_el_set;
*swig_max_el_get = *Hamlibc::rot_caps_max_el_get;
*swig_max_el_set = *Hamlibc::rot_caps_max_el_set;
*swig_cfgparams_get = *Hamlibc::rot_caps_cfgparams_get;
*swig_cfgparams_set = *Hamlibc::rot_caps_cfgparams_set;
*swig_priv_get = *Hamlibc::rot_caps_priv_get;
*swig_priv_set = *Hamlibc::rot_caps_priv_set;
*swig_rot_init_get = *Hamlibc::rot_caps_rot_init_get;
*swig_rot_init_set = *Hamlibc::rot_caps_rot_init_set;
*swig_set_conf_get = *Hamlibc::rot_caps_set_conf_get;
*swig_set_conf_set = *Hamlibc::rot_caps_set_conf_set;
*swig_get_conf_get = *Hamlibc::rot_caps_get_conf_get;
*swig_get_conf_set = *Hamlibc::rot_caps_get_conf_set;
*swig_set_position_get = *Hamlibc::rot_caps_set_position_get;
*swig_set_position_set = *Hamlibc::rot_caps_set_position_set;
*swig_get_position_get = *Hamlibc::rot_caps_get_position_get;
*swig_get_position_set = *Hamlibc::rot_caps_get_position_set;
*swig_stop_get = *Hamlibc::rot_caps_stop_get;
*swig_stop_set = *Hamlibc::rot_caps_stop_set;
*swig_park_get = *Hamlibc::rot_caps_park_get;
*swig_park_set = *Hamlibc::rot_caps_park_set;
*swig_reset_get = *Hamlibc::rot_caps_reset_get;
*swig_reset_set = *Hamlibc::rot_caps_reset_set;
*swig_move_get = *Hamlibc::rot_caps_move_get;
*swig_move_set = *Hamlibc::rot_caps_move_set;
*swig_get_info_get = *Hamlibc::rot_caps_get_info_get;
*swig_get_info_set = *Hamlibc::rot_caps_get_info_set;
*swig_set_level_get = *Hamlibc::rot_caps_set_level_get;
*swig_set_level_set = *Hamlibc::rot_caps_set_level_set;
*swig_get_level_get = *Hamlibc::rot_caps_get_level_get;
*swig_get_level_set = *Hamlibc::rot_caps_get_level_set;
*swig_set_func_get = *Hamlibc::rot_caps_set_func_get;
*swig_set_func_set = *Hamlibc::rot_caps_set_func_set;
*swig_get_func_get = *Hamlibc::rot_caps_get_func_get;
*swig_get_func_set = *Hamlibc::rot_caps_get_func_set;
*swig_set_parm_get = *Hamlibc::rot_caps_set_parm_get;
*swig_set_parm_set = *Hamlibc::rot_caps_set_parm_set;
*swig_get_parm_get = *Hamlibc::rot_caps_get_parm_get;
*swig_get_parm_set = *Hamlibc::rot_caps_get_parm_set;
*swig_set_ext_level_get = *Hamlibc::rot_caps_set_ext_level_get;
*swig_set_ext_level_set = *Hamlibc::rot_caps_set_ext_level_set;
*swig_get_ext_level_get = *Hamlibc::rot_caps_get_ext_level_get;
*swig_get_ext_level_set = *Hamlibc::rot_caps_get_ext_level_set;
*swig_set_ext_func_get = *Hamlibc::rot_caps_set_ext_func_get;
*swig_set_ext_func_set = *Hamlibc::rot_caps_set_ext_func_set;
*swig_get_ext_func_get = *Hamlibc::rot_caps_get_ext_func_get;
*swig_get_ext_func_set = *Hamlibc::rot_caps_get_ext_func_set;
*swig_set_ext_parm_get = *Hamlibc::rot_caps_set_ext_parm_get;
*swig_set_ext_parm_set = *Hamlibc::rot_caps_set_ext_parm_set;
*swig_get_ext_parm_get = *Hamlibc::rot_caps_get_ext_parm_get;
*swig_get_ext_parm_set = *Hamlibc::rot_caps_get_ext_parm_set;
*swig_get_status_get = *Hamlibc::rot_caps_get_status_get;
*swig_get_status_set = *Hamlibc::rot_caps_get_status_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_rot_caps(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_rot_caps($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::rot_state ##############

package Hamlib::rot_state;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_min_az_get = *Hamlibc::rot_state_min_az_get;
*swig_min_az_set = *Hamlibc::rot_state_min_az_set;
*swig_max_az_get = *Hamlibc::rot_state_max_az_get;
*swig_max_az_set = *Hamlibc::rot_state_max_az_set;
*swig_min_el_get = *Hamlibc::rot_state_min_el_get;
*swig_min_el_set = *Hamlibc::rot_state_min_el_set;
*swig_max_el_get = *Hamlibc::rot_state_max_el_get;
*swig_max_el_set = *Hamlibc::rot_state_max_el_set;
*swig_south_zero_get = *Hamlibc::rot_state_south_zero_get;
*swig_south_zero_set = *Hamlibc::rot_state_south_zero_set;
*swig_az_offset_get = *Hamlibc::rot_state_az_offset_get;
*swig_az_offset_set = *Hamlibc::rot_state_az_offset_set;
*swig_el_offset_get = *Hamlibc::rot_state_el_offset_get;
*swig_el_offset_set = *Hamlibc::rot_state_el_offset_set;
*swig_has_get_func_get = *Hamlibc::rot_state_has_get_func_get;
*swig_has_get_func_set = *Hamlibc::rot_state_has_get_func_set;
*swig_has_set_func_get = *Hamlibc::rot_state_has_set_func_get;
*swig_has_set_func_set = *Hamlibc::rot_state_has_set_func_set;
*swig_has_get_level_get = *Hamlibc::rot_state_has_get_level_get;
*swig_has_get_level_set = *Hamlibc::rot_state_has_get_level_set;
*swig_has_set_level_get = *Hamlibc::rot_state_has_set_level_get;
*swig_has_set_level_set = *Hamlibc::rot_state_has_set_level_set;
*swig_has_get_parm_get = *Hamlibc::rot_state_has_get_parm_get;
*swig_has_get_parm_set = *Hamlibc::rot_state_has_get_parm_set;
*swig_has_set_parm_get = *Hamlibc::rot_state_has_set_parm_get;
*swig_has_set_parm_set = *Hamlibc::rot_state_has_set_parm_set;
*swig_has_status_get = *Hamlibc::rot_state_has_status_get;
*swig_has_status_set = *Hamlibc::rot_state_has_status_set;
*swig_level_gran_get = *Hamlibc::rot_state_level_gran_get;
*swig_level_gran_set = *Hamlibc::rot_state_level_gran_set;
*swig_parm_gran_get = *Hamlibc::rot_state_parm_gran_get;
*swig_parm_gran_set = *Hamlibc::rot_state_parm_gran_set;
*swig_rotport_get = *Hamlibc::rot_state_rotport_get;
*swig_rotport_set = *Hamlibc::rot_state_rotport_set;
*swig_rotport2_get = *Hamlibc::rot_state_rotport2_get;
*swig_rotport2_set = *Hamlibc::rot_state_rotport2_set;
*swig_comm_state_get = *Hamlibc::rot_state_comm_state_get;
*swig_comm_state_set = *Hamlibc::rot_state_comm_state_set;
*swig_priv_get = *Hamlibc::rot_state_priv_get;
*swig_priv_set = *Hamlibc::rot_state_priv_set;
*swig_obj_get = *Hamlibc::rot_state_obj_get;
*swig_obj_set = *Hamlibc::rot_state_obj_set;
*swig_current_speed_get = *Hamlibc::rot_state_current_speed_get;
*swig_current_speed_set = *Hamlibc::rot_state_current_speed_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_rot_state(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_rot_state($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::s_rot ##############

package Hamlib::s_rot;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_caps_get = *Hamlibc::s_rot_caps_get;
*swig_caps_set = *Hamlibc::s_rot_caps_set;
*swig_state_get = *Hamlibc::s_rot_state_get;
*swig_state_set = *Hamlibc::s_rot_state_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_s_rot(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_s_rot($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::Rig ##############

package Hamlib::Rig;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_rig_get = *Hamlibc::Rig_rig_get;
*swig_rig_set = *Hamlibc::Rig_rig_set;
*swig_caps_get = *Hamlibc::Rig_caps_get;
*swig_caps_set = *Hamlibc::Rig_caps_set;
*swig_state_get = *Hamlibc::Rig_state_get;
*swig_state_set = *Hamlibc::Rig_state_set;
*swig_error_status_get = *Hamlibc::Rig_error_status_get;
*swig_error_status_set = *Hamlibc::Rig_error_status_set;
*swig_do_exception_get = *Hamlibc::Rig_do_exception_get;
*swig_do_exception_set = *Hamlibc::Rig_do_exception_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_Rig(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_Rig($self);
        delete $OWNER{$self};
    }
}

*open = *Hamlibc::Rig_open;
*close = *Hamlibc::Rig_close;
*set_freq = *Hamlibc::Rig_set_freq;
*set_mode = *Hamlibc::Rig_set_mode;
*set_ptt = *Hamlibc::Rig_set_ptt;
*set_rptr_shift = *Hamlibc::Rig_set_rptr_shift;
*set_rptr_offs = *Hamlibc::Rig_set_rptr_offs;
*set_ctcss_tone = *Hamlibc::Rig_set_ctcss_tone;
*set_dcs_code = *Hamlibc::Rig_set_dcs_code;
*set_ctcss_sql = *Hamlibc::Rig_set_ctcss_sql;
*set_dcs_sql = *Hamlibc::Rig_set_dcs_sql;
*set_split_freq = *Hamlibc::Rig_set_split_freq;
*set_split_mode = *Hamlibc::Rig_set_split_mode;
*set_split_freq_mode = *Hamlibc::Rig_set_split_freq_mode;
*set_split_vfo = *Hamlibc::Rig_set_split_vfo;
*set_rit = *Hamlibc::Rig_set_rit;
*set_xit = *Hamlibc::Rig_set_xit;
*set_ts = *Hamlibc::Rig_set_ts;
*set_ant = *Hamlibc::Rig_set_ant;
*set_func = *Hamlibc::Rig_set_func;
*set_ext_func = *Hamlibc::Rig_set_ext_func;
*set_bank = *Hamlibc::Rig_set_bank;
*set_mem = *Hamlibc::Rig_set_mem;
*send_dtmf = *Hamlibc::Rig_send_dtmf;
*send_morse = *Hamlibc::Rig_send_morse;
*vfo_op = *Hamlibc::Rig_vfo_op;
*scan = *Hamlibc::Rig_scan;
*set_level = *Hamlibc::Rig_set_level;
*set_ext_level = *Hamlibc::Rig_set_ext_level;
*get_level_i = *Hamlibc::Rig_get_level_i;
*get_level_f = *Hamlibc::Rig_get_level_f;
*set_vfo = *Hamlibc::Rig_set_vfo;
*set_powerstat = *Hamlibc::Rig_set_powerstat;
*set_trn = *Hamlibc::Rig_set_trn;
*has_get_level = *Hamlibc::Rig_has_get_level;
*has_set_parm = *Hamlibc::Rig_has_set_parm;
*has_set_func = *Hamlibc::Rig_has_set_func;
*reset = *Hamlibc::Rig_reset;
*has_scan = *Hamlibc::Rig_has_scan;
*has_vfo_op = *Hamlibc::Rig_has_vfo_op;
*passband_normal = *Hamlibc::Rig_passband_normal;
*passband_narrow = *Hamlibc::Rig_passband_narrow;
*passband_wide = *Hamlibc::Rig_passband_wide;
*ext_token_lookup = *Hamlibc::Rig_ext_token_lookup;
*token_lookup = *Hamlibc::Rig_token_lookup;
*set_ext_parm = *Hamlibc::Rig_set_ext_parm;
*set_parm = *Hamlibc::Rig_set_parm;
*get_parm_i = *Hamlibc::Rig_get_parm_i;
*get_parm_f = *Hamlibc::Rig_get_parm_f;
*set_conf = *Hamlibc::Rig_set_conf;
*get_freq = *Hamlibc::Rig_get_freq;
*get_mode = *Hamlibc::Rig_get_mode;
*get_split_mode = *Hamlibc::Rig_get_split_mode;
*get_vfo = *Hamlibc::Rig_get_vfo;
*get_ptt = *Hamlibc::Rig_get_ptt;
*get_rptr_shift = *Hamlibc::Rig_get_rptr_shift;
*get_rptr_offs = *Hamlibc::Rig_get_rptr_offs;
*get_ctcss_tone = *Hamlibc::Rig_get_ctcss_tone;
*get_dcs_code = *Hamlibc::Rig_get_dcs_code;
*get_ctcss_sql = *Hamlibc::Rig_get_ctcss_sql;
*get_dcs_sql = *Hamlibc::Rig_get_dcs_sql;
*get_split_freq = *Hamlibc::Rig_get_split_freq;
*get_split_vfo = *Hamlibc::Rig_get_split_vfo;
*get_rit = *Hamlibc::Rig_get_rit;
*get_xit = *Hamlibc::Rig_get_xit;
*get_ts = *Hamlibc::Rig_get_ts;
*get_ant = *Hamlibc::Rig_get_ant;
*get_vfo_info = *Hamlibc::Rig_get_vfo_info;
*get_mem = *Hamlibc::Rig_get_mem;
*get_powerstat = *Hamlibc::Rig_get_powerstat;
*get_trn = *Hamlibc::Rig_get_trn;
*get_dcd = *Hamlibc::Rig_get_dcd;
*mem_count = *Hamlibc::Rig_mem_count;
*lookup_mem_caps = *Hamlibc::Rig_lookup_mem_caps;
*set_channel = *Hamlibc::Rig_set_channel;
*chan_clear = *Hamlibc::Rig_chan_clear;
*get_chan_all = *Hamlibc::Rig_get_chan_all;
*get_channel = *Hamlibc::Rig_get_channel;
*get_conf = *Hamlibc::Rig_get_conf;
*recv_dtmf = *Hamlibc::Rig_recv_dtmf;
*get_info = *Hamlibc::Rig_get_info;
*get_func = *Hamlibc::Rig_get_func;
*get_ext_func = *Hamlibc::Rig_get_ext_func;
*get_level = *Hamlibc::Rig_get_level;
*get_ext_level = *Hamlibc::Rig_get_ext_level;
*get_parm = *Hamlibc::Rig_get_parm;
*get_ext_parm = *Hamlibc::Rig_get_ext_parm;
sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::channelArray ##############

package Hamlib::channelArray;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_channelArray(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_channelArray($self);
        delete $OWNER{$self};
    }
}

*getitem = *Hamlibc::channelArray_getitem;
*setitem = *Hamlibc::channelArray_setitem;
*cast = *Hamlibc::channelArray_cast;
*frompointer = *Hamlibc::channelArray_frompointer;
sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::toneArray ##############

package Hamlib::toneArray;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_toneArray(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_toneArray($self);
        delete $OWNER{$self};
    }
}

*getitem = *Hamlibc::toneArray_getitem;
*setitem = *Hamlibc::toneArray_setitem;
*cast = *Hamlibc::toneArray_cast;
*frompointer = *Hamlibc::toneArray_frompointer;
sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::Rot ##############

package Hamlib::Rot;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_rot_get = *Hamlibc::Rot_rot_get;
*swig_rot_set = *Hamlibc::Rot_rot_set;
*swig_caps_get = *Hamlibc::Rot_caps_get;
*swig_caps_set = *Hamlibc::Rot_caps_set;
*swig_state_get = *Hamlibc::Rot_state_get;
*swig_state_set = *Hamlibc::Rot_state_set;
*swig_error_status_get = *Hamlibc::Rot_error_status_get;
*swig_error_status_set = *Hamlibc::Rot_error_status_set;
*swig_do_exception_get = *Hamlibc::Rot_do_exception_get;
*swig_do_exception_set = *Hamlibc::Rot_do_exception_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_Rot(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_Rot($self);
        delete $OWNER{$self};
    }
}

*open = *Hamlibc::Rot_open;
*close = *Hamlibc::Rot_close;
*set_position = *Hamlibc::Rot_set_position;
*get_position = *Hamlibc::Rot_get_position;
*stop = *Hamlibc::Rot_stop;
*park = *Hamlibc::Rot_park;
*reset = *Hamlibc::Rot_reset;
*move = *Hamlibc::Rot_move;
*token_lookup = *Hamlibc::Rot_token_lookup;
*set_conf = *Hamlibc::Rot_set_conf;
*get_conf = *Hamlibc::Rot_get_conf;
*get_info = *Hamlibc::Rot_get_info;
sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Hamlib::Amp ##############

package Hamlib::Amp;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Hamlib );
%OWNER = ();
%ITERATORS = ();
*swig_amp_get = *Hamlibc::Amp_amp_get;
*swig_amp_set = *Hamlibc::Amp_amp_set;
*swig_caps_get = *Hamlibc::Amp_caps_get;
*swig_caps_set = *Hamlibc::Amp_caps_set;
*swig_state_get = *Hamlibc::Amp_state_get;
*swig_state_set = *Hamlibc::Amp_state_set;
*swig_error_status_get = *Hamlibc::Amp_error_status_get;
*swig_error_status_set = *Hamlibc::Amp_error_status_set;
*swig_do_exception_get = *Hamlibc::Amp_do_exception_get;
*swig_do_exception_set = *Hamlibc::Amp_do_exception_set;
sub new {
    my $pkg = shift;
    my $self = Hamlibc::new_Amp(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Hamlibc::delete_Amp($self);
        delete $OWNER{$self};
    }
}

*open = *Hamlibc::Amp_open;
*close = *Hamlibc::Amp_close;
*reset = *Hamlibc::Amp_reset;
*token_lookup = *Hamlibc::Amp_token_lookup;
*set_freq = *Hamlibc::Amp_set_freq;
*set_powerstat = *Hamlibc::Amp_set_powerstat;
*set_conf = *Hamlibc::Amp_set_conf;
*get_conf = *Hamlibc::Amp_get_conf;
*get_info = *Hamlibc::Amp_get_info;
sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


# ------- VARIABLE STUBS --------

package Hamlib;

*MAX_MODELS_PER_BACKEND = *Hamlibc::MAX_MODELS_PER_BACKEND;
*RIG_MODEL_NONE = *Hamlibc::RIG_MODEL_NONE;
*RIG_MODEL_DUMMY = *Hamlibc::RIG_MODEL_DUMMY;
*RIG_MODEL_NETRIGCTL = *Hamlibc::RIG_MODEL_NETRIGCTL;
*RIG_MODEL_ARMSTRONG = *Hamlibc::RIG_MODEL_ARMSTRONG;
*RIG_MODEL_FLRIG = *Hamlibc::RIG_MODEL_FLRIG;
*RIG_MODEL_TRXMANAGER_RIG = *Hamlibc::RIG_MODEL_TRXMANAGER_RIG;
*RIG_MODEL_DUMMY_NOVFO = *Hamlibc::RIG_MODEL_DUMMY_NOVFO;
*RIG_MODEL_TCI1X = *Hamlibc::RIG_MODEL_TCI1X;
*RIG_MODEL_FT847 = *Hamlibc::RIG_MODEL_FT847;
*RIG_MODEL_FT1000 = *Hamlibc::RIG_MODEL_FT1000;
*RIG_MODEL_FT1000D = *Hamlibc::RIG_MODEL_FT1000D;
*RIG_MODEL_FT1000MPMKV = *Hamlibc::RIG_MODEL_FT1000MPMKV;
*RIG_MODEL_FT747 = *Hamlibc::RIG_MODEL_FT747;
*RIG_MODEL_FT757 = *Hamlibc::RIG_MODEL_FT757;
*RIG_MODEL_FT757GXII = *Hamlibc::RIG_MODEL_FT757GXII;
*RIG_MODEL_FT575 = *Hamlibc::RIG_MODEL_FT575;
*RIG_MODEL_FT767 = *Hamlibc::RIG_MODEL_FT767;
*RIG_MODEL_FT736R = *Hamlibc::RIG_MODEL_FT736R;
*RIG_MODEL_FT840 = *Hamlibc::RIG_MODEL_FT840;
*RIG_MODEL_FT820 = *Hamlibc::RIG_MODEL_FT820;
*RIG_MODEL_FT900 = *Hamlibc::RIG_MODEL_FT900;
*RIG_MODEL_FT920 = *Hamlibc::RIG_MODEL_FT920;
*RIG_MODEL_FT890 = *Hamlibc::RIG_MODEL_FT890;
*RIG_MODEL_FT990 = *Hamlibc::RIG_MODEL_FT990;
*RIG_MODEL_FRG100 = *Hamlibc::RIG_MODEL_FRG100;
*RIG_MODEL_FRG9600 = *Hamlibc::RIG_MODEL_FRG9600;
*RIG_MODEL_FRG8800 = *Hamlibc::RIG_MODEL_FRG8800;
*RIG_MODEL_FT817 = *Hamlibc::RIG_MODEL_FT817;
*RIG_MODEL_FT100 = *Hamlibc::RIG_MODEL_FT100;
*RIG_MODEL_FT857 = *Hamlibc::RIG_MODEL_FT857;
*RIG_MODEL_FT897 = *Hamlibc::RIG_MODEL_FT897;
*RIG_MODEL_FT1000MP = *Hamlibc::RIG_MODEL_FT1000MP;
*RIG_MODEL_FT1000MPMKVFLD = *Hamlibc::RIG_MODEL_FT1000MPMKVFLD;
*RIG_MODEL_VR5000 = *Hamlibc::RIG_MODEL_VR5000;
*RIG_MODEL_FT450 = *Hamlibc::RIG_MODEL_FT450;
*RIG_MODEL_FT950 = *Hamlibc::RIG_MODEL_FT950;
*RIG_MODEL_FT2000 = *Hamlibc::RIG_MODEL_FT2000;
*RIG_MODEL_FT9000 = *Hamlibc::RIG_MODEL_FT9000;
*RIG_MODEL_FT980 = *Hamlibc::RIG_MODEL_FT980;
*RIG_MODEL_FTDX5000 = *Hamlibc::RIG_MODEL_FTDX5000;
*RIG_MODEL_VX1700 = *Hamlibc::RIG_MODEL_VX1700;
*RIG_MODEL_FTDX1200 = *Hamlibc::RIG_MODEL_FTDX1200;
*RIG_MODEL_FT991 = *Hamlibc::RIG_MODEL_FT991;
*RIG_MODEL_FT891 = *Hamlibc::RIG_MODEL_FT891;
*RIG_MODEL_FTDX3000 = *Hamlibc::RIG_MODEL_FTDX3000;
*RIG_MODEL_FT847UNI = *Hamlibc::RIG_MODEL_FT847UNI;
*RIG_MODEL_FT600 = *Hamlibc::RIG_MODEL_FT600;
*RIG_MODEL_FTDX101D = *Hamlibc::RIG_MODEL_FTDX101D;
*RIG_MODEL_FT818 = *Hamlibc::RIG_MODEL_FT818;
*RIG_MODEL_FTDX10 = *Hamlibc::RIG_MODEL_FTDX10;
*RIG_MODEL_FT897D = *Hamlibc::RIG_MODEL_FT897D;
*RIG_MODEL_FTDX101MP = *Hamlibc::RIG_MODEL_FTDX101MP;
*RIG_MODEL_MCHFQRP = *Hamlibc::RIG_MODEL_MCHFQRP;
*RIG_MODEL_TS50 = *Hamlibc::RIG_MODEL_TS50;
*RIG_MODEL_TS440 = *Hamlibc::RIG_MODEL_TS440;
*RIG_MODEL_TS450S = *Hamlibc::RIG_MODEL_TS450S;
*RIG_MODEL_TS570D = *Hamlibc::RIG_MODEL_TS570D;
*RIG_MODEL_TS690S = *Hamlibc::RIG_MODEL_TS690S;
*RIG_MODEL_TS711 = *Hamlibc::RIG_MODEL_TS711;
*RIG_MODEL_TS790 = *Hamlibc::RIG_MODEL_TS790;
*RIG_MODEL_TS811 = *Hamlibc::RIG_MODEL_TS811;
*RIG_MODEL_TS850 = *Hamlibc::RIG_MODEL_TS850;
*RIG_MODEL_TS870S = *Hamlibc::RIG_MODEL_TS870S;
*RIG_MODEL_TS940 = *Hamlibc::RIG_MODEL_TS940;
*RIG_MODEL_TS950S = *Hamlibc::RIG_MODEL_TS950S;
*RIG_MODEL_TS950SDX = *Hamlibc::RIG_MODEL_TS950SDX;
*RIG_MODEL_TS2000 = *Hamlibc::RIG_MODEL_TS2000;
*RIG_MODEL_R5000 = *Hamlibc::RIG_MODEL_R5000;
*RIG_MODEL_TS570S = *Hamlibc::RIG_MODEL_TS570S;
*RIG_MODEL_THD7A = *Hamlibc::RIG_MODEL_THD7A;
*RIG_MODEL_THD7AG = *Hamlibc::RIG_MODEL_THD7AG;
*RIG_MODEL_THF6A = *Hamlibc::RIG_MODEL_THF6A;
*RIG_MODEL_THF7E = *Hamlibc::RIG_MODEL_THF7E;
*RIG_MODEL_K2 = *Hamlibc::RIG_MODEL_K2;
*RIG_MODEL_TS930 = *Hamlibc::RIG_MODEL_TS930;
*RIG_MODEL_THG71 = *Hamlibc::RIG_MODEL_THG71;
*RIG_MODEL_TS680S = *Hamlibc::RIG_MODEL_TS680S;
*RIG_MODEL_TS140S = *Hamlibc::RIG_MODEL_TS140S;
*RIG_MODEL_TMD700 = *Hamlibc::RIG_MODEL_TMD700;
*RIG_MODEL_TMV7 = *Hamlibc::RIG_MODEL_TMV7;
*RIG_MODEL_TS480 = *Hamlibc::RIG_MODEL_TS480;
*RIG_MODEL_K3 = *Hamlibc::RIG_MODEL_K3;
*RIG_MODEL_TRC80 = *Hamlibc::RIG_MODEL_TRC80;
*RIG_MODEL_TS590S = *Hamlibc::RIG_MODEL_TS590S;
*RIG_MODEL_TRANSFOX = *Hamlibc::RIG_MODEL_TRANSFOX;
*RIG_MODEL_THD72A = *Hamlibc::RIG_MODEL_THD72A;
*RIG_MODEL_TMD710 = *Hamlibc::RIG_MODEL_TMD710;
*RIG_MODEL_TMV71 = *Hamlibc::RIG_MODEL_TMV71;
*RIG_MODEL_F6K = *Hamlibc::RIG_MODEL_F6K;
*RIG_MODEL_TS590SG = *Hamlibc::RIG_MODEL_TS590SG;
*RIG_MODEL_XG3 = *Hamlibc::RIG_MODEL_XG3;
*RIG_MODEL_TS990S = *Hamlibc::RIG_MODEL_TS990S;
*RIG_MODEL_HPSDR = *Hamlibc::RIG_MODEL_HPSDR;
*RIG_MODEL_TS890S = *Hamlibc::RIG_MODEL_TS890S;
*RIG_MODEL_THD74 = *Hamlibc::RIG_MODEL_THD74;
*RIG_MODEL_K3S = *Hamlibc::RIG_MODEL_K3S;
*RIG_MODEL_KX2 = *Hamlibc::RIG_MODEL_KX2;
*RIG_MODEL_KX3 = *Hamlibc::RIG_MODEL_KX3;
*RIG_MODEL_PT8000A = *Hamlibc::RIG_MODEL_PT8000A;
*RIG_MODEL_K4 = *Hamlibc::RIG_MODEL_K4;
*RIG_MODEL_POWERSDR = *Hamlibc::RIG_MODEL_POWERSDR;
*RIG_MODEL_MALACHITE = *Hamlibc::RIG_MODEL_MALACHITE;
*RIG_MODEL_IC1271 = *Hamlibc::RIG_MODEL_IC1271;
*RIG_MODEL_IC1275 = *Hamlibc::RIG_MODEL_IC1275;
*RIG_MODEL_IC271 = *Hamlibc::RIG_MODEL_IC271;
*RIG_MODEL_IC275 = *Hamlibc::RIG_MODEL_IC275;
*RIG_MODEL_IC375 = *Hamlibc::RIG_MODEL_IC375;
*RIG_MODEL_IC471 = *Hamlibc::RIG_MODEL_IC471;
*RIG_MODEL_IC475 = *Hamlibc::RIG_MODEL_IC475;
*RIG_MODEL_IC575 = *Hamlibc::RIG_MODEL_IC575;
*RIG_MODEL_IC706 = *Hamlibc::RIG_MODEL_IC706;
*RIG_MODEL_IC706MKII = *Hamlibc::RIG_MODEL_IC706MKII;
*RIG_MODEL_IC706MKIIG = *Hamlibc::RIG_MODEL_IC706MKIIG;
*RIG_MODEL_IC707 = *Hamlibc::RIG_MODEL_IC707;
*RIG_MODEL_IC718 = *Hamlibc::RIG_MODEL_IC718;
*RIG_MODEL_IC725 = *Hamlibc::RIG_MODEL_IC725;
*RIG_MODEL_IC726 = *Hamlibc::RIG_MODEL_IC726;
*RIG_MODEL_IC728 = *Hamlibc::RIG_MODEL_IC728;
*RIG_MODEL_IC729 = *Hamlibc::RIG_MODEL_IC729;
*RIG_MODEL_IC731 = *Hamlibc::RIG_MODEL_IC731;
*RIG_MODEL_IC735 = *Hamlibc::RIG_MODEL_IC735;
*RIG_MODEL_IC736 = *Hamlibc::RIG_MODEL_IC736;
*RIG_MODEL_IC737 = *Hamlibc::RIG_MODEL_IC737;
*RIG_MODEL_IC738 = *Hamlibc::RIG_MODEL_IC738;
*RIG_MODEL_IC746 = *Hamlibc::RIG_MODEL_IC746;
*RIG_MODEL_IC751 = *Hamlibc::RIG_MODEL_IC751;
*RIG_MODEL_IC751A = *Hamlibc::RIG_MODEL_IC751A;
*RIG_MODEL_IC756 = *Hamlibc::RIG_MODEL_IC756;
*RIG_MODEL_IC756PRO = *Hamlibc::RIG_MODEL_IC756PRO;
*RIG_MODEL_IC761 = *Hamlibc::RIG_MODEL_IC761;
*RIG_MODEL_IC765 = *Hamlibc::RIG_MODEL_IC765;
*RIG_MODEL_IC775 = *Hamlibc::RIG_MODEL_IC775;
*RIG_MODEL_IC781 = *Hamlibc::RIG_MODEL_IC781;
*RIG_MODEL_IC820 = *Hamlibc::RIG_MODEL_IC820;
*RIG_MODEL_IC821H = *Hamlibc::RIG_MODEL_IC821H;
*RIG_MODEL_IC970 = *Hamlibc::RIG_MODEL_IC970;
*RIG_MODEL_ICR10 = *Hamlibc::RIG_MODEL_ICR10;
*RIG_MODEL_ICR71 = *Hamlibc::RIG_MODEL_ICR71;
*RIG_MODEL_ICR72 = *Hamlibc::RIG_MODEL_ICR72;
*RIG_MODEL_ICR75 = *Hamlibc::RIG_MODEL_ICR75;
*RIG_MODEL_ICR7000 = *Hamlibc::RIG_MODEL_ICR7000;
*RIG_MODEL_ICR7100 = *Hamlibc::RIG_MODEL_ICR7100;
*RIG_MODEL_ICR8500 = *Hamlibc::RIG_MODEL_ICR8500;
*RIG_MODEL_ICR9000 = *Hamlibc::RIG_MODEL_ICR9000;
*RIG_MODEL_IC910 = *Hamlibc::RIG_MODEL_IC910;
*RIG_MODEL_IC78 = *Hamlibc::RIG_MODEL_IC78;
*RIG_MODEL_IC746PRO = *Hamlibc::RIG_MODEL_IC746PRO;
*RIG_MODEL_IC756PROII = *Hamlibc::RIG_MODEL_IC756PROII;
*RIG_MODEL_ICID1 = *Hamlibc::RIG_MODEL_ICID1;
*RIG_MODEL_IC703 = *Hamlibc::RIG_MODEL_IC703;
*RIG_MODEL_IC7800 = *Hamlibc::RIG_MODEL_IC7800;
*RIG_MODEL_IC756PROIII = *Hamlibc::RIG_MODEL_IC756PROIII;
*RIG_MODEL_ICR20 = *Hamlibc::RIG_MODEL_ICR20;
*RIG_MODEL_IC7000 = *Hamlibc::RIG_MODEL_IC7000;
*RIG_MODEL_IC7200 = *Hamlibc::RIG_MODEL_IC7200;
*RIG_MODEL_IC7700 = *Hamlibc::RIG_MODEL_IC7700;
*RIG_MODEL_IC7600 = *Hamlibc::RIG_MODEL_IC7600;
*RIG_MODEL_IC92D = *Hamlibc::RIG_MODEL_IC92D;
*RIG_MODEL_ICR9500 = *Hamlibc::RIG_MODEL_ICR9500;
*RIG_MODEL_IC7410 = *Hamlibc::RIG_MODEL_IC7410;
*RIG_MODEL_IC9100 = *Hamlibc::RIG_MODEL_IC9100;
*RIG_MODEL_ICRX7 = *Hamlibc::RIG_MODEL_ICRX7;
*RIG_MODEL_IC7100 = *Hamlibc::RIG_MODEL_IC7100;
*RIG_MODEL_ID5100 = *Hamlibc::RIG_MODEL_ID5100;
*RIG_MODEL_IC2730 = *Hamlibc::RIG_MODEL_IC2730;
*RIG_MODEL_IC7300 = *Hamlibc::RIG_MODEL_IC7300;
*RIG_MODEL_PERSEUS = *Hamlibc::RIG_MODEL_PERSEUS;
*RIG_MODEL_IC785x = *Hamlibc::RIG_MODEL_IC785x;
*RIG_MODEL_X108G = *Hamlibc::RIG_MODEL_X108G;
*RIG_MODEL_ICR6 = *Hamlibc::RIG_MODEL_ICR6;
*RIG_MODEL_IC7610 = *Hamlibc::RIG_MODEL_IC7610;
*RIG_MODEL_ICR8600 = *Hamlibc::RIG_MODEL_ICR8600;
*RIG_MODEL_ICR30 = *Hamlibc::RIG_MODEL_ICR30;
*RIG_MODEL_IC9700 = *Hamlibc::RIG_MODEL_IC9700;
*RIG_MODEL_ID4100 = *Hamlibc::RIG_MODEL_ID4100;
*RIG_MODEL_ID31 = *Hamlibc::RIG_MODEL_ID31;
*RIG_MODEL_ID51 = *Hamlibc::RIG_MODEL_ID51;
*RIG_MODEL_IC705 = *Hamlibc::RIG_MODEL_IC705;
*RIG_MODEL_MINISCOUT = *Hamlibc::RIG_MODEL_MINISCOUT;
*RIG_MODEL_XPLORER = *Hamlibc::RIG_MODEL_XPLORER;
*RIG_MODEL_OS535 = *Hamlibc::RIG_MODEL_OS535;
*RIG_MODEL_OS456 = *Hamlibc::RIG_MODEL_OS456;
*RIG_MODEL_OMNIVI = *Hamlibc::RIG_MODEL_OMNIVI;
*RIG_MODEL_OMNIVIP = *Hamlibc::RIG_MODEL_OMNIVIP;
*RIG_MODEL_PARAGON2 = *Hamlibc::RIG_MODEL_PARAGON2;
*RIG_MODEL_DELTAII = *Hamlibc::RIG_MODEL_DELTAII;
*RIG_MODEL_PCR1000 = *Hamlibc::RIG_MODEL_PCR1000;
*RIG_MODEL_PCR100 = *Hamlibc::RIG_MODEL_PCR100;
*RIG_MODEL_PCR1500 = *Hamlibc::RIG_MODEL_PCR1500;
*RIG_MODEL_PCR2500 = *Hamlibc::RIG_MODEL_PCR2500;
*RIG_MODEL_AR8200 = *Hamlibc::RIG_MODEL_AR8200;
*RIG_MODEL_AR8000 = *Hamlibc::RIG_MODEL_AR8000;
*RIG_MODEL_AR7030 = *Hamlibc::RIG_MODEL_AR7030;
*RIG_MODEL_AR5000 = *Hamlibc::RIG_MODEL_AR5000;
*RIG_MODEL_AR3030 = *Hamlibc::RIG_MODEL_AR3030;
*RIG_MODEL_AR3000A = *Hamlibc::RIG_MODEL_AR3000A;
*RIG_MODEL_AR3000 = *Hamlibc::RIG_MODEL_AR3000;
*RIG_MODEL_AR2700 = *Hamlibc::RIG_MODEL_AR2700;
*RIG_MODEL_AR2500 = *Hamlibc::RIG_MODEL_AR2500;
*RIG_MODEL_AR16 = *Hamlibc::RIG_MODEL_AR16;
*RIG_MODEL_SDU5500 = *Hamlibc::RIG_MODEL_SDU5500;
*RIG_MODEL_SDU5000 = *Hamlibc::RIG_MODEL_SDU5000;
*RIG_MODEL_AR8600 = *Hamlibc::RIG_MODEL_AR8600;
*RIG_MODEL_AR5000A = *Hamlibc::RIG_MODEL_AR5000A;
*RIG_MODEL_AR7030P = *Hamlibc::RIG_MODEL_AR7030P;
*RIG_MODEL_SR2200 = *Hamlibc::RIG_MODEL_SR2200;
*RIG_MODEL_JST145 = *Hamlibc::RIG_MODEL_JST145;
*RIG_MODEL_JST245 = *Hamlibc::RIG_MODEL_JST245;
*RIG_MODEL_CMH530 = *Hamlibc::RIG_MODEL_CMH530;
*RIG_MODEL_NRD345 = *Hamlibc::RIG_MODEL_NRD345;
*RIG_MODEL_NRD525 = *Hamlibc::RIG_MODEL_NRD525;
*RIG_MODEL_NRD535 = *Hamlibc::RIG_MODEL_NRD535;
*RIG_MODEL_NRD545 = *Hamlibc::RIG_MODEL_NRD545;
*RIG_MODEL_RS64 = *Hamlibc::RIG_MODEL_RS64;
*RIG_MODEL_RS2005 = *Hamlibc::RIG_MODEL_RS2005;
*RIG_MODEL_RS2006 = *Hamlibc::RIG_MODEL_RS2006;
*RIG_MODEL_RS2035 = *Hamlibc::RIG_MODEL_RS2035;
*RIG_MODEL_RS2042 = *Hamlibc::RIG_MODEL_RS2042;
*RIG_MODEL_RS2041 = *Hamlibc::RIG_MODEL_RS2041;
*RIG_MODEL_BC780 = *Hamlibc::RIG_MODEL_BC780;
*RIG_MODEL_BC245 = *Hamlibc::RIG_MODEL_BC245;
*RIG_MODEL_BC895 = *Hamlibc::RIG_MODEL_BC895;
*RIG_MODEL_PRO2052 = *Hamlibc::RIG_MODEL_PRO2052;
*RIG_MODEL_BC235 = *Hamlibc::RIG_MODEL_BC235;
*RIG_MODEL_BC250 = *Hamlibc::RIG_MODEL_BC250;
*RIG_MODEL_BC785 = *Hamlibc::RIG_MODEL_BC785;
*RIG_MODEL_BC786 = *Hamlibc::RIG_MODEL_BC786;
*RIG_MODEL_BCT8 = *Hamlibc::RIG_MODEL_BCT8;
*RIG_MODEL_BCD396T = *Hamlibc::RIG_MODEL_BCD396T;
*RIG_MODEL_BCD996T = *Hamlibc::RIG_MODEL_BCD996T;
*RIG_MODEL_BC898 = *Hamlibc::RIG_MODEL_BC898;
*RIG_MODEL_DKR8 = *Hamlibc::RIG_MODEL_DKR8;
*RIG_MODEL_DKR8A = *Hamlibc::RIG_MODEL_DKR8A;
*RIG_MODEL_DKR8B = *Hamlibc::RIG_MODEL_DKR8B;
*RIG_MODEL_HF150 = *Hamlibc::RIG_MODEL_HF150;
*RIG_MODEL_HF225 = *Hamlibc::RIG_MODEL_HF225;
*RIG_MODEL_HF250 = *Hamlibc::RIG_MODEL_HF250;
*RIG_MODEL_HF235 = *Hamlibc::RIG_MODEL_HF235;
*RIG_MODEL_RA3790 = *Hamlibc::RIG_MODEL_RA3790;
*RIG_MODEL_RA3720 = *Hamlibc::RIG_MODEL_RA3720;
*RIG_MODEL_RA6790 = *Hamlibc::RIG_MODEL_RA6790;
*RIG_MODEL_RA3710 = *Hamlibc::RIG_MODEL_RA3710;
*RIG_MODEL_RA3702 = *Hamlibc::RIG_MODEL_RA3702;
*RIG_MODEL_HF1000 = *Hamlibc::RIG_MODEL_HF1000;
*RIG_MODEL_HF1000A = *Hamlibc::RIG_MODEL_HF1000A;
*RIG_MODEL_WJ8711 = *Hamlibc::RIG_MODEL_WJ8711;
*RIG_MODEL_WJ8888 = *Hamlibc::RIG_MODEL_WJ8888;
*RIG_MODEL_ESM500 = *Hamlibc::RIG_MODEL_ESM500;
*RIG_MODEL_EK890 = *Hamlibc::RIG_MODEL_EK890;
*RIG_MODEL_EK891 = *Hamlibc::RIG_MODEL_EK891;
*RIG_MODEL_EK895 = *Hamlibc::RIG_MODEL_EK895;
*RIG_MODEL_EK070 = *Hamlibc::RIG_MODEL_EK070;
*RIG_MODEL_TRP7000 = *Hamlibc::RIG_MODEL_TRP7000;
*RIG_MODEL_TRP8000 = *Hamlibc::RIG_MODEL_TRP8000;
*RIG_MODEL_TRP9000 = *Hamlibc::RIG_MODEL_TRP9000;
*RIG_MODEL_TRP8255 = *Hamlibc::RIG_MODEL_TRP8255;
*RIG_MODEL_WR1000 = *Hamlibc::RIG_MODEL_WR1000;
*RIG_MODEL_WR1500 = *Hamlibc::RIG_MODEL_WR1500;
*RIG_MODEL_WR1550 = *Hamlibc::RIG_MODEL_WR1550;
*RIG_MODEL_WR3100 = *Hamlibc::RIG_MODEL_WR3100;
*RIG_MODEL_WR3150 = *Hamlibc::RIG_MODEL_WR3150;
*RIG_MODEL_WR3500 = *Hamlibc::RIG_MODEL_WR3500;
*RIG_MODEL_WR3700 = *Hamlibc::RIG_MODEL_WR3700;
*RIG_MODEL_G303 = *Hamlibc::RIG_MODEL_G303;
*RIG_MODEL_G313 = *Hamlibc::RIG_MODEL_G313;
*RIG_MODEL_G305 = *Hamlibc::RIG_MODEL_G305;
*RIG_MODEL_G315 = *Hamlibc::RIG_MODEL_G315;
*RIG_MODEL_TT550 = *Hamlibc::RIG_MODEL_TT550;
*RIG_MODEL_TT538 = *Hamlibc::RIG_MODEL_TT538;
*RIG_MODEL_RX320 = *Hamlibc::RIG_MODEL_RX320;
*RIG_MODEL_RX340 = *Hamlibc::RIG_MODEL_RX340;
*RIG_MODEL_RX350 = *Hamlibc::RIG_MODEL_RX350;
*RIG_MODEL_TT526 = *Hamlibc::RIG_MODEL_TT526;
*RIG_MODEL_TT516 = *Hamlibc::RIG_MODEL_TT516;
*RIG_MODEL_TT565 = *Hamlibc::RIG_MODEL_TT565;
*RIG_MODEL_TT585 = *Hamlibc::RIG_MODEL_TT585;
*RIG_MODEL_TT588 = *Hamlibc::RIG_MODEL_TT588;
*RIG_MODEL_RX331 = *Hamlibc::RIG_MODEL_RX331;
*RIG_MODEL_TT599 = *Hamlibc::RIG_MODEL_TT599;
*RIG_MODEL_DX77 = *Hamlibc::RIG_MODEL_DX77;
*RIG_MODEL_DXSR8 = *Hamlibc::RIG_MODEL_DXSR8;
*RIG_MODEL_505DSP = *Hamlibc::RIG_MODEL_505DSP;
*RIG_MODEL_GNURADIO = *Hamlibc::RIG_MODEL_GNURADIO;
*RIG_MODEL_MC4020 = *Hamlibc::RIG_MODEL_MC4020;
*RIG_MODEL_GRAUDIO = *Hamlibc::RIG_MODEL_GRAUDIO;
*RIG_MODEL_GRAUDIOIQ = *Hamlibc::RIG_MODEL_GRAUDIOIQ;
*RIG_MODEL_USRP_G = *Hamlibc::RIG_MODEL_USRP_G;
*RIG_MODEL_MICROTUNE_4937 = *Hamlibc::RIG_MODEL_MICROTUNE_4937;
*RIG_MODEL_MICROTUNE_4702 = *Hamlibc::RIG_MODEL_MICROTUNE_4702;
*RIG_MODEL_MICROTUNE_4707 = *Hamlibc::RIG_MODEL_MICROTUNE_4707;
*RIG_MODEL_DSP10 = *Hamlibc::RIG_MODEL_DSP10;
*RIG_MODEL_SDR1000 = *Hamlibc::RIG_MODEL_SDR1000;
*RIG_MODEL_SDR1000RFE = *Hamlibc::RIG_MODEL_SDR1000RFE;
*RIG_MODEL_DTTSP = *Hamlibc::RIG_MODEL_DTTSP;
*RIG_MODEL_DTTSP_UDP = *Hamlibc::RIG_MODEL_DTTSP_UDP;
*RIG_MODEL_EKD500 = *Hamlibc::RIG_MODEL_EKD500;
*RIG_MODEL_ELEKTOR304 = *Hamlibc::RIG_MODEL_ELEKTOR304;
*RIG_MODEL_DRT1 = *Hamlibc::RIG_MODEL_DRT1;
*RIG_MODEL_DWT = *Hamlibc::RIG_MODEL_DWT;
*RIG_MODEL_USRP0 = *Hamlibc::RIG_MODEL_USRP0;
*RIG_MODEL_USRP = *Hamlibc::RIG_MODEL_USRP;
*RIG_MODEL_DDS60 = *Hamlibc::RIG_MODEL_DDS60;
*RIG_MODEL_ELEKTOR507 = *Hamlibc::RIG_MODEL_ELEKTOR507;
*RIG_MODEL_MINIVNA = *Hamlibc::RIG_MODEL_MINIVNA;
*RIG_MODEL_SI570AVRUSB = *Hamlibc::RIG_MODEL_SI570AVRUSB;
*RIG_MODEL_PMSDR = *Hamlibc::RIG_MODEL_PMSDR;
*RIG_MODEL_SI570PICUSB = *Hamlibc::RIG_MODEL_SI570PICUSB;
*RIG_MODEL_FIFISDR = *Hamlibc::RIG_MODEL_FIFISDR;
*RIG_MODEL_FUNCUBEDONGLE = *Hamlibc::RIG_MODEL_FUNCUBEDONGLE;
*RIG_MODEL_HIQSDR = *Hamlibc::RIG_MODEL_HIQSDR;
*RIG_MODEL_FASDR = *Hamlibc::RIG_MODEL_FASDR;
*RIG_MODEL_SI570PEABERRY1 = *Hamlibc::RIG_MODEL_SI570PEABERRY1;
*RIG_MODEL_SI570PEABERRY2 = *Hamlibc::RIG_MODEL_SI570PEABERRY2;
*RIG_MODEL_FUNCUBEDONGLEPLUS = *Hamlibc::RIG_MODEL_FUNCUBEDONGLEPLUS;
*RIG_MODEL_RSHFIQ = *Hamlibc::RIG_MODEL_RSHFIQ;
*RIG_MODEL_V4L = *Hamlibc::RIG_MODEL_V4L;
*RIG_MODEL_V4L2 = *Hamlibc::RIG_MODEL_V4L2;
*RIG_MODEL_ESMC = *Hamlibc::RIG_MODEL_ESMC;
*RIG_MODEL_EB200 = *Hamlibc::RIG_MODEL_EB200;
*RIG_MODEL_XK2100 = *Hamlibc::RIG_MODEL_XK2100;
*RIG_MODEL_PRM8060 = *Hamlibc::RIG_MODEL_PRM8060;
*RIG_MODEL_PRM8070 = *Hamlibc::RIG_MODEL_PRM8070;
*RIG_MODEL_ADT_200A = *Hamlibc::RIG_MODEL_ADT_200A;
*RIG_MODEL_IC_M700PRO = *Hamlibc::RIG_MODEL_IC_M700PRO;
*RIG_MODEL_IC_M802 = *Hamlibc::RIG_MODEL_IC_M802;
*RIG_MODEL_IC_M710 = *Hamlibc::RIG_MODEL_IC_M710;
*RIG_MODEL_IC_M803 = *Hamlibc::RIG_MODEL_IC_M803;
*RIG_DORJI = *Hamlibc::RIG_DORJI;
*RIG_BACKEND_DORJI = *Hamlibc::RIG_BACKEND_DORJI;
*RIG_MODEL_DORJI_DRA818V = *Hamlibc::RIG_MODEL_DORJI_DRA818V;
*RIG_MODEL_DORJI_DRA818U = *Hamlibc::RIG_MODEL_DORJI_DRA818U;
*RIG_BARRETT = *Hamlibc::RIG_BARRETT;
*RIG_BACKEND_BARRETT = *Hamlibc::RIG_BACKEND_BARRETT;
*RIG_MODEL_BARRETT_2050 = *Hamlibc::RIG_MODEL_BARRETT_2050;
*RIG_MODEL_BARRETT_950 = *Hamlibc::RIG_MODEL_BARRETT_950;
*RIG_ELAD = *Hamlibc::RIG_ELAD;
*RIG_BACKEND_ELAD = *Hamlibc::RIG_BACKEND_ELAD;
*RIG_MODEL_ELAD_FDM_DUO = *Hamlibc::RIG_MODEL_ELAD_FDM_DUO;
*HAMLIB_COOKIE_SIZE = *Hamlibc::HAMLIB_COOKIE_SIZE;
*cookie_use = *Hamlibc::cookie_use;
*hamlib_version = *Hamlibc::hamlib_version;
*hamlib_copyright = *Hamlibc::hamlib_copyright;
*RIG_OK = *Hamlibc::RIG_OK;
*RIG_EINVAL = *Hamlibc::RIG_EINVAL;
*RIG_ECONF = *Hamlibc::RIG_ECONF;
*RIG_ENOMEM = *Hamlibc::RIG_ENOMEM;
*RIG_ENIMPL = *Hamlibc::RIG_ENIMPL;
*RIG_ETIMEOUT = *Hamlibc::RIG_ETIMEOUT;
*RIG_EIO = *Hamlibc::RIG_EIO;
*RIG_EINTERNAL = *Hamlibc::RIG_EINTERNAL;
*RIG_EPROTO = *Hamlibc::RIG_EPROTO;
*RIG_ERJCTED = *Hamlibc::RIG_ERJCTED;
*RIG_ETRUNC = *Hamlibc::RIG_ETRUNC;
*RIG_ENAVAIL = *Hamlibc::RIG_ENAVAIL;
*RIG_ENTARGET = *Hamlibc::RIG_ENTARGET;
*RIG_BUSERROR = *Hamlibc::RIG_BUSERROR;
*RIG_BUSBUSY = *Hamlibc::RIG_BUSBUSY;
*RIG_EARG = *Hamlibc::RIG_EARG;
*RIG_EVFO = *Hamlibc::RIG_EVFO;
*RIG_EDOM = *Hamlibc::RIG_EDOM;
*NETRIGCTL_RET = *Hamlibc::NETRIGCTL_RET;
*RIG_DEBUG_NONE = *Hamlibc::RIG_DEBUG_NONE;
*RIG_DEBUG_BUG = *Hamlibc::RIG_DEBUG_BUG;
*RIG_DEBUG_ERR = *Hamlibc::RIG_DEBUG_ERR;
*RIG_DEBUG_WARN = *Hamlibc::RIG_DEBUG_WARN;
*RIG_DEBUG_VERBOSE = *Hamlibc::RIG_DEBUG_VERBOSE;
*RIG_DEBUG_TRACE = *Hamlibc::RIG_DEBUG_TRACE;
*RIG_DEBUG_CACHE = *Hamlibc::RIG_DEBUG_CACHE;
*HAMLIB_RIGNAMSIZ = *Hamlibc::HAMLIB_RIGNAMSIZ;
*HAMLIB_RIGVERSIZ = *Hamlibc::HAMLIB_RIGVERSIZ;
*HAMLIB_FILPATHLEN = *Hamlibc::HAMLIB_FILPATHLEN;
*HAMLIB_FRQRANGESIZ = *Hamlibc::HAMLIB_FRQRANGESIZ;
*HAMLIB_MAXCHANDESC = *Hamlibc::HAMLIB_MAXCHANDESC;
*HAMLIB_TSLSTSIZ = *Hamlibc::HAMLIB_TSLSTSIZ;
*HAMLIB_FLTLSTSIZ = *Hamlibc::HAMLIB_FLTLSTSIZ;
*HAMLIB_MAXDBLSTSIZ = *Hamlibc::HAMLIB_MAXDBLSTSIZ;
*HAMLIB_CHANLSTSIZ = *Hamlibc::HAMLIB_CHANLSTSIZ;
*HAMLIB_MAX_AGC_LEVELS = *Hamlibc::HAMLIB_MAX_AGC_LEVELS;
*HAMLIB_MAX_SPECTRUM_SCOPES = *Hamlibc::HAMLIB_MAX_SPECTRUM_SCOPES;
*HAMLIB_MAX_SPECTRUM_MODES = *Hamlibc::HAMLIB_MAX_SPECTRUM_MODES;
*HAMLIB_MAX_SPECTRUM_AVG_MODES = *Hamlibc::HAMLIB_MAX_SPECTRUM_AVG_MODES;
*HAMLIB_MAX_SPECTRUM_SPANS = *Hamlibc::HAMLIB_MAX_SPECTRUM_SPANS;
*HAMLIB_MAX_CAL_LENGTH = *Hamlibc::HAMLIB_MAX_CAL_LENGTH;
*HAMLIB_MAX_MODES = *Hamlibc::HAMLIB_MAX_MODES;
*HAMLIB_MAX_VFOS = *Hamlibc::HAMLIB_MAX_VFOS;
*HAMLIB_MAX_ROTORS = *Hamlibc::HAMLIB_MAX_ROTORS;
*HAMLIB_MAX_VFO_OPS = *Hamlibc::HAMLIB_MAX_VFO_OPS;
*HAMLIB_MAX_RSCANS = *Hamlibc::HAMLIB_MAX_RSCANS;
*CTCSS_LIST_SIZE = *Hamlibc::CTCSS_LIST_SIZE;
*DCS_LIST_SIZE = *Hamlibc::DCS_LIST_SIZE;
*RIG_PORT_NONE = *Hamlibc::RIG_PORT_NONE;
*RIG_PORT_SERIAL = *Hamlibc::RIG_PORT_SERIAL;
*RIG_PORT_NETWORK = *Hamlibc::RIG_PORT_NETWORK;
*RIG_PORT_DEVICE = *Hamlibc::RIG_PORT_DEVICE;
*RIG_PORT_PACKET = *Hamlibc::RIG_PORT_PACKET;
*RIG_PORT_DTMF = *Hamlibc::RIG_PORT_DTMF;
*RIG_PORT_ULTRA = *Hamlibc::RIG_PORT_ULTRA;
*RIG_PORT_RPC = *Hamlibc::RIG_PORT_RPC;
*RIG_PORT_PARALLEL = *Hamlibc::RIG_PORT_PARALLEL;
*RIG_PORT_USB = *Hamlibc::RIG_PORT_USB;
*RIG_PORT_UDP_NETWORK = *Hamlibc::RIG_PORT_UDP_NETWORK;
*RIG_PORT_CM108 = *Hamlibc::RIG_PORT_CM108;
*RIG_PORT_GPIO = *Hamlibc::RIG_PORT_GPIO;
*RIG_PORT_GPION = *Hamlibc::RIG_PORT_GPION;
*RIG_PARITY_NONE = *Hamlibc::RIG_PARITY_NONE;
*RIG_PARITY_ODD = *Hamlibc::RIG_PARITY_ODD;
*RIG_PARITY_EVEN = *Hamlibc::RIG_PARITY_EVEN;
*RIG_PARITY_MARK = *Hamlibc::RIG_PARITY_MARK;
*RIG_PARITY_SPACE = *Hamlibc::RIG_PARITY_SPACE;
*RIG_HANDSHAKE_NONE = *Hamlibc::RIG_HANDSHAKE_NONE;
*RIG_HANDSHAKE_XONXOFF = *Hamlibc::RIG_HANDSHAKE_XONXOFF;
*RIG_HANDSHAKE_HARDWARE = *Hamlibc::RIG_HANDSHAKE_HARDWARE;
*RIG_SIGNAL_UNSET = *Hamlibc::RIG_SIGNAL_UNSET;
*RIG_SIGNAL_ON = *Hamlibc::RIG_SIGNAL_ON;
*RIG_SIGNAL_OFF = *Hamlibc::RIG_SIGNAL_OFF;
*RIG_FLAG_RECEIVER = *Hamlibc::RIG_FLAG_RECEIVER;
*RIG_FLAG_TRANSMITTER = *Hamlibc::RIG_FLAG_TRANSMITTER;
*RIG_FLAG_SCANNER = *Hamlibc::RIG_FLAG_SCANNER;
*RIG_FLAG_MOBILE = *Hamlibc::RIG_FLAG_MOBILE;
*RIG_FLAG_HANDHELD = *Hamlibc::RIG_FLAG_HANDHELD;
*RIG_FLAG_COMPUTER = *Hamlibc::RIG_FLAG_COMPUTER;
*RIG_FLAG_TRUNKING = *Hamlibc::RIG_FLAG_TRUNKING;
*RIG_FLAG_APRS = *Hamlibc::RIG_FLAG_APRS;
*RIG_FLAG_TNC = *Hamlibc::RIG_FLAG_TNC;
*RIG_FLAG_DXCLUSTER = *Hamlibc::RIG_FLAG_DXCLUSTER;
*RIG_FLAG_TUNER = *Hamlibc::RIG_FLAG_TUNER;
*RIG_TYPE_OTHER = *Hamlibc::RIG_TYPE_OTHER;
*RIG_STATUS_ALPHA = *Hamlibc::RIG_STATUS_ALPHA;
*RIG_STATUS_UNTESTED = *Hamlibc::RIG_STATUS_UNTESTED;
*RIG_STATUS_BETA = *Hamlibc::RIG_STATUS_BETA;
*RIG_STATUS_STABLE = *Hamlibc::RIG_STATUS_STABLE;
*RIG_STATUS_BUGGY = *Hamlibc::RIG_STATUS_BUGGY;
*RIG_RPT_SHIFT_NONE = *Hamlibc::RIG_RPT_SHIFT_NONE;
*RIG_RPT_SHIFT_MINUS = *Hamlibc::RIG_RPT_SHIFT_MINUS;
*RIG_RPT_SHIFT_PLUS = *Hamlibc::RIG_RPT_SHIFT_PLUS;
*RIG_SPLIT_OFF = *Hamlibc::RIG_SPLIT_OFF;
*RIG_SPLIT_ON = *Hamlibc::RIG_SPLIT_ON;
*RIG_VFO_NONE = *Hamlibc::RIG_VFO_NONE;
*RIG_VFO_A = *Hamlibc::RIG_VFO_A;
*RIG_VFO_B = *Hamlibc::RIG_VFO_B;
*RIG_VFO_C = *Hamlibc::RIG_VFO_C;
*RIG_VFO_SUB_A = *Hamlibc::RIG_VFO_SUB_A;
*RIG_VFO_SUB_B = *Hamlibc::RIG_VFO_SUB_B;
*RIG_VFO_SUB_C = *Hamlibc::RIG_VFO_SUB_C;
*RIG_VFO_MAIN_A = *Hamlibc::RIG_VFO_MAIN_A;
*RIG_VFO_MAIN_B = *Hamlibc::RIG_VFO_MAIN_B;
*RIG_VFO_MAIN_C = *Hamlibc::RIG_VFO_MAIN_C;
*RIG_VFO_OTHER = *Hamlibc::RIG_VFO_OTHER;
*RIG_VFO_SUB = *Hamlibc::RIG_VFO_SUB;
*RIG_VFO_MAIN = *Hamlibc::RIG_VFO_MAIN;
*RIG_VFO_VFO = *Hamlibc::RIG_VFO_VFO;
*RIG_VFO_MEM = *Hamlibc::RIG_VFO_MEM;
*RIG_VFO_CURR = *Hamlibc::RIG_VFO_CURR;
*RIG_VFO_TX_FLAG = *Hamlibc::RIG_VFO_TX_FLAG;
*RIG_VFO_ALL = *Hamlibc::RIG_VFO_ALL;
*RIG_VFO_TX = *Hamlibc::RIG_VFO_TX;
*RIG_VFO_RX = *Hamlibc::RIG_VFO_RX;
*RIG_TARGETABLE_NONE = *Hamlibc::RIG_TARGETABLE_NONE;
*RIG_TARGETABLE_FREQ = *Hamlibc::RIG_TARGETABLE_FREQ;
*RIG_TARGETABLE_MODE = *Hamlibc::RIG_TARGETABLE_MODE;
*RIG_TARGETABLE_PURE = *Hamlibc::RIG_TARGETABLE_PURE;
*RIG_TARGETABLE_TONE = *Hamlibc::RIG_TARGETABLE_TONE;
*RIG_TARGETABLE_FUNC = *Hamlibc::RIG_TARGETABLE_FUNC;
*RIG_TARGETABLE_LEVEL = *Hamlibc::RIG_TARGETABLE_LEVEL;
*RIG_TARGETABLE_RITXIT = *Hamlibc::RIG_TARGETABLE_RITXIT;
*RIG_TARGETABLE_PTT = *Hamlibc::RIG_TARGETABLE_PTT;
*RIG_TARGETABLE_MEM = *Hamlibc::RIG_TARGETABLE_MEM;
*RIG_TARGETABLE_BANK = *Hamlibc::RIG_TARGETABLE_BANK;
*RIG_TARGETABLE_ANT = *Hamlibc::RIG_TARGETABLE_ANT;
*RIG_TARGETABLE_ROOFING = *Hamlibc::RIG_TARGETABLE_ROOFING;
*RIG_TARGETABLE_SPECTRUM = *Hamlibc::RIG_TARGETABLE_SPECTRUM;
*RIG_TARGETABLE_COMMON = *Hamlibc::RIG_TARGETABLE_COMMON;
*RIG_TARGETABLE_ALL = *Hamlibc::RIG_TARGETABLE_ALL;
*VFO_DUAL = *Hamlibc::VFO_DUAL;
*RIG_DCD_OFF = *Hamlibc::RIG_DCD_OFF;
*RIG_DCD_ON = *Hamlibc::RIG_DCD_ON;
*RIG_DCD_NONE = *Hamlibc::RIG_DCD_NONE;
*RIG_DCD_RIG = *Hamlibc::RIG_DCD_RIG;
*RIG_DCD_SERIAL_DSR = *Hamlibc::RIG_DCD_SERIAL_DSR;
*RIG_DCD_SERIAL_CTS = *Hamlibc::RIG_DCD_SERIAL_CTS;
*RIG_DCD_SERIAL_CAR = *Hamlibc::RIG_DCD_SERIAL_CAR;
*RIG_DCD_PARALLEL = *Hamlibc::RIG_DCD_PARALLEL;
*RIG_DCD_CM108 = *Hamlibc::RIG_DCD_CM108;
*RIG_DCD_GPIO = *Hamlibc::RIG_DCD_GPIO;
*RIG_DCD_GPION = *Hamlibc::RIG_DCD_GPION;
*RIG_PTT_OFF = *Hamlibc::RIG_PTT_OFF;
*RIG_PTT_ON = *Hamlibc::RIG_PTT_ON;
*RIG_PTT_ON_MIC = *Hamlibc::RIG_PTT_ON_MIC;
*RIG_PTT_ON_DATA = *Hamlibc::RIG_PTT_ON_DATA;
*RIG_PTT_NONE = *Hamlibc::RIG_PTT_NONE;
*RIG_PTT_RIG = *Hamlibc::RIG_PTT_RIG;
*RIG_PTT_SERIAL_DTR = *Hamlibc::RIG_PTT_SERIAL_DTR;
*RIG_PTT_SERIAL_RTS = *Hamlibc::RIG_PTT_SERIAL_RTS;
*RIG_PTT_PARALLEL = *Hamlibc::RIG_PTT_PARALLEL;
*RIG_PTT_RIG_MICDATA = *Hamlibc::RIG_PTT_RIG_MICDATA;
*RIG_PTT_CM108 = *Hamlibc::RIG_PTT_CM108;
*RIG_PTT_GPIO = *Hamlibc::RIG_PTT_GPIO;
*RIG_PTT_GPION = *Hamlibc::RIG_PTT_GPION;
*RIG_POWER_OFF = *Hamlibc::RIG_POWER_OFF;
*RIG_POWER_ON = *Hamlibc::RIG_POWER_ON;
*RIG_POWER_STANDBY = *Hamlibc::RIG_POWER_STANDBY;
*RIG_POWER_OPERATE = *Hamlibc::RIG_POWER_OPERATE;
*RIG_POWER_UNKNOWN = *Hamlibc::RIG_POWER_UNKNOWN;
*RIG_RESET_NONE = *Hamlibc::RIG_RESET_NONE;
*RIG_RESET_SOFT = *Hamlibc::RIG_RESET_SOFT;
*RIG_RESET_VFO = *Hamlibc::RIG_RESET_VFO;
*RIG_RESET_MCALL = *Hamlibc::RIG_RESET_MCALL;
*RIG_RESET_MASTER = *Hamlibc::RIG_RESET_MASTER;
*RIG_OP_NONE = *Hamlibc::RIG_OP_NONE;
*RIG_OP_CPY = *Hamlibc::RIG_OP_CPY;
*RIG_OP_XCHG = *Hamlibc::RIG_OP_XCHG;
*RIG_OP_FROM_VFO = *Hamlibc::RIG_OP_FROM_VFO;
*RIG_OP_TO_VFO = *Hamlibc::RIG_OP_TO_VFO;
*RIG_OP_MCL = *Hamlibc::RIG_OP_MCL;
*RIG_OP_UP = *Hamlibc::RIG_OP_UP;
*RIG_OP_DOWN = *Hamlibc::RIG_OP_DOWN;
*RIG_OP_BAND_UP = *Hamlibc::RIG_OP_BAND_UP;
*RIG_OP_BAND_DOWN = *Hamlibc::RIG_OP_BAND_DOWN;
*RIG_OP_LEFT = *Hamlibc::RIG_OP_LEFT;
*RIG_OP_RIGHT = *Hamlibc::RIG_OP_RIGHT;
*RIG_OP_TUNE = *Hamlibc::RIG_OP_TUNE;
*RIG_OP_TOGGLE = *Hamlibc::RIG_OP_TOGGLE;
*RIG_SCAN_NONE = *Hamlibc::RIG_SCAN_NONE;
*RIG_SCAN_MEM = *Hamlibc::RIG_SCAN_MEM;
*RIG_SCAN_SLCT = *Hamlibc::RIG_SCAN_SLCT;
*RIG_SCAN_PRIO = *Hamlibc::RIG_SCAN_PRIO;
*RIG_SCAN_PROG = *Hamlibc::RIG_SCAN_PROG;
*RIG_SCAN_DELTA = *Hamlibc::RIG_SCAN_DELTA;
*RIG_SCAN_VFO = *Hamlibc::RIG_SCAN_VFO;
*RIG_SCAN_PLT = *Hamlibc::RIG_SCAN_PLT;
*RIG_SCAN_STOP = *Hamlibc::RIG_SCAN_STOP;
*RIG_CONF_END = *Hamlibc::RIG_CONF_END;
*RIG_CONF_STRING = *Hamlibc::RIG_CONF_STRING;
*RIG_CONF_COMBO = *Hamlibc::RIG_CONF_COMBO;
*RIG_CONF_NUMERIC = *Hamlibc::RIG_CONF_NUMERIC;
*RIG_CONF_CHECKBUTTON = *Hamlibc::RIG_CONF_CHECKBUTTON;
*RIG_CONF_BUTTON = *Hamlibc::RIG_CONF_BUTTON;
*RIG_CONF_BINARY = *Hamlibc::RIG_CONF_BINARY;
*RIG_COMBO_MAX = *Hamlibc::RIG_COMBO_MAX;
*RIG_BIN_MAX = *Hamlibc::RIG_BIN_MAX;
*RIG_ANN_NONE = *Hamlibc::RIG_ANN_NONE;
*RIG_ANN_OFF = *Hamlibc::RIG_ANN_OFF;
*RIG_ANN_FREQ = *Hamlibc::RIG_ANN_FREQ;
*RIG_ANN_RXMODE = *Hamlibc::RIG_ANN_RXMODE;
*RIG_ANN_CW = *Hamlibc::RIG_ANN_CW;
*RIG_ANN_ENG = *Hamlibc::RIG_ANN_ENG;
*RIG_ANN_JAP = *Hamlibc::RIG_ANN_JAP;
*RIG_ANT_NONE = *Hamlibc::RIG_ANT_NONE;
*RIG_ANT_MAX = *Hamlibc::RIG_ANT_MAX;
*RIG_AGC_OFF = *Hamlibc::RIG_AGC_OFF;
*RIG_AGC_SUPERFAST = *Hamlibc::RIG_AGC_SUPERFAST;
*RIG_AGC_FAST = *Hamlibc::RIG_AGC_FAST;
*RIG_AGC_SLOW = *Hamlibc::RIG_AGC_SLOW;
*RIG_AGC_USER = *Hamlibc::RIG_AGC_USER;
*RIG_AGC_MEDIUM = *Hamlibc::RIG_AGC_MEDIUM;
*RIG_AGC_AUTO = *Hamlibc::RIG_AGC_AUTO;
*RIG_METER_NONE = *Hamlibc::RIG_METER_NONE;
*RIG_METER_SWR = *Hamlibc::RIG_METER_SWR;
*RIG_METER_COMP = *Hamlibc::RIG_METER_COMP;
*RIG_METER_ALC = *Hamlibc::RIG_METER_ALC;
*RIG_METER_IC = *Hamlibc::RIG_METER_IC;
*RIG_METER_DB = *Hamlibc::RIG_METER_DB;
*RIG_METER_PO = *Hamlibc::RIG_METER_PO;
*RIG_METER_VDD = *Hamlibc::RIG_METER_VDD;
*RIG_METER_TEMP = *Hamlibc::RIG_METER_TEMP;
*RIG_LEVEL_NONE = *Hamlibc::RIG_LEVEL_NONE;
*RIG_LEVEL_PREAMP = *Hamlibc::RIG_LEVEL_PREAMP;
*RIG_LEVEL_ATT = *Hamlibc::RIG_LEVEL_ATT;
*RIG_LEVEL_VOXDELAY = *Hamlibc::RIG_LEVEL_VOXDELAY;
*RIG_LEVEL_AF = *Hamlibc::RIG_LEVEL_AF;
*RIG_LEVEL_RF = *Hamlibc::RIG_LEVEL_RF;
*RIG_LEVEL_SQL = *Hamlibc::RIG_LEVEL_SQL;
*RIG_LEVEL_IF = *Hamlibc::RIG_LEVEL_IF;
*RIG_LEVEL_APF = *Hamlibc::RIG_LEVEL_APF;
*RIG_LEVEL_NR = *Hamlibc::RIG_LEVEL_NR;
*RIG_LEVEL_PBT_IN = *Hamlibc::RIG_LEVEL_PBT_IN;
*RIG_LEVEL_PBT_OUT = *Hamlibc::RIG_LEVEL_PBT_OUT;
*RIG_LEVEL_CWPITCH = *Hamlibc::RIG_LEVEL_CWPITCH;
*RIG_LEVEL_RFPOWER = *Hamlibc::RIG_LEVEL_RFPOWER;
*RIG_LEVEL_MICGAIN = *Hamlibc::RIG_LEVEL_MICGAIN;
*RIG_LEVEL_KEYSPD = *Hamlibc::RIG_LEVEL_KEYSPD;
*RIG_LEVEL_NOTCHF = *Hamlibc::RIG_LEVEL_NOTCHF;
*RIG_LEVEL_COMP = *Hamlibc::RIG_LEVEL_COMP;
*RIG_LEVEL_AGC = *Hamlibc::RIG_LEVEL_AGC;
*RIG_LEVEL_BKINDL = *Hamlibc::RIG_LEVEL_BKINDL;
*RIG_LEVEL_BALANCE = *Hamlibc::RIG_LEVEL_BALANCE;
*RIG_LEVEL_METER = *Hamlibc::RIG_LEVEL_METER;
*RIG_LEVEL_VOXGAIN = *Hamlibc::RIG_LEVEL_VOXGAIN;
*RIG_LEVEL_ANTIVOX = *Hamlibc::RIG_LEVEL_ANTIVOX;
*RIG_LEVEL_SLOPE_LOW = *Hamlibc::RIG_LEVEL_SLOPE_LOW;
*RIG_LEVEL_SLOPE_HIGH = *Hamlibc::RIG_LEVEL_SLOPE_HIGH;
*RIG_LEVEL_BKIN_DLYMS = *Hamlibc::RIG_LEVEL_BKIN_DLYMS;
*RIG_LEVEL_RAWSTR = *Hamlibc::RIG_LEVEL_RAWSTR;
*RIG_LEVEL_SWR = *Hamlibc::RIG_LEVEL_SWR;
*RIG_LEVEL_ALC = *Hamlibc::RIG_LEVEL_ALC;
*RIG_LEVEL_STRENGTH = *Hamlibc::RIG_LEVEL_STRENGTH;
*RIG_LEVEL_RFPOWER_METER = *Hamlibc::RIG_LEVEL_RFPOWER_METER;
*RIG_LEVEL_COMP_METER = *Hamlibc::RIG_LEVEL_COMP_METER;
*RIG_LEVEL_VD_METER = *Hamlibc::RIG_LEVEL_VD_METER;
*RIG_LEVEL_ID_METER = *Hamlibc::RIG_LEVEL_ID_METER;
*RIG_LEVEL_NOTCHF_RAW = *Hamlibc::RIG_LEVEL_NOTCHF_RAW;
*RIG_LEVEL_MONITOR_GAIN = *Hamlibc::RIG_LEVEL_MONITOR_GAIN;
*RIG_LEVEL_NB = *Hamlibc::RIG_LEVEL_NB;
*RIG_LEVEL_RFPOWER_METER_WATTS = *Hamlibc::RIG_LEVEL_RFPOWER_METER_WATTS;
*RIG_LEVEL_SPECTRUM_MODE = *Hamlibc::RIG_LEVEL_SPECTRUM_MODE;
*RIG_LEVEL_SPECTRUM_SPAN = *Hamlibc::RIG_LEVEL_SPECTRUM_SPAN;
*RIG_LEVEL_SPECTRUM_EDGE_LOW = *Hamlibc::RIG_LEVEL_SPECTRUM_EDGE_LOW;
*RIG_LEVEL_SPECTRUM_EDGE_HIGH = *Hamlibc::RIG_LEVEL_SPECTRUM_EDGE_HIGH;
*RIG_LEVEL_SPECTRUM_SPEED = *Hamlibc::RIG_LEVEL_SPECTRUM_SPEED;
*RIG_LEVEL_SPECTRUM_REF = *Hamlibc::RIG_LEVEL_SPECTRUM_REF;
*RIG_LEVEL_SPECTRUM_AVG = *Hamlibc::RIG_LEVEL_SPECTRUM_AVG;
*RIG_LEVEL_SPECTRUM_ATT = *Hamlibc::RIG_LEVEL_SPECTRUM_ATT;
*RIG_LEVEL_TEMP_METER = *Hamlibc::RIG_LEVEL_TEMP_METER;
*RIG_LEVEL_48 = *Hamlibc::RIG_LEVEL_48;
*RIG_LEVEL_49 = *Hamlibc::RIG_LEVEL_49;
*RIG_LEVEL_50 = *Hamlibc::RIG_LEVEL_50;
*RIG_LEVEL_51 = *Hamlibc::RIG_LEVEL_51;
*RIG_LEVEL_52 = *Hamlibc::RIG_LEVEL_52;
*RIG_LEVEL_53 = *Hamlibc::RIG_LEVEL_53;
*RIG_LEVEL_54 = *Hamlibc::RIG_LEVEL_54;
*RIG_LEVEL_55 = *Hamlibc::RIG_LEVEL_55;
*RIG_LEVEL_56 = *Hamlibc::RIG_LEVEL_56;
*RIG_LEVEL_57 = *Hamlibc::RIG_LEVEL_57;
*RIG_LEVEL_58 = *Hamlibc::RIG_LEVEL_58;
*RIG_LEVEL_59 = *Hamlibc::RIG_LEVEL_59;
*RIG_LEVEL_60 = *Hamlibc::RIG_LEVEL_60;
*RIG_LEVEL_61 = *Hamlibc::RIG_LEVEL_61;
*RIG_LEVEL_62 = *Hamlibc::RIG_LEVEL_62;
*RIG_LEVEL_63 = *Hamlibc::RIG_LEVEL_63;
*RIG_LEVEL_FLOAT_LIST = *Hamlibc::RIG_LEVEL_FLOAT_LIST;
*RIG_LEVEL_READONLY_LIST = *Hamlibc::RIG_LEVEL_READONLY_LIST;
*RIG_PARM_NONE = *Hamlibc::RIG_PARM_NONE;
*RIG_PARM_ANN = *Hamlibc::RIG_PARM_ANN;
*RIG_PARM_APO = *Hamlibc::RIG_PARM_APO;
*RIG_PARM_BACKLIGHT = *Hamlibc::RIG_PARM_BACKLIGHT;
*RIG_PARM_BEEP = *Hamlibc::RIG_PARM_BEEP;
*RIG_PARM_TIME = *Hamlibc::RIG_PARM_TIME;
*RIG_PARM_BAT = *Hamlibc::RIG_PARM_BAT;
*RIG_PARM_KEYLIGHT = *Hamlibc::RIG_PARM_KEYLIGHT;
*RIG_PARM_SCREENSAVER = *Hamlibc::RIG_PARM_SCREENSAVER;
*RIG_COOKIE_GET = *Hamlibc::RIG_COOKIE_GET;
*RIG_COOKIE_RELEASE = *Hamlibc::RIG_COOKIE_RELEASE;
*RIG_COOKIE_RENEW = *Hamlibc::RIG_COOKIE_RENEW;
*RIG_MULTICAST_POLL = *Hamlibc::RIG_MULTICAST_POLL;
*RIG_MULTICAST_TRANSCEIVE = *Hamlibc::RIG_MULTICAST_TRANSCEIVE;
*RIG_MULTICAST_SPECTRUM = *Hamlibc::RIG_MULTICAST_SPECTRUM;
*RIG_SETTING_MAX = *Hamlibc::RIG_SETTING_MAX;
*RIG_TRN_OFF = *Hamlibc::RIG_TRN_OFF;
*RIG_TRN_RIG = *Hamlibc::RIG_TRN_RIG;
*RIG_TRN_POLL = *Hamlibc::RIG_TRN_POLL;
*RIG_FUNC_NONE = *Hamlibc::RIG_FUNC_NONE;
*RIG_FUNC_FAGC = *Hamlibc::RIG_FUNC_FAGC;
*RIG_FUNC_NB = *Hamlibc::RIG_FUNC_NB;
*RIG_FUNC_COMP = *Hamlibc::RIG_FUNC_COMP;
*RIG_FUNC_VOX = *Hamlibc::RIG_FUNC_VOX;
*RIG_FUNC_TONE = *Hamlibc::RIG_FUNC_TONE;
*RIG_FUNC_TSQL = *Hamlibc::RIG_FUNC_TSQL;
*RIG_FUNC_SBKIN = *Hamlibc::RIG_FUNC_SBKIN;
*RIG_FUNC_FBKIN = *Hamlibc::RIG_FUNC_FBKIN;
*RIG_FUNC_ANF = *Hamlibc::RIG_FUNC_ANF;
*RIG_FUNC_NR = *Hamlibc::RIG_FUNC_NR;
*RIG_FUNC_AIP = *Hamlibc::RIG_FUNC_AIP;
*RIG_FUNC_APF = *Hamlibc::RIG_FUNC_APF;
*RIG_FUNC_MON = *Hamlibc::RIG_FUNC_MON;
*RIG_FUNC_MN = *Hamlibc::RIG_FUNC_MN;
*RIG_FUNC_RF = *Hamlibc::RIG_FUNC_RF;
*RIG_FUNC_ARO = *Hamlibc::RIG_FUNC_ARO;
*RIG_FUNC_LOCK = *Hamlibc::RIG_FUNC_LOCK;
*RIG_FUNC_MUTE = *Hamlibc::RIG_FUNC_MUTE;
*RIG_FUNC_VSC = *Hamlibc::RIG_FUNC_VSC;
*RIG_FUNC_REV = *Hamlibc::RIG_FUNC_REV;
*RIG_FUNC_SQL = *Hamlibc::RIG_FUNC_SQL;
*RIG_FUNC_ABM = *Hamlibc::RIG_FUNC_ABM;
*RIG_FUNC_BC = *Hamlibc::RIG_FUNC_BC;
*RIG_FUNC_MBC = *Hamlibc::RIG_FUNC_MBC;
*RIG_FUNC_RIT = *Hamlibc::RIG_FUNC_RIT;
*RIG_FUNC_AFC = *Hamlibc::RIG_FUNC_AFC;
*RIG_FUNC_SATMODE = *Hamlibc::RIG_FUNC_SATMODE;
*RIG_FUNC_SCOPE = *Hamlibc::RIG_FUNC_SCOPE;
*RIG_FUNC_RESUME = *Hamlibc::RIG_FUNC_RESUME;
*RIG_FUNC_TBURST = *Hamlibc::RIG_FUNC_TBURST;
*RIG_FUNC_TUNER = *Hamlibc::RIG_FUNC_TUNER;
*RIG_FUNC_XIT = *Hamlibc::RIG_FUNC_XIT;
*RIG_FUNC_NB2 = *Hamlibc::RIG_FUNC_NB2;
*RIG_FUNC_CSQL = *Hamlibc::RIG_FUNC_CSQL;
*RIG_FUNC_AFLT = *Hamlibc::RIG_FUNC_AFLT;
*RIG_FUNC_ANL = *Hamlibc::RIG_FUNC_ANL;
*RIG_FUNC_BC2 = *Hamlibc::RIG_FUNC_BC2;
*RIG_FUNC_DUAL_WATCH = *Hamlibc::RIG_FUNC_DUAL_WATCH;
*RIG_FUNC_DIVERSITY = *Hamlibc::RIG_FUNC_DIVERSITY;
*RIG_FUNC_DSQL = *Hamlibc::RIG_FUNC_DSQL;
*RIG_FUNC_SCEN = *Hamlibc::RIG_FUNC_SCEN;
*RIG_FUNC_SLICE = *Hamlibc::RIG_FUNC_SLICE;
*RIG_FUNC_TRANSCEIVE = *Hamlibc::RIG_FUNC_TRANSCEIVE;
*RIG_FUNC_SPECTRUM = *Hamlibc::RIG_FUNC_SPECTRUM;
*RIG_FUNC_SPECTRUM_HOLD = *Hamlibc::RIG_FUNC_SPECTRUM_HOLD;
*RIG_FUNC_BIT45 = *Hamlibc::RIG_FUNC_BIT45;
*RIG_FUNC_BIT46 = *Hamlibc::RIG_FUNC_BIT46;
*RIG_FUNC_BIT47 = *Hamlibc::RIG_FUNC_BIT47;
*RIG_FUNC_BIT48 = *Hamlibc::RIG_FUNC_BIT48;
*RIG_FUNC_BIT49 = *Hamlibc::RIG_FUNC_BIT49;
*RIG_FUNC_BIT50 = *Hamlibc::RIG_FUNC_BIT50;
*RIG_FUNC_BIT51 = *Hamlibc::RIG_FUNC_BIT51;
*RIG_FUNC_BIT52 = *Hamlibc::RIG_FUNC_BIT52;
*RIG_FUNC_BIT53 = *Hamlibc::RIG_FUNC_BIT53;
*RIG_FUNC_BIT54 = *Hamlibc::RIG_FUNC_BIT54;
*RIG_FUNC_BIT55 = *Hamlibc::RIG_FUNC_BIT55;
*RIG_FUNC_BIT56 = *Hamlibc::RIG_FUNC_BIT56;
*RIG_FUNC_BIT57 = *Hamlibc::RIG_FUNC_BIT57;
*RIG_FUNC_BIT58 = *Hamlibc::RIG_FUNC_BIT58;
*RIG_FUNC_BIT59 = *Hamlibc::RIG_FUNC_BIT59;
*RIG_FUNC_BIT60 = *Hamlibc::RIG_FUNC_BIT60;
*RIG_FUNC_BIT61 = *Hamlibc::RIG_FUNC_BIT61;
*RIG_FUNC_BIT62 = *Hamlibc::RIG_FUNC_BIT62;
*RIG_FUNC_BIT63 = *Hamlibc::RIG_FUNC_BIT63;
*RIG_MODE_NONE = *Hamlibc::RIG_MODE_NONE;
*RIG_MODE_AM = *Hamlibc::RIG_MODE_AM;
*RIG_MODE_CW = *Hamlibc::RIG_MODE_CW;
*RIG_MODE_USB = *Hamlibc::RIG_MODE_USB;
*RIG_MODE_LSB = *Hamlibc::RIG_MODE_LSB;
*RIG_MODE_RTTY = *Hamlibc::RIG_MODE_RTTY;
*RIG_MODE_FM = *Hamlibc::RIG_MODE_FM;
*RIG_MODE_WFM = *Hamlibc::RIG_MODE_WFM;
*RIG_MODE_CWR = *Hamlibc::RIG_MODE_CWR;
*RIG_MODE_RTTYR = *Hamlibc::RIG_MODE_RTTYR;
*RIG_MODE_AMS = *Hamlibc::RIG_MODE_AMS;
*RIG_MODE_PKTLSB = *Hamlibc::RIG_MODE_PKTLSB;
*RIG_MODE_PKTUSB = *Hamlibc::RIG_MODE_PKTUSB;
*RIG_MODE_PKTFM = *Hamlibc::RIG_MODE_PKTFM;
*RIG_MODE_ECSSUSB = *Hamlibc::RIG_MODE_ECSSUSB;
*RIG_MODE_ECSSLSB = *Hamlibc::RIG_MODE_ECSSLSB;
*RIG_MODE_FAX = *Hamlibc::RIG_MODE_FAX;
*RIG_MODE_SAM = *Hamlibc::RIG_MODE_SAM;
*RIG_MODE_SAL = *Hamlibc::RIG_MODE_SAL;
*RIG_MODE_SAH = *Hamlibc::RIG_MODE_SAH;
*RIG_MODE_DSB = *Hamlibc::RIG_MODE_DSB;
*RIG_MODE_FMN = *Hamlibc::RIG_MODE_FMN;
*RIG_MODE_PKTAM = *Hamlibc::RIG_MODE_PKTAM;
*RIG_MODE_P25 = *Hamlibc::RIG_MODE_P25;
*RIG_MODE_DSTAR = *Hamlibc::RIG_MODE_DSTAR;
*RIG_MODE_DPMR = *Hamlibc::RIG_MODE_DPMR;
*RIG_MODE_NXDNVN = *Hamlibc::RIG_MODE_NXDNVN;
*RIG_MODE_NXDN_N = *Hamlibc::RIG_MODE_NXDN_N;
*RIG_MODE_DCR = *Hamlibc::RIG_MODE_DCR;
*RIG_MODE_AMN = *Hamlibc::RIG_MODE_AMN;
*RIG_MODE_PSK = *Hamlibc::RIG_MODE_PSK;
*RIG_MODE_PSKR = *Hamlibc::RIG_MODE_PSKR;
*RIG_MODE_DD = *Hamlibc::RIG_MODE_DD;
*RIG_MODE_C4FM = *Hamlibc::RIG_MODE_C4FM;
*RIG_MODE_PKTFMN = *Hamlibc::RIG_MODE_PKTFMN;
*RIG_MODE_SPEC = *Hamlibc::RIG_MODE_SPEC;
*RIG_MODE_CWN = *Hamlibc::RIG_MODE_CWN;
*RIG_MODE_IQ = *Hamlibc::RIG_MODE_IQ;
*RIG_MODE_BIT38 = *Hamlibc::RIG_MODE_BIT38;
*RIG_MODE_BIT39 = *Hamlibc::RIG_MODE_BIT39;
*RIG_MODE_BIT40 = *Hamlibc::RIG_MODE_BIT40;
*RIG_MODE_BIT41 = *Hamlibc::RIG_MODE_BIT41;
*RIG_MODE_BIT42 = *Hamlibc::RIG_MODE_BIT42;
*RIG_MODE_BIT43 = *Hamlibc::RIG_MODE_BIT43;
*RIG_MODE_BIT44 = *Hamlibc::RIG_MODE_BIT44;
*RIG_MODE_BIT45 = *Hamlibc::RIG_MODE_BIT45;
*RIG_MODE_BIT46 = *Hamlibc::RIG_MODE_BIT46;
*RIG_MODE_BIT47 = *Hamlibc::RIG_MODE_BIT47;
*RIG_MODE_BIT48 = *Hamlibc::RIG_MODE_BIT48;
*RIG_MODE_BIT49 = *Hamlibc::RIG_MODE_BIT49;
*RIG_MODE_BIT50 = *Hamlibc::RIG_MODE_BIT50;
*RIG_MODE_BIT51 = *Hamlibc::RIG_MODE_BIT51;
*RIG_MODE_BIT52 = *Hamlibc::RIG_MODE_BIT52;
*RIG_MODE_BIT53 = *Hamlibc::RIG_MODE_BIT53;
*RIG_MODE_BIT54 = *Hamlibc::RIG_MODE_BIT54;
*RIG_MODE_BIT55 = *Hamlibc::RIG_MODE_BIT55;
*RIG_MODE_BIT56 = *Hamlibc::RIG_MODE_BIT56;
*RIG_MODE_BIT57 = *Hamlibc::RIG_MODE_BIT57;
*RIG_MODE_BIT58 = *Hamlibc::RIG_MODE_BIT58;
*RIG_MODE_BIT59 = *Hamlibc::RIG_MODE_BIT59;
*RIG_MODE_BIT60 = *Hamlibc::RIG_MODE_BIT60;
*RIG_MODE_BIT61 = *Hamlibc::RIG_MODE_BIT61;
*RIG_MODE_BIT62 = *Hamlibc::RIG_MODE_BIT62;
*RIG_MODE_TESTS_MAX = *Hamlibc::RIG_MODE_TESTS_MAX;
*RIG_MODE_SSB = *Hamlibc::RIG_MODE_SSB;
*RIG_MODE_ECSS = *Hamlibc::RIG_MODE_ECSS;
*RIG_DBLST_END = *Hamlibc::RIG_DBLST_END;
*RIG_TS_ANY = *Hamlibc::RIG_TS_ANY;
*RIG_FLT_ANY = *Hamlibc::RIG_FLT_ANY;
*RIG_CHFLAG_NONE = *Hamlibc::RIG_CHFLAG_NONE;
*RIG_CHFLAG_SKIP = *Hamlibc::RIG_CHFLAG_SKIP;
*RIG_CHFLAG_DATA = *Hamlibc::RIG_CHFLAG_DATA;
*RIG_CHFLAG_PSKIP = *Hamlibc::RIG_CHFLAG_PSKIP;
*RIG_MTYPE_NONE = *Hamlibc::RIG_MTYPE_NONE;
*RIG_MTYPE_MEM = *Hamlibc::RIG_MTYPE_MEM;
*RIG_MTYPE_EDGE = *Hamlibc::RIG_MTYPE_EDGE;
*RIG_MTYPE_CALL = *Hamlibc::RIG_MTYPE_CALL;
*RIG_MTYPE_MEMOPAD = *Hamlibc::RIG_MTYPE_MEMOPAD;
*RIG_MTYPE_SAT = *Hamlibc::RIG_MTYPE_SAT;
*RIG_MTYPE_BAND = *Hamlibc::RIG_MTYPE_BAND;
*RIG_MTYPE_PRIO = *Hamlibc::RIG_MTYPE_PRIO;
*RIG_MEM_CAPS_ALL = *Hamlibc::RIG_MEM_CAPS_ALL;
*RIG_SPECTRUM_MODE_NONE = *Hamlibc::RIG_SPECTRUM_MODE_NONE;
*RIG_SPECTRUM_MODE_CENTER = *Hamlibc::RIG_SPECTRUM_MODE_CENTER;
*RIG_SPECTRUM_MODE_FIXED = *Hamlibc::RIG_SPECTRUM_MODE_FIXED;
*RIG_SPECTRUM_MODE_CENTER_SCROLL = *Hamlibc::RIG_SPECTRUM_MODE_CENTER_SCROLL;
*RIG_SPECTRUM_MODE_FIXED_SCROLL = *Hamlibc::RIG_SPECTRUM_MODE_FIXED_SCROLL;
*RIG_FUNCTION_INIT = *Hamlibc::RIG_FUNCTION_INIT;
*RIG_FUNCTION_CLEANUP = *Hamlibc::RIG_FUNCTION_CLEANUP;
*RIG_FUNCTION_OPEN = *Hamlibc::RIG_FUNCTION_OPEN;
*RIG_FUNCTION_CLOSE = *Hamlibc::RIG_FUNCTION_CLOSE;
*RIG_FUNCTION_SET_FREQ = *Hamlibc::RIG_FUNCTION_SET_FREQ;
*RIG_FUNCTION_GET_FREQ = *Hamlibc::RIG_FUNCTION_GET_FREQ;
*RIG_FUNCTION_SET_MODE = *Hamlibc::RIG_FUNCTION_SET_MODE;
*RIG_FUNCTION_GET_MODE = *Hamlibc::RIG_FUNCTION_GET_MODE;
*RIG_FUNCTION_SET_VFO = *Hamlibc::RIG_FUNCTION_SET_VFO;
*RIG_FUNCTION_GET_VFO = *Hamlibc::RIG_FUNCTION_GET_VFO;
*RIG_FUNCTION_SET_PTT = *Hamlibc::RIG_FUNCTION_SET_PTT;
*RIG_FUNCTION_GET_PTT = *Hamlibc::RIG_FUNCTION_GET_PTT;
*RIG_FUNCTION_GET_DCD = *Hamlibc::RIG_FUNCTION_GET_DCD;
*RIG_FUNCTION_SET_RPTR_SHIFT = *Hamlibc::RIG_FUNCTION_SET_RPTR_SHIFT;
*RIG_FUNCTION_GET_RPTR_SHIFT = *Hamlibc::RIG_FUNCTION_GET_RPTR_SHIFT;
*RIG_FUNCTION_SET_RPTR_OFFS = *Hamlibc::RIG_FUNCTION_SET_RPTR_OFFS;
*RIG_FUNCTION_GET_RPTR_OFFS = *Hamlibc::RIG_FUNCTION_GET_RPTR_OFFS;
*RIG_FUNCTION_SET_SPLIT_FREQ = *Hamlibc::RIG_FUNCTION_SET_SPLIT_FREQ;
*RIG_FUNCTION_GET_SPLIT_FREQ = *Hamlibc::RIG_FUNCTION_GET_SPLIT_FREQ;
*RIG_FUNCTION_SET_SPLIT_MODE = *Hamlibc::RIG_FUNCTION_SET_SPLIT_MODE;
*RIG_FUNCTION_SET_SPLIT_FREQ_MODE = *Hamlibc::RIG_FUNCTION_SET_SPLIT_FREQ_MODE;
*RIG_FUNCTION_GET_SPLIT_FREQ_MODE = *Hamlibc::RIG_FUNCTION_GET_SPLIT_FREQ_MODE;
*RIG_FUNCTION_SET_SPLIT_VFO = *Hamlibc::RIG_FUNCTION_SET_SPLIT_VFO;
*RIG_FUNCTION_GET_SPLIT_VFO = *Hamlibc::RIG_FUNCTION_GET_SPLIT_VFO;
*RIG_FUNCTION_SET_RIT = *Hamlibc::RIG_FUNCTION_SET_RIT;
*RIG_FUNCTION_GET_RIT = *Hamlibc::RIG_FUNCTION_GET_RIT;
*RIG_FUNCTION_SET_XIT = *Hamlibc::RIG_FUNCTION_SET_XIT;
*RIG_FUNCTION_GET_XIT = *Hamlibc::RIG_FUNCTION_GET_XIT;
*RIG_FUNCTION_SET_TS = *Hamlibc::RIG_FUNCTION_SET_TS;
*RIG_FUNCTION_GET_TS = *Hamlibc::RIG_FUNCTION_GET_TS;
*RIG_FUNCTION_SET_DCS_CODE = *Hamlibc::RIG_FUNCTION_SET_DCS_CODE;
*RIG_FUNCTION_GET_DCS_CODE = *Hamlibc::RIG_FUNCTION_GET_DCS_CODE;
*RIG_FUNCTION_SET_TONE = *Hamlibc::RIG_FUNCTION_SET_TONE;
*RIG_FUNCTION_GET_TONE = *Hamlibc::RIG_FUNCTION_GET_TONE;
*RIG_FUNCTION_SET_CTCSS_TONE = *Hamlibc::RIG_FUNCTION_SET_CTCSS_TONE;
*RIG_FUNCTION_GET_CTCSS_TONE = *Hamlibc::RIG_FUNCTION_GET_CTCSS_TONE;
*RIG_FUNCTION_SET_DCS_SQL = *Hamlibc::RIG_FUNCTION_SET_DCS_SQL;
*RIG_FUNCTION_GET_DCS_SQL = *Hamlibc::RIG_FUNCTION_GET_DCS_SQL;
*RIG_FUNCTION_SET_TONE_SQL = *Hamlibc::RIG_FUNCTION_SET_TONE_SQL;
*RIG_FUNCTION_GET_TONE_SQL = *Hamlibc::RIG_FUNCTION_GET_TONE_SQL;
*RIG_FUNCTION_SET_CTCSS_SQL = *Hamlibc::RIG_FUNCTION_SET_CTCSS_SQL;
*RIG_FUNCTION_GET_CTCSS_SQL = *Hamlibc::RIG_FUNCTION_GET_CTCSS_SQL;
*RIG_FUNCTION_POWER2MW = *Hamlibc::RIG_FUNCTION_POWER2MW;
*RIG_FUNCTION_MW2POWER = *Hamlibc::RIG_FUNCTION_MW2POWER;
*RIG_FUNCTION_SET_POWERSTAT = *Hamlibc::RIG_FUNCTION_SET_POWERSTAT;
*RIG_FUNCTION_GET_POWERSTAT = *Hamlibc::RIG_FUNCTION_GET_POWERSTAT;
*RIG_FUNCTION_RESET = *Hamlibc::RIG_FUNCTION_RESET;
*RIG_FUNCTION_SET_ANT = *Hamlibc::RIG_FUNCTION_SET_ANT;
*RIG_FUNCTION_GET_ANT = *Hamlibc::RIG_FUNCTION_GET_ANT;
*RIG_FUNCTION_SET_LEVEL = *Hamlibc::RIG_FUNCTION_SET_LEVEL;
*RIG_FUNCTION_GET_LEVEL = *Hamlibc::RIG_FUNCTION_GET_LEVEL;
*RIG_FUNCTION_SET_FUNC = *Hamlibc::RIG_FUNCTION_SET_FUNC;
*RIG_FUNCTION_GET_FUNC = *Hamlibc::RIG_FUNCTION_GET_FUNC;
*RIG_FUNCTION_SET_PARM = *Hamlibc::RIG_FUNCTION_SET_PARM;
*RIG_FUNCTION_GET_PARM = *Hamlibc::RIG_FUNCTION_GET_PARM;
*RIG_FUNCTION_SET_EXT_LEVEL = *Hamlibc::RIG_FUNCTION_SET_EXT_LEVEL;
*RIG_FUNCTION_GET_EXT_LEVEL = *Hamlibc::RIG_FUNCTION_GET_EXT_LEVEL;
*RIG_FUNCTION_SET_EXT_FUNC = *Hamlibc::RIG_FUNCTION_SET_EXT_FUNC;
*RIG_FUNCTION_GET_EXT_FUNC = *Hamlibc::RIG_FUNCTION_GET_EXT_FUNC;
*RIG_FUNCTION_SET_EXT_PARM = *Hamlibc::RIG_FUNCTION_SET_EXT_PARM;
*RIG_FUNCTION_GET_EXT_PARM = *Hamlibc::RIG_FUNCTION_GET_EXT_PARM;
*RIG_FUNCTION_SET_CONF = *Hamlibc::RIG_FUNCTION_SET_CONF;
*RIG_FUNCTION_GET_CONF = *Hamlibc::RIG_FUNCTION_GET_CONF;
*RIG_FUNCTION_SEND_DTMF = *Hamlibc::RIG_FUNCTION_SEND_DTMF;
*RIG_FUNCTION_SEND_MORSE = *Hamlibc::RIG_FUNCTION_SEND_MORSE;
*RIG_FUNCTION_STOP_MORSE = *Hamlibc::RIG_FUNCTION_STOP_MORSE;
*RIG_FUNCTION_WAIT_MORSE = *Hamlibc::RIG_FUNCTION_WAIT_MORSE;
*RIG_FUNCTION_SET_BANK = *Hamlibc::RIG_FUNCTION_SET_BANK;
*RIG_FUNCTION_SET_MEM = *Hamlibc::RIG_FUNCTION_SET_MEM;
*RIG_FUNCTION_GET_MEM = *Hamlibc::RIG_FUNCTION_GET_MEM;
*RIG_FUNCTION_VFO_OP = *Hamlibc::RIG_FUNCTION_VFO_OP;
*RIG_FUNCTION_SCAN = *Hamlibc::RIG_FUNCTION_SCAN;
*RIG_FUNCTION_SET_TRN = *Hamlibc::RIG_FUNCTION_SET_TRN;
*RIG_FUNCTION_GET_TRN = *Hamlibc::RIG_FUNCTION_GET_TRN;
*RIG_FUNCTION_DECODE_EVENT = *Hamlibc::RIG_FUNCTION_DECODE_EVENT;
*RIG_FUNCTION_SET_CHANNEL = *Hamlibc::RIG_FUNCTION_SET_CHANNEL;
*RIG_FUNCTION_GET_CHANNEL = *Hamlibc::RIG_FUNCTION_GET_CHANNEL;
*RIG_FUNCTION_GET_INFO = *Hamlibc::RIG_FUNCTION_GET_INFO;
*RIG_FUNCTION_SET_CHAN_ALL_CB = *Hamlibc::RIG_FUNCTION_SET_CHAN_ALL_CB;
*RIG_FUNCTION_GET_CHAN_ALL_CB = *Hamlibc::RIG_FUNCTION_GET_CHAN_ALL_CB;
*RIG_FUNCTION_SET_MEM_ALL_CB = *Hamlibc::RIG_FUNCTION_SET_MEM_ALL_CB;
*RIG_FUNCTION_GET_MEM_ALL_CB = *Hamlibc::RIG_FUNCTION_GET_MEM_ALL_CB;
*RIG_FUNCTION_SET_VFO_OPT = *Hamlibc::RIG_FUNCTION_SET_VFO_OPT;
*RIG_CAPS_TARGETABLE_VFO = *Hamlibc::RIG_CAPS_TARGETABLE_VFO;
*RIG_CAPS_RIG_MODEL = *Hamlibc::RIG_CAPS_RIG_MODEL;
*RIG_CAPS_PORT_TYPE = *Hamlibc::RIG_CAPS_PORT_TYPE;
*RIG_CAPS_PTT_TYPE = *Hamlibc::RIG_CAPS_PTT_TYPE;
*RIG_CAPS_HAS_GET_LEVEL = *Hamlibc::RIG_CAPS_HAS_GET_LEVEL;
*RIG_CAPS_VERSION_CPTR = *Hamlibc::RIG_CAPS_VERSION_CPTR;
*RIG_CAPS_MFG_NAME_CPTR = *Hamlibc::RIG_CAPS_MFG_NAME_CPTR;
*RIG_CAPS_MODEL_NAME_CPTR = *Hamlibc::RIG_CAPS_MODEL_NAME_CPTR;
*RIG_CAPS_STATUS_CPTR = *Hamlibc::RIG_CAPS_STATUS_CPTR;
*HAMLIB_ELAPSED_GET = *Hamlibc::HAMLIB_ELAPSED_GET;
*HAMLIB_ELAPSED_SET = *Hamlibc::HAMLIB_ELAPSED_SET;
*HAMLIB_ELAPSED_INVALIDATE = *Hamlibc::HAMLIB_ELAPSED_INVALIDATE;
*HAMLIB_CACHE_ALWAYS = *Hamlibc::HAMLIB_CACHE_ALWAYS;
*HAMLIB_CACHE_ALL = *Hamlibc::HAMLIB_CACHE_ALL;
*HAMLIB_CACHE_VFO = *Hamlibc::HAMLIB_CACHE_VFO;
*HAMLIB_CACHE_FREQ = *Hamlibc::HAMLIB_CACHE_FREQ;
*HAMLIB_CACHE_MODE = *Hamlibc::HAMLIB_CACHE_MODE;
*HAMLIB_CACHE_PTT = *Hamlibc::HAMLIB_CACHE_PTT;
*HAMLIB_CACHE_SPLIT = *Hamlibc::HAMLIB_CACHE_SPLIT;
*HAMLIB_CACHE_WIDTH = *Hamlibc::HAMLIB_CACHE_WIDTH;
*TWIDDLE_OFF = *Hamlibc::TWIDDLE_OFF;
*TWIDDLE_ON = *Hamlibc::TWIDDLE_ON;
*DEBUGMSGSAVE_SIZE = *Hamlibc::DEBUGMSGSAVE_SIZE;
*debugmsgsave = *Hamlibc::debugmsgsave;
*debugmsgsave2 = *Hamlibc::debugmsgsave2;
*debugmsgsave3 = *Hamlibc::debugmsgsave3;
*ROT_MODEL_NONE = *Hamlibc::ROT_MODEL_NONE;
*ROT_MODEL_DUMMY = *Hamlibc::ROT_MODEL_DUMMY;
*ROT_MODEL_NETROTCTL = *Hamlibc::ROT_MODEL_NETROTCTL;
*ROT_MODEL_EASYCOMM1 = *Hamlibc::ROT_MODEL_EASYCOMM1;
*ROT_MODEL_EASYCOMM2 = *Hamlibc::ROT_MODEL_EASYCOMM2;
*ROT_MODEL_EASYCOMM3 = *Hamlibc::ROT_MODEL_EASYCOMM3;
*ROT_MODEL_FODTRACK = *Hamlibc::ROT_MODEL_FODTRACK;
*ROT_MODEL_ROTOREZ = *Hamlibc::ROT_MODEL_ROTOREZ;
*ROT_MODEL_ROTORCARD = *Hamlibc::ROT_MODEL_ROTORCARD;
*ROT_MODEL_DCU = *Hamlibc::ROT_MODEL_DCU;
*ROT_MODEL_ERC = *Hamlibc::ROT_MODEL_ERC;
*ROT_MODEL_RT21 = *Hamlibc::ROT_MODEL_RT21;
*ROT_MODEL_SARTEK1 = *Hamlibc::ROT_MODEL_SARTEK1;
*ROT_MODEL_GS232A = *Hamlibc::ROT_MODEL_GS232A;
*ROT_MODEL_GS232_GENERIC = *Hamlibc::ROT_MODEL_GS232_GENERIC;
*ROT_MODEL_GS232B = *Hamlibc::ROT_MODEL_GS232B;
*ROT_MODEL_F1TETRACKER = *Hamlibc::ROT_MODEL_F1TETRACKER;
*ROT_MODEL_GS23 = *Hamlibc::ROT_MODEL_GS23;
*ROT_MODEL_GS232 = *Hamlibc::ROT_MODEL_GS232;
*ROT_MODEL_LVB = *Hamlibc::ROT_MODEL_LVB;
*ROT_MODEL_ST2 = *Hamlibc::ROT_MODEL_ST2;
*ROT_MODEL_GS232A_AZ = *Hamlibc::ROT_MODEL_GS232A_AZ;
*ROT_MODEL_GS232A_EL = *Hamlibc::ROT_MODEL_GS232A_EL;
*ROT_MODEL_GS232B_AZ = *Hamlibc::ROT_MODEL_GS232B_AZ;
*ROT_MODEL_GS232B_EL = *Hamlibc::ROT_MODEL_GS232B_EL;
*ROT_MODEL_PCROTOR = *Hamlibc::ROT_MODEL_PCROTOR;
*ROT_MODEL_HD1780 = *Hamlibc::ROT_MODEL_HD1780;
*ROT_MODEL_SPID_ROT2PROG = *Hamlibc::ROT_MODEL_SPID_ROT2PROG;
*ROT_MODEL_SPID_ROT1PROG = *Hamlibc::ROT_MODEL_SPID_ROT1PROG;
*ROT_MODEL_SPID_MD01_ROT2PROG = *Hamlibc::ROT_MODEL_SPID_MD01_ROT2PROG;
*ROT_MODEL_RC2800 = *Hamlibc::ROT_MODEL_RC2800;
*ROT_MODEL_RC2800_EARLY_AZ = *Hamlibc::ROT_MODEL_RC2800_EARLY_AZ;
*ROT_MODEL_RC2800_EARLY_AZEL = *Hamlibc::ROT_MODEL_RC2800_EARLY_AZEL;
*ROT_MODEL_RCI_AZEL = *Hamlibc::ROT_MODEL_RCI_AZEL;
*ROT_MODEL_RCI_AZ = *Hamlibc::ROT_MODEL_RCI_AZ;
*ROT_MODEL_IF100 = *Hamlibc::ROT_MODEL_IF100;
*ROT_MODEL_TS7400 = *Hamlibc::ROT_MODEL_TS7400;
*ROT_MODEL_NEXSTAR = *Hamlibc::ROT_MODEL_NEXSTAR;
*ROT_ETHER6 = *Hamlibc::ROT_ETHER6;
*ROT_BACKEND_ETHER6 = *Hamlibc::ROT_BACKEND_ETHER6;
*ROT_MODEL_ETHER6 = *Hamlibc::ROT_MODEL_ETHER6;
*ROT_CNCTRK = *Hamlibc::ROT_CNCTRK;
*ROT_BACKEND_CNCTRK = *Hamlibc::ROT_BACKEND_CNCTRK;
*ROT_MODEL_CNCTRK = *Hamlibc::ROT_MODEL_CNCTRK;
*ROT_PROSISTEL = *Hamlibc::ROT_PROSISTEL;
*ROT_BACKEND_PROSISTEL = *Hamlibc::ROT_BACKEND_PROSISTEL;
*ROT_MODEL_PROSISTEL_D_AZ = *Hamlibc::ROT_MODEL_PROSISTEL_D_AZ;
*ROT_MODEL_PROSISTEL_D_EL = *Hamlibc::ROT_MODEL_PROSISTEL_D_EL;
*ROT_MODEL_PROSISTEL_COMBI_TRACK_AZEL = *Hamlibc::ROT_MODEL_PROSISTEL_COMBI_TRACK_AZEL;
*ROT_MEADE = *Hamlibc::ROT_MEADE;
*ROT_BACKEND_MEADE = *Hamlibc::ROT_BACKEND_MEADE;
*ROT_MODEL_MEADE = *Hamlibc::ROT_MODEL_MEADE;
*ROT_IOPTRON = *Hamlibc::ROT_IOPTRON;
*ROT_BACKEND_IOPTRON = *Hamlibc::ROT_BACKEND_IOPTRON;
*ROT_MODEL_IOPTRON = *Hamlibc::ROT_MODEL_IOPTRON;
*ROT_INDI = *Hamlibc::ROT_INDI;
*ROT_BACKEND_INDI = *Hamlibc::ROT_BACKEND_INDI;
*ROT_MODEL_INDI = *Hamlibc::ROT_MODEL_INDI;
*ROT_SATEL = *Hamlibc::ROT_SATEL;
*ROT_BACKEND_SATEL = *Hamlibc::ROT_BACKEND_SATEL;
*ROT_MODEL_SATEL = *Hamlibc::ROT_MODEL_SATEL;
*ROT_RADANT = *Hamlibc::ROT_RADANT;
*ROT_BACKEND_RADANT = *Hamlibc::ROT_BACKEND_RADANT;
*ROT_MODEL_RADANT = *Hamlibc::ROT_MODEL_RADANT;
*ROT_ANDROIDSENSOR = *Hamlibc::ROT_ANDROIDSENSOR;
*ROT_BACKEND_ANDROIDSENSOR = *Hamlibc::ROT_BACKEND_ANDROIDSENSOR;
*ROT_MODEL_ANDROIDSENSOR = *Hamlibc::ROT_MODEL_ANDROIDSENSOR;
*NETROTCTL_RET = *Hamlibc::NETROTCTL_RET;
*ROT_RESET_ALL = *Hamlibc::ROT_RESET_ALL;
*ROT_FLAG_AZIMUTH = *Hamlibc::ROT_FLAG_AZIMUTH;
*ROT_FLAG_ELEVATION = *Hamlibc::ROT_FLAG_ELEVATION;
*ROT_TYPE_OTHER = *Hamlibc::ROT_TYPE_OTHER;
*ROT_MOVE_UP = *Hamlibc::ROT_MOVE_UP;
*ROT_MOVE_DOWN = *Hamlibc::ROT_MOVE_DOWN;
*ROT_MOVE_LEFT = *Hamlibc::ROT_MOVE_LEFT;
*ROT_MOVE_CCW = *Hamlibc::ROT_MOVE_CCW;
*ROT_MOVE_RIGHT = *Hamlibc::ROT_MOVE_RIGHT;
*ROT_MOVE_CW = *Hamlibc::ROT_MOVE_CW;
*ROT_STATUS_NONE = *Hamlibc::ROT_STATUS_NONE;
*ROT_STATUS_BUSY = *Hamlibc::ROT_STATUS_BUSY;
*ROT_STATUS_MOVING = *Hamlibc::ROT_STATUS_MOVING;
*ROT_STATUS_MOVING_AZ = *Hamlibc::ROT_STATUS_MOVING_AZ;
*ROT_STATUS_MOVING_LEFT = *Hamlibc::ROT_STATUS_MOVING_LEFT;
*ROT_STATUS_MOVING_RIGHT = *Hamlibc::ROT_STATUS_MOVING_RIGHT;
*ROT_STATUS_MOVING_EL = *Hamlibc::ROT_STATUS_MOVING_EL;
*ROT_STATUS_MOVING_UP = *Hamlibc::ROT_STATUS_MOVING_UP;
*ROT_STATUS_MOVING_DOWN = *Hamlibc::ROT_STATUS_MOVING_DOWN;
*ROT_STATUS_LIMIT_UP = *Hamlibc::ROT_STATUS_LIMIT_UP;
*ROT_STATUS_LIMIT_DOWN = *Hamlibc::ROT_STATUS_LIMIT_DOWN;
*ROT_STATUS_LIMIT_LEFT = *Hamlibc::ROT_STATUS_LIMIT_LEFT;
*ROT_STATUS_LIMIT_RIGHT = *Hamlibc::ROT_STATUS_LIMIT_RIGHT;
*ROT_STATUS_OVERLAP_UP = *Hamlibc::ROT_STATUS_OVERLAP_UP;
*ROT_STATUS_OVERLAP_DOWN = *Hamlibc::ROT_STATUS_OVERLAP_DOWN;
*ROT_STATUS_OVERLAP_LEFT = *Hamlibc::ROT_STATUS_OVERLAP_LEFT;
*ROT_STATUS_OVERLAP_RIGHT = *Hamlibc::ROT_STATUS_OVERLAP_RIGHT;
*ROT_SPEED_NOCHANGE = *Hamlibc::ROT_SPEED_NOCHANGE;
*ROT_LEVEL_NONE = *Hamlibc::ROT_LEVEL_NONE;
*ROT_LEVEL_SPEED = *Hamlibc::ROT_LEVEL_SPEED;
*ROT_LEVEL_63 = *Hamlibc::ROT_LEVEL_63;
*ROT_LEVEL_FLOAT_LIST = *Hamlibc::ROT_LEVEL_FLOAT_LIST;
*ROT_LEVEL_READONLY_LIST = *Hamlibc::ROT_LEVEL_READONLY_LIST;
*ROT_PARM_NONE = *Hamlibc::ROT_PARM_NONE;
*ROT_PARM_FLOAT_LIST = *Hamlibc::ROT_PARM_FLOAT_LIST;
*ROT_PARM_READONLY_LIST = *Hamlibc::ROT_PARM_READONLY_LIST;
*ROT_FUNC_NONE = *Hamlibc::ROT_FUNC_NONE;
*ROT_FUNC_BIT63 = *Hamlibc::ROT_FUNC_BIT63;
1;
